"""
Contains embedded image and icon resources for SQLitely. Auto-generated.

------------------------------------------------------------------------------
This file is part of SQLitely - SQLite database tool.
Released under the MIT License.

@author      Erki Suurjaak
@created     21.08.2019
@modified    17.06.2020
------------------------------------------------------------------------------
"""
try:
    import wx
    from wx.lib.embeddedimage import PyEmbeddedImage
except ImportError:
    class PyEmbeddedImage(object):
        """Data stand-in for wx.lib.embeddedimage.PyEmbeddedImage."""
        def __init__(self, data):
            self.data = data


"""Returns the application icon bundle, for several sizes and colour depths."""
def get_appicons():
    icons = wx.IconBundle()
    [icons.AddIcon(i.Icon) for i in [
        Icon16x16_32bit, Icon16x16_8bit, Icon24x24_32bit, Icon24x24_8bit,
        Icon32x32_32bit, Icon32x32_8bit, Icon40x40_32bit, Icon40x40_8bit,
        Icon48x48_32bit, Icon48x48_8bit, Icon64x64_32bit, Icon64x64_8bit
    ]]
    return icons


"""SQLitely application 16x16 icon, 32-bit colour."""
Icon16x16_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAl0lEQVQ4y82SOw4CMQwFJ9mU"
    "CGoKCjqqlTjXFpwECZC4GAUX4AawBfnYoSAcIEnDSC79NH6yGa/347hZHoxhoIKckdvjeXa7"
    "9WLab1dVy4UhJJ1cELXzO9FCELXOR6U1wEelBEhHQOowSMXg1XVCkg4D+YcOQlRmGv/gZxBF"
    "mwI0gxPNtDXwxdKHsdAloBa4AB5IleOB0wf8VXjeUs0eYwAAAABJRU5ErkJggg=="
)


"""SQLitely application 16x16 icon, 8-bit colour."""
Icon16x16_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAfUlEQVQ4y82SOw7CQAwF3yKX"
    "EdQpKOioVsphczEKLsANkhTsrj8pIOmxCzIHGI2fnPL4tHw9IyX8hBnweE2ge99huF3gobKC"
    "qiiWN/sEoqDS/ILSdoEEBBwo4G/BHDqBJVAgR9igNsUC5x9sBU3UJVADSNTgW+DDCUH+L1gB"
    "SXdlkKqpY/MAAAAASUVORK5CYII="
)


"""SQLitely application 24x24 icon, 32-bit colour."""
Icon24x24_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAAzUlEQVRIx92WMWoCYRCFv13/"
    "DYgEI5IyIIsWniGlJxHFc3gFawmeJDdIGRQSC8FSUqVY2WVmUog32NfkO8B8vMcrJuuvP15f"
    "ht3d8+PDhIx2CLj81t/nn2qeTTef+9VsNC06bV2/0ViwfT8d0qBXlGaOGa3z1CvKZB5UjaPA"
    "HJIHXEUCjyCZB9faRAnugkYucLFAWZELE/g9QSWtKNBVFPybFTXqFdXiFWkrCl1FHkGKAItA"
    "RY4YtSBXC7IcOAoFXwlYAm/AGNp8XDgCiz8zNaVKgdcv0QAAAABJRU5ErkJggg=="
)


"""SQLitely application 24x24 icon, 8-bit colour."""
Icon24x24_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAAsElEQVRIx+2SMQ4BURRFz+eP"
    "RgSFXiuUdmAvOnuwBVFaix0oR69XiWJkJu9dxUStmdeIs4B3c8+7CWB1vGo2GkCiGwT3Z025"
    "W6a0OJTabuYU/a6utzQmTucbeTosMHPM6JzJsCCbi6pxIjCH7IJXUIBLbYNXbUENPgFNeIAH"
    "B0Qq8sAG/mlQhSoScYrEz6yoiV5RHbyiWEWKU+QSWQKTiKJHMP+ArySA8f4S8uXHfp3e2YKg"
    "eZ/SxB4AAAAASUVORK5CYII="
)


"""SQLitely application 32x32 icon, 32-bit colour."""
Icon32x32_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAA8ElEQVRYw+2WsW3CYBBGn83J"
    "ckSsFJAZKFAmoKLIDEhRelo6twxAkSECS1DQpEyHKJgBFCmCwjG2PwqQ2MCHFH/dX93T0/13"
    "FzxNv2PgI4ntLY5aCTUky8vDISsWwMSA2evL83jY7xIQ1FEfoWS12Y+X611hD1FrNOh1OJUC"
    "RF0Z9Dp8bX9GFlnYPpUVHoksbJsk8sIHQBIGuAEAmISjATA5GtDNgPwMgBx7QE0PXAD+PAFw"
    "HERIzTe8AwNNDzSDCEcDXAw4XkS3ZeS6jqGSDwBAiHP+PYDdhYGjY/3fEFg4AswNSK+Pd+Cx"
    "psJH4BNIz/KLoHvVvwtPAAAAAElFTkSuQmCC"
)


"""SQLitely application 32x32 icon, 8-bit colour."""
Icon32x32_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAzElEQVRYw+2XIQ7CQBBF37aT"
    "BgRBAGdAEFxdFYJ79V4IDLKOIDgDhIRggLZ8REN6gw5i/wX25eXvzG4AmJaVJiNjlKUMkee7"
    "5fFsuJd5CNOy0na9YLOaEwiDAAixP13ZHS/YOEspljPqVoAYKsVyxuF8wzJLqNsPHskswSTx"
    "bnwAJGGAGwCASTgaAJOjAfUG5GcA5NgBxQ50AC9PABwHEVK8hn9gIHYgDiIcDdAZcHwR9cvI"
    "dR3DRz4AAAnOiQARwB0g/L7nHoffyzx8ActLnSM1Ic6bAAAAAElFTkSuQmCC"
)


"""SQLitely application 40x40 icon, 32-bit colour."""
Icon40x40_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAABe0lEQVRYw+2XvW6TQRBFz6w3"
    "VhSkuIkQVO4oLX5S00QpQsETgfxJyfsgUdDQ0WKg5wVCmwLJyu7MpMkXxYaOwjcS9wmO7t07"
    "s2MAs2F1ClyY8dKwyg6VZM/kO/Duajj+bLNhdbK/N/n09tWT6bOnjyhmu+QjMvl5+ZuP335d"
    "r5u/qcDy7Pnj6WJ+iIoW80Oax/TD18tlNVjMjw5oPVDS/OgAg0XFmHgkzVMK0DPBmFSAHkl3"
    "LQf7rWGVhOZB8yIF2DwgoY60TdZBoHvQehEDjPuA4g4212tx24g4gu6m5WDkdsSp+wabJ1Vs"
    "k9xFnGOLi8k5mBsRF/EWlyLW4thq8cTRdbB7Uky8xWaiLR5pDfFdDMotjkTrBf6x6oJMrUHt"
    "27s4xCyM2B7UYoQjzl3Euz7Y/3bAbzpo0g4mYgaSG4ARqKrep1VUQVz/Af9Rpg649yAidmG+"
    "6wL8EAZcFWAJrAXh1sDSAGbD6jVwDrwYh/cu/6q3qb6/Go6/3AAHgfhH95BcrwAAAABJRU5E"
    "rkJggg=="
)


"""SQLitely application 40x40 icon, 8-bit colour."""
Icon40x40_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACgAAAAoCAYAAACM/rhtAAABSklEQVRYw+2ZsU4CQRRFzxu3"
    "wgILEqUisbA34G+Y+D022/g9Jv6GEHsLW7STwmpm3rOARRbtuSbccquT8/bOy+wamwzbeZiB"
    "YRwyQRABq3ZmwJrm/OElbqcXXI1PSXZYQI/gdfnF0+Kdj/trs2E7j7ubMdPLM5SyePvk8XlJ"
    "Y8BkNCAXlwKcjAYY0GBQPcg1pABrBBg0AMWDUrUMlo2whoBcnVyTFGCuDtEZrLF+IGkQKNXJ"
    "JYkB+i6guMFc9VqceyN2p1TTMuixP+LQfQdzDRqxTbIdcXQtTiZnMHojTuItTkmsxb7X4pOK"
    "rsFSg2TiLTYTbXFHa4jvYlBusQdab+CvVedEaB3UdX8Xu5hC9/2DWoyww9mO+NAX9r8u8H2D"
    "Jm0wEBNI9ADdUU2zS6uYhHiOgEfAI+B/BzRYf+FXhFu1s58FpwbZ/Yb4Bmv/7XHDHhFBAAAA"
    "AElFTkSuQmCC"
)


"""SQLitely application 48x48 icon, 32-bit colour."""
Icon48x48_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAADAAAAAwCAYAAABXAvmHAAABm0lEQVRo3u2asUpDURBEz4sv"
    "IZiYmCAEUbBII9g+sLLSbxDEH7AXG6tX2WnpH0i+QcRK0qWysrQRQUQixiZ5d9ciEUJiZ5MJ"
    "mfJWM/fuzO7CjQCqaWcVOAeOgA0gYjbhwAvQAi4+06QbVdNOBbivlwvJ3nadtZXCTPN//+rz"
    "8PTBR6/fAfZj4Gy1lE9ODrYoF2NmHc1GiZ3NFa7vnpPu9+AsBg53mzWK+SWy4CigmF9it1nj"
    "9vHtMAYaleWYzDTI/6KyHAM0YiAyQ+b2f2EGQBQDBHM5AWFUMUMB7mQjSTICfFyA4AvY+AuY"
    "fAmZy6XQhADIgpgHRnTnxAMuWELTKWTiJlZOIRNMIZvqxEHaAzCQK6GJGA1m4h4I4h4YqPeB"
    "oD7MDYK6B6T7gOBO/Mc0qjwLqU+j+n1gPnZi6X1APIXMnSyg5YHJUULr/v8wsbvwC5g5Fokp"
    "8DEP+NiBGnKIYyFgIeCf/NUF5OeihFyYv+eAV2EBzzmGHydU0coBV0BbkHwbuIoAqmmnDJwC"
    "x8A6s/3d5hW4AS4/06T3AzhwPiEhFaQkAAAAAElFTkSuQmCC"
)


"""SQLitely application 48x48 icon, 8-bit colour."""
Icon48x48_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAADAAAAAwCAYAAABXAvmHAAABV0lEQVRo3u2asU4CQRRFz8gu"
    "2SCCED/AhMYPIKGy9Gf8iv0K/8VY2lJRWVobQyRiYtiZ9yxgFYHOxkv2llPNfe/e+94kE9ig"
    "X04dISzKcQAI9eWH3TbXV0Muztr18T+E8/q+4vFpzny5YlGOQ+iXUz8/zbm9uaRbZBLVX35G"
    "7h6eefuoyAAmowFF3iImDRUVeYvJaMD97GVNoNfJiCZlAXqdtVoyADNkql/DjB8CyVyOQNoo"
    "Zk3AnVhTUiHgrt0B2+6AyUvIXC6FdghATGIeUE+h3x5wQQntp5CJm1g5hUwwhWxvEidpD0Al"
    "J6GdGE1m4h5I4h6o1OdAUl/mqqTuAek5IPgmPrCNKu9C6tuo/hw4jjex9HtAPIXMnZjQ8sDu"
    "KqFV/wMmdhfugJljQYyBb3nAtw7UcII4GgINgYZAQ6Ah8Cd8/5VQvPyiHIfj6EANlU7UX20A"
    "vgCH2zVzfKl5NAAAAABJRU5ErkJggg=="
)


"""SQLitely application 64x64 icon, 32-bit colour."""
Icon64x64_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAB4UlEQVR42u2bvUoccRTFf/fv"
    "uIsIKwwsFunCrk4REOI2gnYWgq2FeYBgmVeYPIK19olvIKSTlIuwGIgfYKWFSBamEHeXmbkp"
    "dHT1Eebe8wbnzLnnfsyM8IyFtD8PfAN2gSWgSb0wBi6Bn8B+lvYeAOSZ/EfgGOjON2f4EM8R"
    "BakV+7xUboePPIwLgCtgK0t719L63p8T5VSEZGtlkfXlmJmaka9QlMrviyHHgztUOVfhcyTK"
    "HpBsfmqzkcQAlKq1FEAENpKYvCj5dXafiLIXATvNKLDWjSnKehJ/j7VuzMnff4zzcicCOu1W"
    "gxAwI0AI0G41uBmOOhEwG0QoSkwhiADMRgCKnadfoWL7JIAaFECnBbDuAFTNCVBZ4MUBuekM"
    "8BLAYAm8cYAadIB6G/QM8AxwB1QZYDAE3w9CngGeAXgGmM0ADGYAbx3gk6CfxEw7AIPbIL4N"
    "egZ4G/RByEvAQ/A1A3IfhU23QT+Lewb4OmztIuQZMH0R8qOoT4K+Dvs3Qsa6ANa3wQoB43AB"
    "XAAXwAVwAQyjYV2A4CXgAsDEMP9R4Ol3Uqv4E4AjwwIcBZBDYGCQ/ADkMGTp6gTYNibCANjO"
    "0tXJy1/SC2m/CXwFvgDLTL0zqAly4AL4ARxkaW8M8B8wvUimfQrs3gAAAABJRU5ErkJggg=="
)


"""SQLitely application 64x64 icon, 8-bit colour."""
Icon64x64_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAABe0lEQVR42u2bvUoDURCFv3uz"
    "GkQwsBAsrMUUgk1K01lY+Tq22/o6VgFbyzRiJbZaiBBIIRrc3bG43JjNI+ycU+1PNWfPnPlh"
    "b2AHo2ph9Birahq278Nu4IfDASflAUUMvQq8bo335Tdf66ZDRMjBhwDXF8dcnpUMehZ8RtMa"
    "jy9L5k8fmCUSivzy6nzMbFIC0Fo/syAEmE1K6qbl4fkzPRtVCxsWkdubU/aKgAf81sbd/Svr"
    "uqUAGB/tE2OSiAfEmGJ+W/4kAmIINC2uEENSewFg+Pn6GTnaRIA5JMCQAjYEYOaOgCyBjQJq"
    "1x6gFMBhCnQUYA4VYCqD8gB5gBSQPcChCe42QvIAeQDyALcegEMPoKsAdYJaiblWAA6nQTQN"
    "ygNUBtUIKQVkgv8eUKsVdl0GtRaXB2gc9rYRkgdsb4S0FFUnqHFY/wg5qwJ4nwYzIs4hAkSA"
    "CBABIkAEiAARIAJEgFNsTo56DH5VTYMUkC+8qaBzeHob3o7P/wFCgTPVWRSf5gAAAABJRU5E"
    "rkJggg=="
)


"""SQLitely application 256x256 icon, 32-bit colour."""
Icon256x256_32bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAQAAAAEACAYAAABccqhmAAAMEUlEQVR42u3dW4xdVR3H8e/a"
    "58yZ6UzndErbMQ0t0Mq1gkCZSlQuiZoQEhJjYrwFExIf6oOE8CCIBufUqqA+GY1RE33RqKm+"
    "6IuJqEG8BXohchEhIKQUEaRlOm2nnc7MWT7MaQMy5+I+kM7a+/shQFLOGZI1Wb/9///3LdCn"
    "emPvqkDcCmwFLgMuBDYAK4FRoIqkvOaBI8BR4ADwFPAosC8S9k03rjrczw8Peb40uvPBFVmz"
    "MkHkI8CNwNrWZs/8fUlvuWYrFF4Bfk1gVzNb2HPk7quPv6UBMNrYO5gR3wV8Bng/sMbfhXTG"
    "HQR+B3y7SXjoSOOq2Tc9AMYaD50dye4CPgUMuebSsnMC+EGgec9U410vvCkB8LZv/C07cWz+"
    "4xDvbfX2kpa3AxA+NzRS/elLn728mTsA6l96eCg0Fz4P3AbUXVcpGdPAN2NW+er0F6888X8H"
    "QL2xdzQQ7wTuAAZ6+T8OVDNWDGQMVDMGssBANaOSBX8VUk4LzcjcfJO51r+PzzWZm2/2+vU5"
    "4OuR8LXpxlVHeg6AsZ37BuNC8wvAXXQ5jRcCrFoxwGXn1Nk0Psx4fZD6iiq1qicEpDfLyfkm"
    "08fneXl6lmdfnuHR/dMcPj5HjF2/Og/cEyrZV6bu3vqG4eCSmzsuxNtbR/5qp41/9lkruPai"
    "NbxjwyjVikd66a1Sq2asHa2xdrTGlrNHueGd4zx+4Ah/fPIgLxw63ikIqsAdcSHOAPd2rQBW"
    "NfbcCPyIDqf4xoYHuObis9h63hjDgxV/O9IZMjO7wL7npvjTPw4xNTPX6aMHgU8ebkz8um0A"
    "rNyxe6wSw5+BLe1+yvqxQT44sZ5z1g5jey+dec0I+1+Z4Zd7XuTFqY6XAPx9IcT3Hp3cNnXq"
    "D0436qM7d1crMdzWafOP1we5+dqNnLfOzS8tF1mA89YNc/O1GxmvD3b66JZKDLeN7tx9urU/"
    "Xb8PX7/9YuC7wPBS31xXr/HJazaydnTQFZeWoRW1Cue/bYSnXzrGzOxCu49dlsXwqxP3f/8/"
    "pwNg7Mv7KrEZPwe8b6lvDA9W+NC29Wxcu8JVlpax4cEKa1bWeOrfx5hbWHIyOAycXPGBT//2"
    "xO+/F6sAcaG5Cbip3Q+d2DzG5vGRXk45SDrDNo+PMLF5jAeeONjuIzfFheZ3gKdPzQCuAzYv"
    "9cmzVta4+vzVXtAjJaKSBa4+fzVnray1zYjWnm+d54989LXzgP89+teHBjz6SwmpDw0wsXmM"
    "3zzy8pIZ0drzP6yO7ti7nhgvWepTtWrGFefWIYD7X0pIgCvOrXP/31/h5NKXDl8yumPv+moW"
    "uRQYW+oTG9YMsXKoSvTwLyVn5VCVDWuG+OdLM0v957EscmkV4ibanPrbtG7EI7+UsE3rRtoF"
    "wDDETVXggqX6/4FKYLxes/aXEjZerzFQCUudEqwAF1SBdUt9caCSMTJUdf9LCRsZqjJQyZhb"
    "WPLCoHVVFh/m+QZZFqhVgv2/lLBaJZC1P4U/WqXN8/0CEEKwApASFkLo9Nivoe7P7DcBpMKq"
    "dtr30f0vJa3bHq52+7YzACnxBMgbAFYAUqH3f5cAMAGktAOgnwoA979UaF0qgOgMQEq6AojO"
    "ACRnADlbABNAKm0L4P6X0m4B+qoAok8CkgrcBPRQAZgAUikrgNjDD5CU6vH/NW8GyvVtSUkn"
    "QPebgQwBKen9n/tmoNj6S1KqAZB3CBhbQ0D3v5RuAHQpATKXSCqv7qcBrQCktCuAvAGAMwAp"
    "+SlAzgCIngWQCrH9Y84ZgJtfKnIB4AxAcgbQcQJgAkjpFgD9PhDE/S8VtQPwOgCpzJwBSM4A"
    "8vcQkgpYASz2/z4RSEq7Auh8CM86H/0lJR0AzgAkZwB9zAAklW4GsLj5fTOQlHYL0Hn/ei+A"
    "VOIhgE8Ekoo+A4i5WwCLAKnABUAPQ0BLAKmwvA5AsgLoPAeQVMwEcAYgWQG07/+dAUgJB0DM"
    "eR2AR3+pGBVA7leDOQOQnAFIcgYgqTQzAEnFZwsg2QK0Kx8cAkpptwB9BEAvP0BSUVuAaBMg"
    "pV0B9PFmINz+UpkrAFsAqbQzAN8NKCUeAP1UAJ4IlIodAdVuR3+3v5R2C5D7ZiBbAKmsLUCr"
    "+jcApMQToMMe9pmAkhVAuy9HXw8uJR0A/VwIZAsgFboEcAgolbgF8N2AkhVAhwrAFJAKWwF4"
    "L4BU5ADweQCScs0A3PtSaVuAxScCOwOQUm4BOl8KaAsglVj3uwENACnhCqBzG+AMQHIG0GEO"
    "YAxIhY0ArwOQCt4CGACSAZCnBXAOIBVZ1m0CICnlCUDfMwBDQCpfCxB7+wGSln0Z0EcF4PJJ"
    "ha0AvBBIKufBv3sFQIzOAKQClwCd7wVwBiAlXwHkfjOQbYBUbFkf1YOktDuAXh4LbgpIKbcA"
    "/QWAayiVMwB8M5BU7ATIXCGpvLpcCeh1AFLSBUDs52YgZwBSeWcAPhBESr0CcAYgKf8MwEWS"
    "SjcDOH0vgFMAKekZQK57AUKPPYSk5S3kmQF4J6BUhBYg792AcfEfhoCUeBOQ+5FgzgCk5GcA"
    "kDcAvA5ASr4FIM8MQFLxWQFIJa4AuswAfDuwlPYMoI+bgXwegJR8AvRTAXg3oFTg/d99BmAC"
    "SKWcAcTTUwBJKdcAMX8F4AxAKmEFEJ0BSAU//vdwFsAEkBJPgLwB4P6XCr3/e7gQyCGAlHAA"
    "9PNU4GgFICUdAP20AD3VEJKS5evBJQOgXfngDEBKuwXwzUBSeQOgrxbABJAKnQAdHwrq/pcK"
    "sP9zPxTUGYBU3hlALz2EpHR1vxnIBJCSbgE6beHMo79U8BlA7hYg4gxAKnACeB2AZAXQ5ss+"
    "EUhKOwB8M5CknBWAbweW0q4AvBdAcgaQJwB8M5BU7ATwOgDJCqBd/2AFIKU9A+inBfC9QFKh"
    "a4DuQ0ATQCpsC5D19W1JSSeAFYBU4gqgy+3AzgCktAMg5nw3YPQsgJR8AHS5mq/7hUCuoVTO"
    "GUBPTYSkZPVwL4AJIBW0AOjlbsDgKkrJzgC8G1CyAsg1AzABpEIngDMAyQqgXf/gdQBS2jOA"
    "floAOwCp0LpWACaAVMIKIFoBSIWfA1Q7fS3iU4Gl9Dd/zNkCWAFIhT36dw0Ad79U7ASwApCs"
    "ANp8OXoZkJR0AHgdgKScFYALJBW5AvDNQJIzgDbfjJGIzwOQki4B8j4TsNtFBJKKWgE4A5DK"
    "OwNw70vFrwK6twAmgVTSFsDdL5U3AHwxiFRsmUsglZdnASQDwBmAZABYAUjOACQZAJIMAEkG"
    "gCQDQJIBIMkAkGQASDIAJBkAkgwASQaAJANAkgEgyQCQZABIMgAkGQCSDABJBoAkA0CSASDJ"
    "AJBkAEgyACQZAJIMAEkGgKRebTAApPIaMgAkWwBJBoAkA0CSASDJAJBkAEgyACQZAJIMAEkG"
    "gCQDQJIBICmhAIgug1RKzQyYcR2kUprJgCOug1RKBzPgX66DVEoPZsDTwJxrIZXKHPB0FuAZ"
    "4JjrIZXKsQDPZDHEx4BDrodUKodiiI9lhye3TQF7XA+pVPYcntw2depCoJ8Bs66JVAqzrT2/"
    "eCVgCOwGnnBdpFJ4orXnFwNgOPICsAuvCpSKLgK7WnuecOpPV+3YvZEY/gBsco2kwnqWEK8/"
    "PLnt+dMVAMCJWDsATLo+UqFNtvY6rwuA2cblMZDtAu6zFZAKWfrfF8h2zTYuj28IAICpxtbZ"
    "QLgdeNb1kopV+gfC7VONra872/eG5wFMNa56HLgLeNU1kwrhVeCu1t6mYwAALKwf/jlwK3DU"
    "tZOSdhS4tbWn6SkAjm7fEpsZu4DtVgJS0kf+7c2MXUe3b1lyrhc6fXu48Uyo8uqHA3wNOK/b"
    "5yUtCxF4LsKd86z+xUzj7W2H+j1t6FU79ryTyLeA61xbadl7gMCthycnHun2wZ4eCnp4cuIR"
    "QnYDcAuwH08TSsvxqL8fuIWQ3dDL5u+5AjhlvLEnnAxxY4zhZuATwEVA1bWXzph54EngJyHE"
    "H9dieP7lxkTPB+hcPX298ZcsUDsHeDfwMeBKYDUw4pxAesuP9MdYHPA9zOJdfX+NnNw/3XhP"
    "8//9YW/KZq3v2LM+RK4ELmz9vaEVBkP+vqS+nWht+gPAU8BTMfDw9OTEi/3+4P8Cp9h57X9h"
    "4FQAAAAASUVORK5CYII="
)


"""SQLitely application 256x256 icon, 8-bit colour."""
Icon256x256_8bit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAQAAAAEACAYAAABccqhmAAAIhklEQVR42u3dzW8eVxUH4DPz"
    "ftixHcdNYkuhSZtEFUUgqgpFKotmC0t2rMr/4v+FHTu2rBDtgkXEAsRHWQAqHxFpUyUGOXIc"
    "+7JIVATVOzOecdvce58nUrrp61Zjnd+cc975aOIcXdq/lwL4Qj3ev9Oc189qFDzUGwiNwod6"
    "g6BR+FBvEDSKH+oNgUbhQ71B0Jxn8S/mbVxYtLGYt7Fom1jM25i1jd8CjHRymuL42Wkcv/jn"
    "k+PTOH52em4h0Ewt/qaJuHRhEd9+bTtu7W3E3vZabF+Yx3Le+u3BOXn67DQOnjyLBwdH8ecH"
    "h/Gbjw7i8ZPjSGlaCMzH/g81TcSrly/E3TevxLeuX4z5zJkevijLeRtXLy7j6sVlfPPVi/H9"
    "t/bit3/7V7z/4cP4+6dPBgfBoA6g7+y/s7GId79xOb5zcyc21mZ+O/AVOTw6iV/95VF88IdP"
    "49Hh8Zm7gOasxX9tZy1+cOdavHZ1I4z38NU7TREffXIYP713P+4/OjpTCJxpUN/bXov37t6I"
    "m7uKH14WbRNxc3cj3rt7I/a218aPAF1n/93tZfzo3Ruxe8b/APDl+fjgKH78wV/j44Ong7qA"
    "Zkjxb6zN4off/Vp8/dqWIwwvuT/e/3f85Jf/iMOjk94QGPQtwJ3bO3F7b3P0phH48tze24w7"
    "t3fiF79/2D8+9P0Ll7eW8c4br7igBzIxa5t4541X4vLWctgOoKv9/95be3H3zSvRqH/IRkoR"
    "73/4MH726wedY0DnCLCct/H269sRTYTuHzLSRLz9+nb8/HefxNOOS4c7A+D6lfXYWp9HMvxD"
    "drbW53H9ynr86Z+H4wLg1u6mMz9k7NbuZncArJr/F7Mm9raXen/I2N72MhazJo5PPl/Il/bv"
    "pZUdwGLWxub6XP1DxjbX57GYtXF8cnK2EaBtm1jOGvM/ZGw5a6Lt+Ap/ZQA0EdE0jQ4AMtY0"
    "TedTf/qvBJQAUKx5V90n9Q9Z66vhed+n7QAg8wQYGwA6ACi6/nsCQAJA3gEwpQMI9Q9F6+kA"
    "kh0AZN0BJDsAsAMYOQJIAKh2BFD/kPcIMKkDSJ4DCAUPAQM6AAkAVXYAacAPAHI9//c9FVjx"
    "Q9EJ0H8zkBCArOt/9M1A6cUfINcAGLsETC+WgOof8g2AnhagdYigXv1fA+oAIO8OYGwAhB0A"
    "ZL8FGBkAybcAUET5p5E7AMUPJTcAdgBgB9C5AZAAkG8DMPWBIOofSp0AXAcANbMDADuA8TME"
    "UGAH8Hz+90QgyLsD6D6Ft91nfyDrALADADuACTsAoLodwPPi92YgyHsE6K5f9wJAxUsATwSC"
    "0ncAafQIoAmAghuAAUtALQAUy3UAoAPo3gMAZSaAHQDoAFbP/3YAkHEApJHXATj7QxkdwOhX"
    "g9kBgB0AYAcAVLMDAMpnBAAjwKr2wRIQ8h4BJgTAkB8AlDoCJEMA5N0BTHgzUCh/qLkDMAJA"
    "tTsA7waEzANgSgfgi0AoOwLmfWd/5Q95jwCjbwYyAkCtI8CL7l8AQOYJ0FHDngkIOoBVH05e"
    "Dw5ZB8CUC4GMAFB0C2AJCBWPAN4NCDqAjg5ACkCxHYB7AaDkAPA8AGDUDkDtQ7UjwPMnAtsB"
    "QM4jQPelgEYAqFj/3YACADLuALrHADsAsAPo2AOIASg2AlwHAIWPAAIABMCYEcAeAErW9m0A"
    "gJw3AJN3AEIA6hsB0rAfALz0bcCEDsDhg2I7ABcCQZ0n//4OIFKyA4CCW4DuewHsACD7DmD0"
    "m4GMAVC2dkL3AOQ9AQx5LLgUgJxHgGkB4BhCnQHgzUBQdgK0jhDUq+dKQNcBQNYNQJpyM5Ad"
    "ANS7A/BAEMi9A7ADAMbvABwkqG4H8Nm9ALYAkPUOYNS9AM3AGQJ4uTVjdgDuBIQSRoCxdwOm"
    "538JAch8CBj9SDA7AMh+BxAxNgBcBwDZjwAxZgcAlE8HABV3AD07AG8Hhrx3ABNuBvI8AMg+"
    "AaZ0AO4GhILrv38HIAGgyh1A+mwLAOTcA6TxHYAdAFTYASQ7ACj8/D/gWwAJAJknwNgAUP9Q"
    "dP0PuBDIEgAyDoApTwVOOgDIOgCmjACDegggW14PDgJgVftgBwB5jwDeDAT1BsCkEUACQNEJ"
    "0PlQUPUPBdT/6IeC2gFAvTuAITMEkK/+m4EkAGQ9AnSVcOvsD4XvAEaPACnsAKDgBHAdAOgA"
    "VnzYE4Eg7wDwZiBgZAfg7cCQdwfgXgCwAxgTAN4MBGUngOsAQAewan7QAUDeO4ApI4D3AkHR"
    "PUD/ElACQLEjQDvp00DWCaADgIo7gJ7bge0AIO8ASCPfDZh8CwDZB0DP1Xz9FwI5hlDnDmDQ"
    "EAFka8C9ABIACm0AhtwN2DiKkO0OwN2AoAMYtQOQAFB0AtgBgA5g1fzgOgDIewcwZQQwAUDR"
    "ejsACQAVdgBJBwDF7wHmXR9L4anAkH/xp5EjgA4Aij379waA6oeyE0AHADqAFR9OLgOCrAPA"
    "dQDAyA7AAYKSOwBvBgI7gBWfTClSeB4AZN0CjH0mYN9FBECpHYAdANS7A1D7UH4X0D8CSAKo"
    "dARQ/VBvAHgxCJStdQigXr4FAAFgBwACQAcAdgCAAAAEACAAAAEACABAAAACABAAgAAABAAg"
    "AAABAAgAQAAAAgAQAIAAAAQAIAAAAQAIAEAAAAIAEACAAAAEACAAAAEACABAAAACABAAgAAA"
    "AeAQgAAABAAgAAABAAgAQAAAAgAQAIAAAAQAIACArDQREZf27yWHAuryeP9OowMAIwAgAID6"
    "dgD2AFDf/K8DAB3Af+kCoJ6zvw4AdAD/SxcAdZz9dQCgA/g8XQCUf/ZfGQBCAMov/s4AEAJQ"
    "dvH3BoAQgHKLf1AACAEos/gHB4AQgPKK/0wBIAignMIfHQCCAPIv/MkBIAgg38I/twAQCJBP"
    "wf+//wDtz6tSLB63yAAAAABJRU5ErkJggg=="
)


"""Small icon for clear list button on start page."""
ButtonClear = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAgdJREFUeNqkk8tu00AUho9nfKnDJU5j5NoJkTB20+JU3ZR1"
    "F+xaKhZIkRCSAYkdL9CqEgtW9B14BVa8AiyQQCELJCRUFUgXMZAKqOPY8WWYsZISaFohdaTP"
    "njnz/2c84zMcIQTO0rg3L7iT5oqUZ6P+Q8rPaSJ0SvKmbt2zdcu1Wf8kEcoygH+hu7qMhdKa"
    "Vru5qNXWF7GgrLHYNO3UBBTXsN0GCT+JJPwsGtbdBov9VwK60rJ0rrZaKjfM7Z2vsL3zDZTy"
    "NVMqVFfZ3LEEKX1MwMYPKtYdJ/I/oiAIgDHs7yH9yi2HzY00Rx6UpTTTCJLBjQuKsyLLRSON"
    "f4Hv+zlp7EOhoBjnL1orTDPp4dP06EBlDnGucXXdiYMvMExDaLVa4Hke7D9ahozsAj9bd9Le"
    "rksy8pLqB/lfiBMABv2c2+W560sIRUpv0AGvvwftdhu63S6kQghEjADESJGK1SWmHfsQK0SK"
    "CpzYVKuN+d7hW4izHgg4gu/ekxwRD3Mw50NR1+YJ4CbzMC9K6BboNu6rlfpCnH2QeeSDhMMc"
    "VXucMx4zZCmRS3OXFpiHeVGSgIUFaUOrzJgC/IAZutKYcZuMMfSqYiKe32BePgjIlllXbREf"
    "YkLYif65XMHBZv7uHzz/u34xYKM2a79/523xwQCi16/2OzTcOV7pT0+/iRxE3Fmv828BBgCY"
    "syym9ECFNgAAAABJRU5ErkJggg=="
)


"""Large icon for detect databases button on start page."""
ButtonDetect = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACIpJ"
    "REFUWIXFl1uMXVUZx/9rrX09++xz2WfmzJnTubXTQlung7SFUrBALQba1JAQ28gDD5qIShQj"
    "gYRoTKiXB0M06oMooQ8KMVpsDJeAJERagXZgqGmBTmnPFDr3mXPm3M8++76WD05rQWmnSOJK"
    "/tkrO2uv77f+37fXyiJCCPw/G/0kH934wFH90wIgl3Ng89ePyQ4p3Uw5v16T2faIi2tDzi1G"
    "SEOi0nE3ig4Jwt9IxOzDR36+x/lUAdZ+7dlhDTiYiem5NZmknjdN1mkaiKsKOInQ9DwU7TY/"
    "U6w6pxZqdZ+TL53av/vo/wywffshqbSy/AMG+tD2gV5ttWWRZquI6ZkCyovTWChOwTSSuOaa"
    "LRgcXIvOzg6UWzYeO/SOa/v+bxxDf7jwq53eJwIge59mQzGMZGP6Z27t7dcJt3Fk5BmcPnsC"
    "WiIdhIgIYYxRQqKo3UJgt6Xurj58494H0NPTjT+9dtJ7bXxmQlONa9/67e725QCkj75Yp3rf"
    "SyvG+h29ffrU9HGMjL4ET1PCZE/PGRLWT7KgPsl4s8iZaQVJs19YPesqjj306C/3sbt234M7"
    "r9+iUiH6Dxcmfwbgm1fkwOov7x9SKHvzi4NX64FTxN9Gno1gxjzmTP+xK+YdTyQMp79/lbR1"
    "69a+RDxuekHARkZG5l4+MtbZ8LWv8rar777tbnrd5hvw0+cOObW2t7Nw4CuHlwWwffs+aT6b"
    "P7mxK79mRUwlR956Hg3iOWk+8ZPebHIuk820EolE+/bbb1+1bt3QDstK3yEEwkajMX7o0KG/"
    "Pv7E7+am7MQPY1w279l7PxxO8MTrIwuaog2e+P099scBXNgHJjqsrRpDd18iRSamxlAn3EtK"
    "tSdX92anBgb7SytXDhTXDl61oOvaO5qqfgAQj1KqJpPJgeHhIXP3HTv87iR+3Qjq0dGRV5BQ"
    "dVxtWWazVd91KQcu1ADxg+uycUvlPMBUaQIKsd9f2UmP5nvzlb6+nkou11W3rFxTVY3J0uLi"
    "BytU6SSl8g1hEAhG2JgWU6cHu2OVui+Pnp74x5YNG24iPcm0fmpu6kYAT18WQCbi1qSiKK1m"
    "BT5Cz9TpsWw228hnu+sr8/3VfDZb9SQpopRGlDb9QqF9UHKcvzBZpnOlUlylciaX6+jsqNWO"
    "TjfbGxuNhpLUdEIF33YpBy6kIAiDzaakIgxDRAKwDPqeZaXtjlymmcnn61KShpIkhYrSDB1H"
    "CbOMBVI6HQSKG6W64nY+l2t0dHS0cmn5ParIrF4vQ2MqgtBbTwjIJQHI3r0siNwulckgRAcj"
    "XMml2IRpmm6HaTkJxkJNU6JuRQmNuhSqqhq0VDVwXTdyXSVSFClSTNMxzbjblZLnqaSg3iyB"
    "hwAVggzs2td1SQBx4EDEBC+23DYI1RCTk2Ez1LOyrIdyXA4aUSQqlUhEqRTv3qSHo6OjQblc"
    "jhKJRBSPe5zzSKTTim8oRtAM1AQlTMQNC23XQRA44twLjyxcNgUkio5V2w0QwWBoXaTmymuB"
    "ELhoQ11Y+Nc8e/bsEZs2bRLA1IcmC+CjVOerFEZDSUpisVkFFfyUuMSBcwHA951XKnYtiKIQ"
    "cS0v8dC8KQgCqRXYMmOMWBYjqqrS6ekEGx8fl8+dOyfJskGllkopZcRedOQo4lKl4d6gKXFZ"
    "cIrF+qIIQ+/Vjwv+IQAOPlpqFN0gcpGKr4ZBV6x9c6x5s+M4WhAEzC35TFUdptm25Pu+7Hme"
    "bNuB1FYUylyZNoKW/urxueGmE+zIJVeyiBPMVOfaIQ+OLAtgznaOOpFbnK7NCCGqMPVh6rq9"
    "33/nzHSuUSolfFVlvh9JxSiSoyiSdd2XfN+QwjCUSpVKbHx8PjN2rvrjrNEta8oKFOtFlFpF"
    "J4y0Fy8F8KGzoGfb/dcQyo5u7d2sp4yNgKihFp52jVTp4bs/v+6lrt5MkzEacq4LA4DneXS+"
    "uWgcePHk1rGJ8qMamJUz1iscMRyZeBXy4siJ02+//tllAwBA7y3ffcRU4w9t7N4U09XVELDh"
    "8smoGUy/ocf85wa6Eye2bcidGzld7i7MlDdUavYtjuPvyqiWakp5COg4vfgeujM1LLz7Andd"
    "f/+JscK9ywYge/eynoWe0aQWv+pqa41hqHlIchx+NCtC0vSbfpXaQZMJEUQKFb4CTTNYmjGS"
    "QhgKFKpnYPuL2DVYRl9vHvufOhjJkvzgibHCL5YFAABDQ/uUqlX7ESX41prUoN4Z7yKMqiCg"
    "ICREyJsghENEFIIwgBNU3CoKtbNIGxy9Zh0xZwrZTArplIU/HHw+1FXtzrdPn31hWQDnW/5z"
    "395MqfTnmKxbaTUViysGM+QYFKYi4D5s30YraPO617CbXlUiC0ea64c3WpIiS7w1j7ioI5tJ"
    "Q1IUPP/S330K6drCxMTYsgEAYM2u+9VWC7dRsC2MkFs5xDCEiAkCjxL6Lhf8sOB4IxDNl5XC"
    "M/eB0gcHhq5X4olMwq9OIq1xZDvSaDs+Ro693bS9xqqZmcbisgH+W+vfdl968rXHagDIkuiS"
    "SDaT2SlJeKJzxYBv5fpyXmUSHQkd2Y405hcqODsxM1Vv+2tnZ2cdIYS4YgBCyPmgbEnykpTz"
    "/YRhrIkZ6uNxM0m7egZ6/GYJnekEujrSOPP+JKq11uhY4YObAfhXdDNaCk6XAqkAYgDiABIA"
    "UgAsAB0N27Yr5fp3GvVaeaIwtsiJjLliGbPFMlb25+F63saUad4BQF02wEUrpxetXFkC0S6S"
    "DsDwowjFxerjbds5Ozs92Q5DzhdKFcwXK5AkKgjFFgDqslPwEYCPC65e9FSX3MmY8dgX4rHY"
    "TlmibQGQIIjc+VL5JgCzV1QDH4GQ8O/8q0tA5yUtuUSXxhNVVZPJeOwuLsRc2HafrLnuLIDg"
    "kxYh8J9/ALuof36MuEgcQLQkDkAIIcQ/AcljIy+SCczdAAAAAElFTkSuQmCC"
)


"""Small icon for export button on start page."""
ButtonExport = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAiJJREFUeNqMk8trE1EUxr87GfOYR9KKLUQwCUi6jdK9CkUI"
    "WoluIm5dBQTXroKIZOPWTSGb/A26cCW4EFQU0UUXaRERNTXpJM1k8pyZO56bR5shEnvgm3uZ"
    "Offc+/3uGeZ5HkTk8/lbNMRxuqiRXoiJPHszHA7j5XJ5p9vtot/vw3FcNBoWzTnC4Qh0XUc0"
    "GkUsFkWhcPdBIBCAr4AIx3HQbrdhGMa4QL3ewWDIoao6HNeBFJCgqBHfUaSlB2WAMOgxPhEm"
    "On0BSp8s9KaL3bHmY97Cp1Kp9DKTyWxzztHr9aZWHGIQhqZp5D+GarX6inI//qvAZrFY3J6H"
    "WD800R2MEAwFoekqYgTx+s072YeF++IGPvwX4p/DNrqjESIEzuYr+L63i57VQbPZ9ETOQoFF"
    "iCfeOXNhHrWQvZelaywIdpdJn5dC5NwBtwfoHTXxs1qFbdswDgzsG/vP6fM1YZvNOjGXy20m"
    "EonH8xBt18bq2iqSF5OIX4hD0RXfBulz6UfyyW58AeKPXwdotBrY2/2GL++/YtgfYOv2FtbP"
    "r2NjbaPIGHtzbMGyLG8GsVarkX6j2TZgOX2cOasieSmNEQGdLn5KS16T3h2fgKjKS5uJpK5o"
    "KD8rI5VKtTqdzlvfLVABRZblcbMEg8GxhUAoAmVgQgoxqFoEV25cHfdCpVJhItdXwDRNgyA+"
    "cV1q1wlYJkQhHpAkSYyemNOfaIhRxF8BBgAPDR3S0EHTJwAAAABJRU5ErkJggg=="
)


"""Large icon for import folder button on start page."""
ButtonFolder = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAp5JREFUeNrsl01oE0EYht9NNj8btMWIhHopEhAKRgURBC+2"
    "0uLFU/HkwYMIUhEUBIMpPWlBFHtS9CB4F48iNl5r8dTSnmKjCFYpHpL2EJP9m/Wb2Z+YH2M2"
    "0c1BlwzfZjOz3zPv+81kV7IsC4M8QhjwIb+bl8SJJPkfzMdIdsxQmP5N9xck9jrXm4vuCi//"
    "gUkcpptNp6fuzqGDnR/yWcFKba1Bgb6TA+cOnrk3m8hch2oYqOm6iCpFzTRx5XMKlYqGV5OY"
    "K+azruVr7QAuUjvgJzuf8NjZhdyuQ9dgULJOx8kvM1iaxOzGolDiOLWnwsa3tz3/7xy78OwW"
    "v6vlmCQiYyI2XGuKJs3WoFmL7y4Z6ma7xkRkWfQvvM7O09ecUMDpe4nDFFdXfekfVxQMJ5OI"
    "UZSj0Y6QDUAWpAYL6EL6xNXnNy3T8AVQrVTxaWUF+0dHoSQSnlLSL6KrDAVv+cvMvhZihg6m"
    "qr4AomEJY+OnsJ5/g72pFPaNjLTY1g6GcoZsq+oAksUHMdP3MjB2ysicnsD75WVsbW52NYbZ"
    "Flwmlscy5RUKWCYBmKyntahvl5E+eqT7DWxi/MbSw/MPfi7CEJ8960EBb1bV7133DcfiXh14"
    "NcABrD4AfO0ffLItAH1Y4BuA8tQBmFuE/Vng6y9Y5LL3gsFb4Kge7nUZ9gbAQHnDTTVAVIHV"
    "gNlSA6GgFaBP8zJk4ofAANopwIIEcBXQnSLcLpWga2ogAJFoFbpbhDVNXFOGhoegqdVAAKIx"
    "BZRXEQBVGyC2UypD04NRIBqpgfLGBMDCS2BmCvFkcg891xmBAMhhmR5aEX+0SOfFLQwXvmLj"
    "yf1cJMgXko/fUKDcu/l+HOeqcBucRzTpL+fmZa86zZT++XfD/wA/BBgA+029gcH4w1sAAAAA"
    "SUVORK5CYII="
)


"""Large icon for home on start page."""
ButtonHome = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAyBpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl"
    "dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l"
    "dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu"
    "MC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpS"
    "REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt"
    "bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v"
    "bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv"
    "bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu"
    "MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w"
    "IENTNSBXaW5kb3dzIiB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOkNDMzdGODExN0VENTEx"
    "RTBBRjEwRENFMzEyMUUzMjQ1IiB4bXBNTTpEb2N1bWVudElEPSJ4bXAuZGlkOkNDMzdGODEy"
    "N0VENTExRTBBRjEwRENFMzEyMUUzMjQ1Ij4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVmOmlu"
    "c3RhbmNlSUQ9InhtcC5paWQ6Q0MzN0Y4MEY3RUQ1MTFFMEFGMTBEQ0UzMTIxRTMyNDUiIHN0"
    "UmVmOmRvY3VtZW50SUQ9InhtcC5kaWQ6Q0MzN0Y4MTA3RUQ1MTFFMEFGMTBEQ0UzMTIxRTMy"
    "NDUiLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBh"
    "Y2tldCBlbmQ9InIiPz41BSmtAAAC8UlEQVR42sRWy27TQBSdaztpmlSUBRSxAdEFQt0VuuiK"
    "BV/Rv2CFBHs2iA3/gMRXVKyQQDzElsemYkNRRUlsJ37NzOXO2E5sj50QhIaotxOPPT5n7j3n"
    "ZgAR2f/8eAcPj9V4jWKfYmQJd0rxkeKbV0zsv7h/+Gh3Z7RnA/3kbPr56Nmbx5pAUYKtGzvD"
    "W9/H8VsbBK5fHh4Q7pYuQTlJPCSzpAeNVWqgyADQf0FhhYHGQoRqBkCxkmiJQJ4BqGaAJlGx"
    "skRAY7FaBiQiZ5ZKUGDVMgBSMk41kFYIENZcA2UqiJWwpQHZUQJKgB0bKiyjBLkL/rwEXGKW"
    "ZDKZJSLiQqYZXQsh6Y9JoFc7wBzXcVzPBa/nOv3hhrs56LkD12E9hdUsgSIgCH5pCihvIoh5"
    "EEY8jDIRrzANbUYKGlOK2XnIJkDMNonExVH/qkFA7V5UOlQNWCIfz9KJP8sC0S5ULFPauIaG"
    "/dg04XGUCN9oRLkGpNEw/Cjzx9PMJ2BRPttCAFZcNzWApg3zTjhnkHGZnfnJecJlUuwJ9BJs"
    "gShf1zWyeodRbjNtSNsvbTBLRfQzSMfFrqEG1Pa9et011voAyrkNF41IE2BhzMMxpZ2mEUCx"
    "bG5hWRpYxzNo2LBNhMKPs+lkxkOdbr0SOsq6rgygQUALsk4g5Zj6JTgUK7pcBh33oEUTzTWQ"
    "u8FwQUy+Zqp/LB4sZafPKWBuUL1nDkn3Ya45c/OYP5S/BpGZLtD+LncO9bxBu6mgMg+them4"
    "L6sZWJyIEGGFf//diQjRJKA7ADhWCMiKCMl7anSQ5T8gls6E1AukxvKEEDmRXLFOV2NrqzGu"
    "aYJKi2eEqw3gca5OR8zVvRbqYqmMuFxj9R8k6O4WWGiAEa5by4D2yF9oABduXWMRLDLw6/gJ"
    "2773IHj35dS5c/PKJRsa+PD1h0saCCYvn2rq26PbR3uD3buHzO1dsHImE5mfnLx+Fb5//kkR"
    "GFD0KTYoejaOhBRJcVLivwUYACZZJwaDak8bAAAAAElFTkSuQmCC"
)


"""Button for databases in database list."""
ButtonListDatabase = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAB3RJTUUH3QgQDRcfgk6jPwAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAM/SURBVHjazZc9bxMxGMcf"
    "596TFCI69ysUUWBASLAwVZ27d0JCSCULCztzlnyJrCA2vkGL1H6BDt060ObIvV9sHjv2ne96"
    "1zRqInD0yHdNes/ffz/+2UcYY/Avm6nfHB4eqssXGHtrzvUL44RfTCaTZgGqzefzvdFo9LXf"
    "72/Xv+OORVEOQZBCGGb4W4BOh2AYYBgGmKYFlmViWHhtiojj8PdwePSFEHJypwOVL0xz++rq"
    "CpOEmCyAJElEcj5jcZyC7ydCCGNEJLVtGxzHAc/zoNv1RO+6LoYDW1tbT9rydB7uLNM+oEX1"
    "fv0CCA9MIvsiKimXS3iAA+zWvfgQBk2fDQhQEvQUcrTCCbppB6QIomacNoybFv1mBBBWiiDK"
    "DboIwqQ45cS6BZDCA9Dnv17/y2qgjQOn4/H4++7u7kEURZCmKShk53kuuKDYwBsHEAePYsFi"
    "/Zdxfn7+AyQF7yvg+XA4PEAicioCpVRCaBFRnKGABMIohXxOgXASCgoqIRjYW7YlIPXqzbv9"
    "j++PvjWJaCUhH7Xv++0knEUQopCcUTDMjkimRi9IiL3nIg0dQcLN1ACDOnzqc0+LWL8AKQLq"
    "y46ohBSqgF67gGr1i8SkiQObcIBoIyI1MXpSuT9sBsVqE2rYCxWESjGrc2A1N3QKkttYhjum"
    "4P8F0fHx8QFPkGWZCJ5YjFOAKIU/QQRBHENGM+FAB1lgWsYCQg4XgoGC+P3T1y/3P3/4tBqI"
    "1EgbQYTXPv59FieQAwowCDpgiMSua4vjmJe5Akbu3AUTHWprD9yOy3NAWXjNW/KqNbCSiFKK"
    "3BFru+K9BfBNR/btnumtqH7VV1kA2irgz8Rj+d0C+HxLAf3licvkhECVA1CektQ9rqbeUgHT"
    "6VQJsFedgjqQFhtVKQyfbS8VcHZ2Bjs7O7za3fsLgCKZvjMyUhVzfX3tcAGXl5ftAvhyu7i4"
    "gMFg4KFiH1/NHnG49Hq9KgeSFPoBLs84hISmIhnBJy04YEogcQ7wQ4kNwTTyb25uuhgFvIrZ"
    "1N+OUeEAu8e4jt9i/0ydhFRxNlQBkf8H0l6mrpXdmu2nWGM/sZ/hM/02Adx6FWt4bas0bmGE"
    "kWLOwoa/OzOLOIBt5xoAAAAASUVORK5CYII="
)


"""Large icon for new database on start page."""
ButtonNew = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABGdBTUEAAK/INwWK6QAAABl0"
    "RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAAbTSURBVHjaYvz//z/DQAKAAGJi"
    "GGAAEEAsyBxGvURVfjGpqZJySuaMDP//AIWoEzyMIMTI+PffP6Ynd2/t+vrhTR4DE9NLkBRA"
    "AKE4gEtApLG1Jts1yEqK4ecvMmz/D9HzH8GFiP2HOIIFaNv8HTfD2jsmP/nz7XMxAzMzA0AA"
    "oThAUEJSx0lXikGSDchho25QgxzBCHSEnZ4MwwQ+Qc3P378yMDCzMAAEEIoD/v/7/+/XX6hz"
    "SQT/YL5HppFCBMTmYmVg+PX7H5D//y/YCiAGCCAmzEAkz3cwS9ANQhb/D3UoAxIGCCAWSoL1"
    "H9Tgf8jx/x9h4T+oGpBn//3D7juAACI7G2IkNDTf/kNmoyVOZAAQQExkW/4fM3j//8O0HDlE"
    "YA5ghMY/CAMEEAs5lv9HS3AMWCxHj44/QIlffxkYHnxgYPjyE2EYQACxUOLz/3h8Dsv/v4GW"
    "AhM+wx+QODMDw6efCPUgABBALJT4HD3BIYuDfPwTWJaCcjVyImVkQM3lAAHEQg3L/6PF+S+g"
    "xb/+oSVEaE5ABwABxEKJ5f/R5YEW/IAGOSwK/v1HOOTff0TWhQGAAGIiK86xFDIg332HWQ7L"
    "/1xAzA+xBTnBIgOAAGLCW7oB8V90n/+D+gapIAJZ+h0a32A5kCSw2H2zYzfDs/6JDL/efmD4"
    "z4xWGDEygzFAAJEWAlgKHFDW+vEbYiEzN9CznEA2OwPD+/PXGX6vz2WQY+hm+LByKsN/YOX2"
    "HxjhPzmBCpnY/0n/eM8gA8QAAcSEq4T7+x9/nIPkQan8J9ABjEALP9y8xXC+JJfh0ao1DMxA"
    "/s+njxn41IQYJGJdGVh+PGX4C7T38+M3DJrz2xiCnhzk9Pxwl8Hr3S0GgABiIZgAsVQmoCwG"
    "yt/gIhaYpf4B2XdmNjKYB/ExPNzex/Dgz28GdjFlSHb79ZOBkVuY4cfDbwy/WuIYgrIvMXir"
    "sNjdLn9kwcjIeAIggJgIWg5NVH+ghQrI17/+IlL0/7+QfM0qJMvw7TMTg1F3KwPvnakMj+bM"
    "AbZAOBgYONgZvly+z/C9OZpBq/AxA4euNMPj879e3mPgfn6fhZsBIICY0Gu3P38RbJDPwEEN"
    "tRiU2P79RyRCWNZiBAavRmULw42Dnxmeb1nGoF2bzyDJsIPh/5e3QFWcDNwvdzJo579h4NKX"
    "YDhSysgQdcLuwk8Wloeyf74xAAQQShS8ATZSHn1iYDCRhDjkLzTV/4MFPzQV/0OuXln+M7w6"
    "f4/hz/cvDLyeJQwHWnMYLJ6/YDCbX8jw5/FpsBr9uU4Mfxn/M9wIuMywib2Z4T3nWV6+P58V"
    "ORj+PgcIIBQHwHwLT4Qwy5Cy4j9otIAwKJ/fXb2M4fupRQyCkhLAVtxvBhU7EYavd+4y/Pv8"
    "koFFyxao+hkwhv4zfNp4koFJmZ0hRWoyQ4rmaxtuFonLnzd82QYQQCxojVcGRqTU/g9aDjBA"
    "Q+EvUo4A8RmBxPvLexkso80YRE39gdXcfWCI/AAmEmCV9+cjKAVCiprffxgEHGQZBHy/AzU/"
    "B+ZXdmCkcbA+/8vmCBBALLgS379/qC0euM//I/iMQBfJ+BcznFrVxsC+up6BjYOP4fPlewxi"
    "zDcYTGdmA1XwAF0NdAQrM8PHPfcZ7kz5yPBcx5Hh072Lr+0+3jv/6trPNQABxIKtBISX3wxI"
    "bLQSEFwWAKtWAV1tBj7NpQz/gAXN61O3GJjvJDFo1ZUwfH/2ieHn0Y0M/BaqDF/OnWPgD9Zi"
    "UHh6jWHNYQOGjveax7oeLw7w/HCVASCAcDoARiMXSP+wVS4/oAXRpZsM3xfFMzh1xwAlfzDs"
    "8uhhUA5RZxCwY2Y4X3OPQeXxTwapPAmGXI6pDO+bhTn537xm+AbUDxBAKNmQkZGJiYWZkYEF"
    "1FyGYhagCqAQBDNBMZI8sG8BdtGrhbUMlqUxDEy/OBhONW5iYAztZ2AVAJbNv74wMLvHMty6"
    "HcXwdt5tBqk0UYbWrBd2ej9emYIaRgABhJoLfnx4fe3lV4bHitwM334iZTskXyNHETyNAJPU"
    "FwkThocbVjLcv8nN8D9rOQPjkwcM/2/9BCv6CwyhL4WVDMe72RgMu2YwfLry6xmw+ngNSvQA"
    "AYQaBR8fT5g4banGkq060sAi7j+hFjGiTmUCJkgLBp7zXxi+yxsw/Nz+iUHixBmGRbb/GBk4"
    "WRh2n37KMLvr4n9OBltG1mWPbljf3ZeUyvD8AShXAQQQWhpg3PLx5lGrjzeOKDPgbknj6IAC"
    "/cMBTPUXtzIwnNvyj+HdM9b7b27Ust99oPfytFDDy4fTzzD8/8rGwCd2w5Cf/yXTF0i2Bggw"
    "AJIalOSPBHBZAAAAAElFTkSuQmCC"
)


"""Button for open file on main page."""
ButtonOpen = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAZFJREFUeNqkUz0vBFEUPe9jyQqKJWyi4gdoKEgU/oNKKxKl"
    "UrI0CqKXqERHIxLxA0QnolkEWWJCLLtLJozdnZk1M++5M1Z8hGRkb3Jzz8u957x778xjWms0"
    "YvJwif2a4Az9FMZ+SW0pjeOPeyX5BHnvzyoqwsCMmrMcB0+2jUmjA6ZpY/WolVN6kHwtrGP7"
    "C1gYmt7OIAigtYJWXz14j2GujhljyK5PLRJ3NuogUBAhWb3WvhHVF3KE61GIBCJOSOZ1ge83"
    "/02OOmE8Ekg2UfuhiE8H5Xswc3uolR+BUIw29O6KzhTVJ+acIyEwQuR54l9LEpWuVYJPRenh"
    "8Vifrmd0Yqj6YHSfbWaWpU9jVcw7iJYU3Ici4vwXjMZ4zB3kXR+noYB8ujfQ1TcAnxYZx0RT"
    "MwpXJ0Xbxbn0FGTFekGaJWILBJ5bLtwYJcGRl75PO0mm4Ll2tPk4Zt7nCpaDS4JaEmhvbeuE"
    "oLkgeIz5GW6Ni+eqi2OC1L6Dq52Nld3/PCB6J1kvwF4k2Ohr5GjQ3gQYAE2uCzTGoVQ4AAAA"
    "AElFTkSuQmCC"
)


"""Large icon for open database button on start page."""
ButtonOpenA = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAABYtJ"
    "REFUWIW9l79vHMcVxz8zuzxapC0QIhgVdqEICgJRBCI1AgkQTApGQf4BFWkSpHD+gFTsCClR"
    "FTXpwi6KCgEs9AdEQIQAOUixCkeFITswFYuM7ACEdBF5vNudN++5mNnj8RdMWkgesRiSM3zf"
    "z/u+t7tHeIu4devWr27fvv3Lt8lRfNs/vHHjxtylS5f+cObMmZ9cvny5/eDBgxdvA3KiWF5e"
    "vnDnzp31EIKFEOzu3bsvb968+b3/i/jS0tLUysrKP7vdromIiYh1u11bWVl5vrS0NHXSfCdq"
    "wfLy8tjZs2cfXr9+/eLIyIiLMRJjBODChQsT6+vrP7169eofHz58GI6b0wE8evRoXlV/670f"
    "GWw4t2dVVff06dPpa9euvTcxMeHMbG8i5+h0Onr//v2/ttvtxdXV1XgcgBLAzH5z5cqVBVdt"
    "ETfXDz3454+eMTc7y/j4OFVVHXpmbGzMLy4uzsYY/7S6uvqzYwMAI9576s8/ov7kLwcOPdl6"
    "l6npBc5MTtLr9Q7sNy4BTE5OvjM7O3v93r17C9PT0y+G97335IJ3gF/PzMz8oxzeaM0s0ppZ"
    "3JP88ePHfPrxx8yfnmBjY4OJiQlardag900URUFd13Q6HcbGxorNzc33X7169f7c3NwBYFVl"
    "bW3td8CP/TdZdP78eRYWFvDeMzo6Srvdpq5rqqrac4UQaLfbjI6O4r1nfn6ec+fOHZozz49A"
    "bsGwhftjamqKqandu+vZs2fUdY2IHKjq1KlTXLx48Ztqwszw3m8NAE4SZnYkwP4746hQVWKM"
    "nT0AR032/hCRIwFE5Fh56roGeA1QPl/+0Ttf7XRGvnzx+bEAqLuEbucAgJUlVF2+/GI3z1F+"
    "aFR0+7/9Jx9+OOI++/3P/92a+uA7OF/ifJoH53Deg/OAA2egBiihFgrfWB4hGphhUYlBKApA"
    "DNUIUTERiBGNioWIRcFihGrnTej3OmU5Nt5693SrtLANRYErCpwvcIWBh935NEzzFW2Q2CQl"
    "1VBjTrAQsBiSWAhY0LwKFgStBa0EC3I6+NGtMgbpoQENOzgrwAooylS98+Dy68IMU8UkQIwQ"
    "AiqCSRYVST83YhKzqGJ1A5IAElxEnfVKpO7jy1SqczjnkvM+tcEXDnMOokAUzCJmgpmACqYB"
    "U8GiQMzVxwzWQIhgomgIWG6LSSCK9kvVsAMGmvqZvmJyIzqid2mcVLHGcgloSKJN9SaNIyG7"
    "0JxNANq4UgtWC1oFJMSt0kL4Svs7P7C6j3mPKzzOO8z7PTNgqmA66HkDspu8sT9ky5NIEgxo"
    "nWHqZH8MhvblZaka10J3G+oernDgPc57nDPwLrc/TToaE8ig4rArKiFZHIZ6L3nyQ+Oephao"
    "oVEhFM9Li3wi3W187CXRwuc7OF8WwRTUUq81g8ScNKbvB3dEIzx0ERXE0hrTGoOhwT4tw6vX"
    "n1Vxq9tyO+NmIT8D3NBQAjiMxgVLjmiqplmb6pBDACS3buh3UdiJpv8qw/bmFxVj3WI0jmN1"
    "bkEDkMR3H235odOAxGZNVVq0vRBxGECzOwkk1n6byEZZVdXLgkLMwFTy7ZfF978lbQhCSdXr"
    "EEzMotGOhpDUThELvAkbDuDJLy6tnX7Pf9dinTQbB/YZsAtAEt7jRBbOLlju936IJl6/cc9/"
    "+PfN8yWAVKEfPKCShJs5dEMAth8iu9BADDkxEG9aI8r+N3VdWx/y67iupNcXwaHg8pMvV+8G"
    "NlhiGHJhdyCHADSLa556O/ytGMSqAUCvjnUZ+xhDvR90YciCJtmwCxkAZQAxrHiYuBlUZruf"
    "iP7zJvxtpxj5vqmhhhucSh6nBcNiTqmkvQxizSOj8VlBm3P7woNizm0Hezxc3gjwAdDiW3xM"
    "O2EIUAMbwLH/g/qfxdfI9P0zcP/UhwAAAABJRU5ErkJggg=="
)


"""Small icon for remove database button on start page."""
ButtonRemove = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAhFJREFUeNpi/P//PwMlgImBQsACY6xiZPQAUi1Q7vF/DAy5"
    "v4GMH1BFbBBam5GBIRjINALibWH//8+CGwBU3BJRUmL84/v3/zdPn5a8fuqUJdBzJjB5ILuT"
    "gY3N7fevX++AhvQChbaDxBlhYbCAkTENyErTNjeXVNTWlvr57dvvM/v23Xn96lUsPx9fjqiU"
    "lN2DGzeuAzVnszIwPATSDFFAvXAD5jMyMvxiYDAGOj0cyHUyd3RU4hEQ4L937dozdg4OhhsX"
    "L54DOjcdqPkFK8hmHAaA/fwXaBBQwUw9Q0N1BiYm9tvXrt36/v27DiPEK2AgDjUAHgaPENEi"
    "ChSsVZKSkv7x8SPbradPbwjy8vJ/+/Pn0pffv/VAlvwB4lfo0fgDEpAgyRoFUVFTMWZmsWtP"
    "n97++PPnxPtv3pxlZ2XlAspt+4crHYAMAJqeLsHL663GxCT15NOnF29//lwIdPJcoMagR9++"
    "beVhYZEHstt+Q9SiGgD0t/xPBoZUaw4O+e+/fn098/HjeSB/zieg3D+Iy/Kf/PmzFmiREVCz"
    "I4YBQMW5hlxckjx//7Js/fTpPpBfD1T0HqYQakgd0IAzQDmPH9BEiGyAgw07u+SlX7/ePv/7"
    "dwdQ49nvQPHvEDm4IUCX1gD5r4De0ENJSNHApPwfkpTfMgPDAhhlD5BSIQNa4CkCxSSW/f9/"
    "nHHAcyNAgAEAxF3igbzwV7kAAAAASUVORK5CYII="
)


"""Small icon for remove missing button on start page."""
ButtonRemoveMissing = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAUFJ"
    "REFUOI2lkt8qhFEUxX9r7z0mkijlAqUMKbnwPN7CO0yY8BbeyBQayh0Xahokme/bLpiPD6Vh"
    "1en822vtdfbZ2jtoH0ns8gdkcsx+p51lWf5p7HfaGW9KSbfbHSt7q9UCIAAkVQfjonJweX1e"
    "v4gG4Y574B5EBGGORwP3oNlofgiMsLiwXK0lvc2IJBklAnCzuoMaBFdz8wCsD/pczMwCsDbo"
    "k2WSWWKfBOwr3+SsD/oAFXnj4R43w8yQrCZQc2AmJNUCAMKdMhOUIJCsek4tUjJMxtn0DABb"
    "z88AnE5OYWaYCUOY/+BglFUSm0+PyBwzsT0cUiZkFmSRyITLKCjqApJxe3dDeBCjr3PH42Pv"
    "HjQmJtBPNVhZWv1az+9IGL4UDF+K7wK9Xu93gU/4dys3m++dmHDSOdzbGYv9jkyOXwHmFJKW"
    "bHJGnQAAAABJRU5ErkJggg=="
)


"""Small icon for remove by type button on start page."""
ButtonRemoveType = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAB6ElEQVQ4y42TvWtTURjGf+fk"
    "kubzXslQ7JJBcBMj1dFNhYJ1EA0iOHUKCP4JERyyuStksWvGKpTOTmKsdJIsarRqk9wbEvOd"
    "8+HQpEmo1rzwwuFwnofn/fEewaSy2ewdYI3l6mepVNoBcKY3w+FwrVgsvux2u/T7fZTS1Osd"
    "+n1DJBIlmUziui6e55LLPXg81TnztkopWq0Wvu+jlKZW+81gaIjHkyitkCFJLB5diCLPDCrA"
    "AlaY4+a4lzfAToR2ItZY9MKL+RHKhULhdSaT2TTG0Ov1JqMoIpEIiUQCz/OoVCq7wPu/GVzN"
    "5/Ob8xBrjTbdwYjwSphEMo7nuty6fXfjSW5rB3j3X4hHjRbd0YhoPMrYnANpcMKSIAjskhBn"
    "sxuhTxikUimxlIExanZGY4TBoBcSnAlxrMcEjeAEou95vKlUdlOpVPmUgTHmFMTq4S8+16tc"
    "2HvL8GAfLFyXcuPil+/rD+GbhfKJQafTsYsQFUGrCUBwsM/9K5dnWTOXVoHVV9vbswS+7zv/"
    "WiaTWefFxw8AhKSk+vWwm2gefXLmE/i+H3McB8/zCIfDKKUJrUSJDdrIrXucTzzCnezCzWs3"
    "nv5o8nyBQbvd9tPp9DOtNdbayU9ACCEQQiClRAhhhRCEQiF/qvsD5gYPZnfJMf4AAAAASUVO"
    "RK5CYII="
)


"""Small icon for save as button on start page."""
ButtonSaveAs = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAf1JREFUeNqMUktoE1EUPfOzEzDalQ2FBjV+tuIim5ZOFxYX"
    "igqK4LJ0U0GquLLgQnEnUmvppl20SLrSTV1IF65KYxeCCSglgi0IGmokaLQxDm/ezPPdl86Q"
    "SavtgTtv7pt7DufeuZoQAsPmExA27/7Abqj0jEzLY7nzeWH+00APzK37ERkZGR93E+CN2lnj"
    "p7joHejIynRUCQiI43dyw7dPXEvK9zgeLH5BqeJGeVqGc/kYZic3r4ogeLMlEOiMMXDZju/7"
    "MYG361WcuXQKH37JFnnzbqUK9A9luxae5m+FDvQgCMAk2fO8mMDhTg0vcstRrmka6v19yD9a"
    "+OYetCdCBwbnXAm4bQJjF47E8isPV8BzL9Fd+PoO++15JRAI3yDrTLpoF2hH5lAHTlpJlErv"
    "1yhvCkgHJPB7g2Ffl/1fgXvnT6OyWMOq5EQCYQtrzz5jL0gkEorT4qDZQrFYBC3WTqDhhXAc"
    "R3FaWzDJgWEY6B3NbPsTlmXh9eQ60uk0yuUyqJY4rQ5McmCaJup1F0vjq4qYvX40skzfCLZt"
    "q10hTiTgg1u6rquiRoMhlUqpYnpXMxJGTIB2hjiU6/TwhDv1eGzmVXXje40xoYophGhGeNcq"
    "wMSfpAxoNLRz+k154Q7Kjby/ZM7ldxqiw4f6YkOFVpDHDe1fU98r/gowAMaC+CTtivcaAAAA"
    "AElFTkSuQmCC"
)


"""Help image on default search page for data page."""
HelpData = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MDU6NDkgKzAyMDDSmuHXAAAAB3RJTUUH4wsDEyAIvF7sygAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAACZtSURBVHja3Fp5kxvHdZ+j"
    "557B4L72Xu4uyV1yqYOXZMpShTIl27FTlbjKSaUq+QT5Bvk4qVSUklOh7KoklqPEoiTbjJnQ"
    "lLQk9+SewGIBzGBmMPeRN8Bqib2wFA+pkvcHCujued3z+r3f+71u4F/c/S32AoQgSJAju8Io"
    "ahsGyzIvYt7/K4JekF4wuue5WOgurlSxwEUMy9C4G6CRwYJtO5qud+0ehmEqW6YZFosiyzRJ"
    "mqWpfbsVeD5BIRzDdE212+q3ba7nJi/K7nviWCaGaMKz65qTzZd6u8Do5aGJTDZ384N/Vuq1"
    "xYcPsOTwD7575cv7X6wur5XKKS/AiuXxd955+87t354/P/P/wO7tdvvjW599/93v4S8IZzw/"
    "qFSqR3YBzuQyKUGUM7lCOpPbbY2i3S843v0eRWFtp1Eo5LvNLVWpVTe/bbs9J8Fx/MN//Tl8"
    "BmFIEsQzagNr6Xo7IQl9htiOF4bR1MSo73uHu6GLIPAnb//mhUSIwI81VEvTEwnpxIUqioLA"
    "6G1NffDgIckIclLOpuXJifGnW1PY2bx8Ln1k7/yDuc3NJsYwL50/C5NCC8RDqbhvjB+EzbD+"
    "e/tukcxf5F7e3q5BI7g8tNME+UBdOpM8FUXRP3yw9p2L2eEB4eQ1PW8Bo1e3NuqqTpEoCkOa"
    "Yz3bEnlubmH19OlJz7XlhFStbFW3a1GIkxQNge16nqrZDI0SklgoxPHdVFTkBz7FcucuXDBN"
    "i+c5sMja+lOGM1jEaFu2bR3ZywryqSk5nrWp5LPx3szNYYjEcjkMACVqKuSZKWisB80ICxki"
    "zrpt09pz8/X21t8v3/zbC39Dk1RCpJIy/c0bfdf0JAo9zwkimqLAlG0sBNYwOlzmebbl2jCA"
    "pilZlnEMJygax3wMRyyNGIYFgG21dFmWYAz+q3/7xVvX3zUMI5FI6FrLDzEiCgzTSqWzPPdC"
    "qB4gzMrClzHbOSRBEIKhAywkwbFwvLcdJ3DYD6LTDhvc2/tNiu04tVr9uF5YFFhcVVv9lcBu"
    "xXwG4GZtbW1m5vR//vvHBE0NDQ/vVDZmL14RePZFvoBHHJVRgjBOql7gk+T+3k47bMleg+/7"
    "NE0DuPWfCPbsoKqvL3tKCAIVi8XjhvlBQCHEslwfVaLAtzQttnsmk5EkCd7hx3/6Y3B8URSx"
    "2ZkXYeteAaMfoOq9ArFwoBd83PPA0NReC0QMxzLwaVk2x8Uu4rouvMWJqo6Y7qgHj1ASAS9w"
    "EEWHQbzlh58KAh/qFPiEVZHAno+KyaXlR/V6PbY7xCx4jaqqq6urp6cmP711S1FV2wlGRsfk"
    "BLOwtPqD77/zrZOJ9/7xvVNT05denj3cdes/ftVoBzSDBkoFq9WotjwKDwPP/O71d0vZZH+1"
    "1ZWF9//l44Akr1y+fPXl6T4jb37wiyCwVxbXIjHJk+Ff/OVf3Xz/7wSabdmkyCLd1BNJeWB4"
    "4s2rL8eDf/YeJhQwW6GFXKNeDf2IIF2MZH/60z9nOQ4yRIzv12/8ELYOHBAAJ5vNWma7qWoA"
    "7kGEIwD7EM9m0tjzE/AFwHfImf383QsOFq5BgONEL5sEDUlZBm3AKyBlAenX9RbN8CxDdYuA"
    "znD8sKpegce+Qiq8DxyBEtM0JECCDl2GRTTqjWQ6TfasB9zXsl3AbvB3WO1eu64bkiR2R8B6"
    "VM2C6ulxvYoQAoSBpsXFxenp6ZWlBYrhfM+HCn9rY71QHirknsn6QAoRiTcaLV6IMQEKqz6D"
    "1xyqjcuHjIT1wDv84kmH24fvUnZ3WLcI68yAB16EU9iTiH9sT6xEyGJRT1MmW8GwfS3xhri4"
    "y0RRtO9h8asHO59vT/HYgXOCjn/gQGxgG2NqAdVUEJiOH+/hUWXO1xISjxDNYKEXYjHvphC5"
    "54YwzZ27X1565TGGKERmO3lCGUH79uLd/3IcH9xUHhhV1heL06+JKfHAMEKr3r9zl02mTUWh"
    "aIqgYRVC7ME+zTJBq6EzLCpdeJ1l++0N49sOOpllPMEwsP3mQbvjnUgWBAGPTxOpYqmkt5R0"
    "Ng+54hmNvr76iOWlKMSGR8dsx7a1ff4OsT48NAix/NhYoQfvcILdA2f41KTnATgDRiDp1BTP"
    "4+Shp2iaPXPxsm20iIEyTEUxjGfbJM2EnotYvjQYOGZbxD2ib/zBXE/ymk8wbDcU9tkdUAmA"
    "HnAGSOhOdWt1fRMS7vQFeqCUf0a7q0oTUw0gA57vMjQt8USvvwd+uLa23otjYUCd6F/wBjvN"
    "TUtrUzQC2+Umz/uMcBgqPLO19OUDLp0N3ICTE5l8nuoA2B6WM0nsSWL5Sfz9CYYdZXdwciCU"
    "s7OzDMPMvnoRAOcZzb0nZ6fPOX4g8DGx7ebVXn8PfD+dzfX6e4rwePIEfycjJ11MeRLCKcaz"
    "WEnCqKMeISUqNzNhagouUYyAxJPUHjdXQD6XYcf4O/D3u3fvvvbaa7/+8JcBnfiTH914Lgzy"
    "zu9+EyLWMNrAGWB3Szlxn7/jpGMaNFXeGz8rhKLo5DJyH522jW1s7CiWkkkVx189e9ywek3d"
    "NJrZiZwNPEKr+81GNpUkKWpjfT1fLrttw3K8fD4XBm6l0gASQRKwHBpCMyEmSNzbabZTCY6V"
    "kkp1CTEcwBTCvKbmlIupxeWNyclTEJyNak3KZE2liVhG29ESsuQHEcR26NucmJJ45AZEs74j"
    "cKTmkFg5iR3291Qq9cYbbwC3+dGf/eR5GHxXrrzx5t73rr9DXtvL+77r0SzruI9BAlGeZZm2"
    "3e+gwnEc2zTLA3FisO1jvRjeBShlS1XAYhGOeY69U6/zgiSIktPWTdNyPa9tGEpLZWgmLsFY"
    "orFTTaWTwE13Ktt0IqXreoChCIuAnbZNMy3xqTTv2u7AQNl3bdv1GI6F1cZnFySeyWYajQbD"
    "CUAWwJ6OY+EhrplezIgI1o2vEA7ZHfzdNM179+5dvnjhk09+j2g6CqMC7CxP/u7ecorDzr5y"
    "NZ+Svq7RH8zdN3SdZljH8yCF0gzDUxhDU3v+HtEkttOIefdXQhAk8HCWPQFSk5m0oWu8IPcZ"
    "qalKOpUgKZpGROBjhWIB9sl1HDkp41gItboLUa61RwYHwZfBT4G5yXKSIBCwudMzM01FTcn5"
    "MCKV0CUphhcpjkY1RRss5baqDcgXLB+amm56Pri50tIxzCoUCppuwM6JAg9b5fu4KPu+54R+"
    "MDE51qW3B/0dKDyQd5oVL125pKotQeAoRKgt/crFWRIPZYHDvr5kcplsLgPVQBQG4H22bTVr"
    "G5DAA38Xw1zbUjUdfK0nJkJWysCYPmo9z6tVqoIkOa7TZySExebmOkZwnmOCR27XcI4XqpUK"
    "yzKyJHoxqxGttlnd3Exn0wGOjGbdigPJKpXK9UYTyirbNDwXcMhieN/VMYHGSUqobm2Ztm8Y"
    "FIQp+DJFc0pTjbAgDPz7cw95QdD19mKrnsnlgYGbbYPj+WajJgjM6ampg3aHGgReplKpJCSh"
    "srkJvFJOpdVGtbJdxzF8evYCQz/NvWAul5+/PxcRFOwrTaGgAy/g9Qy16+Cgdqg8wPOPz9MR"
    "xULBfNzN+J6XDA4Pm4ZOc0KfkYIojoyOg63BlFCIYFEIKX1iYhzQHqAG/JCCJYUR6PH9EAKI"
    "HB8LABMijGFopdmU5KRSr5EIOZZFUAxkJ55GTb2dzZYY3UwkxLjiDULLtoRsFlwJkWS+NCSK"
    "sCQUn9P4sXMBL2/r2tTpCdME3/KwI/k7xCzUTwjRGEloyo5pOZBtCGDIz3CqB/sfYaQf+K7v"
    "4R1Uj8vzcBfQIQY3tzYLucdnKdAFZsqkU310wlLXHq3wouSFYI1jmS5F4nOLC16IAGpFKUF4"
    "ZtvHbMvJJHlNdwAKMEikVEJAHuCGlE7TeKQprVQ2bfu+3mhMzsyqtW2REzRdYwXgqYRI4z7O"
    "qo16taGReMGJT+Yc07GoKLIcB7JIrWnnZNoOCMdq5/J5RWsPlXLr648CjPU9e/bcIX8HuwMO"
    "AHknSCpfzMIubVeqI6MjsGuw4b5jeWTMu5/C7oDliOYB0AHVHdeubmj7zgkIemig3MsjaY4B"
    "f++TLbEOgIyOn4IQJim2z0jbC8+/9ArTOTiE7MXz/G5HFPlBiDqv4/s+INXE6bPw+oc1AJTD"
    "XFyzARNFWMjSlNY2BUEaEWUO+I9tSwIvR2lISIahQdRmcmacPHCie3ranbRYLndn8V0TO7Ju"
    "mp+fTwgzv/zwN6VC0nfagDIhHuFR2FKNq9euZdNPQ+orGxXIki3DhBAG08si2csjLa1x78Hy"
    "9WuX9sa7ltFQGEh6/dV+/oe7gBVQCQ+Ujz0TB+C+t7zU0k14Ba3dTqfztt4cGTs1v7Q8MzOj"
    "1LcUI8ynBNcxymPnz04OHadndWkF/D1CtERjdsRinr2yvj02OlTbrvE0XW0ouXRaEJmV5RXb"
    "8kfGBm7f/p98JtlQmgTgIM26YZTPyL5rzJw7D9rwm//0nmH53RucA/c4QCqADD2FlXuFoqj4"
    "3jwI8M61ALQMlMulvKxqxl7oAEICmnWrqq7wQqJQHu5/PgE+2CFqDngWzx+b8B1ger7fPUrc"
    "OzHv5mH47tiWFwC9jARB6D8XZAISUWEQAILbrhsnJyL2nlhVFAEtBoYGrB/SNUIAOSHgKlCS"
    "vRcE08InYKPeakALAuBfWFiA3wC38Ammv3bt2ief/W5yYhyCCKgCJMC5zz/3ghOudY6TkdEx"
    "4AOSnAIYhFVCfkad6Nt3LuYH8wuLVy6+tPeU1VJ32MTk2HB/5Z/e+hiWJyTSr7x0/rgx9a3N"
    "xfWNZr2ZSKYZwq83DZZFuuW2lOYfvf29jUcLmxv18tDAW29dO2Gujz5iRAmn2BRP6C7KJZmH"
    "S5tTk6OVrQpHUbQkadu1APPDwKupJoFFLAfBwZSTjGJGAhMqqjkwOAhJYnZmErThP7/5Ps1K"
    "x91YgstDOoXK4umM3tFAHLiKy2YyIkf0+vthkeTM4NBIf81OnMROvgE+MAwibz/5iYIggir6"
    "QDtQFLzncP3p5josYOddf+dY9vqNG5CXLMtaW1s7c3rqs88+QySEC5VISs2WWSjmxkeGT5zy"
    "yaVbr/b6u9Gs/OyjO3/9kz/eG1NdW4kQPzk21F/VrY9/DZ/JdOFST6wckLWVpf/+wxcpIAs0"
    "75mqYfuZpFhXbQZ3cZouFspb66uaYVEMSqdSyUTS9ID4tCuPKlfevPzo0bapqyQizpydXp77"
    "gkskCZpNMFGt5Q0X5fmVyvTZyfW1NcD3hmbKHAqwUBD4ja16hOHjw8W1WsO3XJEneHlwffVh"
    "qVjQNevq1QtY9/8E12/8sGMOT1XVbDbbbrcts40oGjx9p6EkU1B5ydjzk67dD/g7UCbg0Xs/"
    "BSlZHhxBffk7OFc8IE4eYe+96wEBf4Je4ONxdglDIGmA5kH8RygswroxHl9YQFDCiyeTye7l"
    "VfxfIIQAFVuqInRyA/gqRD8oARzH4yAOOmeacTADgQe1ncrAB+rSSTnx3VIUdg9CcMs0oR6B"
    "CgBK4uAAn4EEKEkSkJ7V1dWpqamlhYdAmzS1CS317arjBTRCmVwum+nHqZ9c9vEZXfn0zv0b"
    "b73+uDsENl2bOjXWX8nt27cBJnKF8vT06ePGNLarc5tb8bW4E8gy0HCjWMjNL697ujp+ZgbH"
    "woX5xYmpKQD96sZmiJHgZRQKDQdRnu7gVGO7Nn1uqlXfsS2X4kWGF1Bo1RR7eCAzv7QB8wJf"
    "IoKwphvljBSQncN9RECyxUkWmHc6n99YXkrksp5h5UoZQ/PHxvLY4f+lxmc7ZOwRtuMlWIHj"
    "RaDenCARhgqmD07608STSy9/Jxjx1Qvnevk7SRGDxeKJ/P3c9DSBSMt2+4zkJalYyIPrgfqk"
    "LJShAKQoYC9x3gOI01qvf+cqsBqo4yWes90gnUzoppnEcIrJtw2zVMjLssRQDPAZRDO246YS"
    "2eIQFXjOq6/m8MgfGB6C8CmTBM9x0Bv/mcC1dcOG3XW9kONokWdpGnmOz/C8KJjdVR285wOj"
    "p9NpqFeBgeSyaQgrKF+Bb5HHE+Snk15/X15Y3qhWZl66nJF2j7faUCg3mmPDA/2VPFj5X2au"
    "+7mO6zpvb3fr6wV4AJtFiZLoyDJl2ZFHsmMnyowzmclM/tlkEstSFIXSSKFkksMCEMTrdXtv"
    "OReNEOX3+IsjYH9aLO7bcva753zfOefuM9/zGs02uM51Y+bjoWXZaqXpLvsw89M0TNOSAU1u"
    "OfDASZQQpFmp1mfzhSrLK8v2HBPe0JFrIpMYOCKwClz0txcLVpQ4QVzOpys37raMR08Pe+3m"
    "ZGHWNHnpeQYCjZqXWVltbhGFNxj0XR+34JUFKYjicjbr7faA2olChfihXgUf9+jRI/Vnbw+H"
    "U3MxduwAvNr1127ubLWJv+p2Hu+SrDaaFM/SZ5CnORHk3yvxrmtqt9sJo3TDSDxbUUyVqaJV"
    "jvwvYjnB9z2Ol4Bu52UJdBnmtyghQCVLUwxVWq7nR/SVnV7gearWDkESUySchRXEOMkM3UAV"
    "hsrTW7feyNPoqqYkYXyz2zkKHqTvuo5rMbzIETnDgltCOab8DNeqp0V5FsO+Z3dw8RBYPvjg"
    "A9j/9Qfv/XUN/bI5zuEdJiboA0lgzxJAIKch9L0yDwxxa9Dv60Z9w0hwspPZ8tqNmzRhzz2P"
    "43h3PkkLWtVoeF6OLxncDp2XRTaZB61GXeAgrpkUI6VJbFurdrebhG6YFiAyyBRmP58k8dI2"
    "u+3qs4MBSNCV7SoS97w/rCkog9kRRUa1QWaRGySqzMtaJY5813EolpUVZM6jv2D3H3NLwPmd"
    "NplA2IAZHQQRc9q5x/EiEIZX4t1znGq1lhXlhpFAWmr1BljTWoYcQwJHJBleICnAJUKqY5ng"
    "RaU8dRyX4eXZdJLnKcA09eytbh10nrmcm7bLIyPNUrCd4ya6xCuq6jmebmhAfSQkAmdnYhde"
    "XXHUIjmeTAwZ6+fVcgXkdT4ZBkEMsyorMWWq17WLtDsAhzuddDJCQFth+ovcyQwA3+Dbdq1e"
    "Fza22NUajcBzBaRuwLvIs0GKqxk8L9abzdCPPd9HEleXGpHvgc+F48ARm6025oNZAYEaJ4EF"
    "Lo4zSRBd36c56epud3iQUhwvs6zEMXPL7bTq09kKnqKIEgiKEpJoXG4qvay4cWVntVqJIt9q"
    "AXWh5CvXPN9jeZEqC4k9UVUXZneQC+VpHtix7f5koRgVqjy5H5j/y6Xb3u4x61uOwG9ORiOk"
    "KAD2LFvbcwTxyTGXi8kQXHcQxcCJKYadZLmEeCKn/Mg1Ko3VagksGVhFo1mbTYcEjTi6dP34"
    "ynY7AveSR6BjLNPikZQWJOJIkpFm47HjJ2QuOEFYZjwrSLHvhkkKs+fJo4dJTmZp1qwbs4WJ"
    "NCWLU8e2tntbg8Ph7ds3L9LuFMiSU7zrlRqPFIEXmFMlRVLM9s6uwDMv916dN2hZHtc94Jk3"
    "DSuI7taWIstJjAsJsiQ2263Qc0Cq8wxp2Q44k+1e1zbtZrMGF8aVvyRVFXEFmpYjq+BDGAbe"
    "a1av4roHRQHeTc+vVOqcGOE+KBHxHBXGmQoKk6WytOz1eo5j86LCc/T2zk4QAquRwG3OZstf"
    "/PIX4dEqrQuzO1AI8rTrzlzOTNeT9QrPnGREQOuNhqNGu8mtz+EA3g/295CscgXJsmt5ZBzF"
    "h/3DOGc4KvHCEtA6XcwDx/bDpCxpRSSvvPZ2f+8BuPGV1R32h6/95MpoPA6CZGvneubP++MF"
    "vImtbhsElIhQRtIyR6Sk6Jir0dyqacrKcSWei5KMKQvZkB3L+nK4YDmaZnhwWfBuTddnyzzK"
    "S1C09x+Q79/Bjasv8gQ/2vbDPAHIaOBzwPDOElGyoouSoleqG4pcEFdxIR5IHsMbxtpMhud6"
    "8Pwgao7/BOAyNG1atmHowFEK8Oen2dowDEVRhAFFUQJ/dxxHVVU4Pzg9x/OLNGJYHO0FjnH8"
    "QAYIY/DgrAKcHLea4qR0hJDM8sLxo+ECYInbXaMwBIjBsBd5sR/T4ue38zzyycHe08Hkw49+"
    "o0knCXeazJ882XvnTl3eSCXvfvEFkmURqe32WryPB4O9Z/vDwYTGkS0FMajW285kMF4sgTQv"
    "TV/hiEZ7e7Ga2m4iceTPf/Wrb//7M0ptRvYCCP2V6704zJGuzvt9EJwEyys8GRd8noR7B+N2"
    "TZ+bDgguENih5VS7nf2nTyeTSUFyWRoatXoYl7dfv/bVV18pCoI37NnBR7/B6ZBLgXcADSga"
    "INNnqWjQOI1Gm+W4DetpcF7syPPCmA2rBvByZIYtigJzjxzLAlxmpsjzq03OZ30LLH/w/tFC"
    "LQp4Fon7DJdIViiKwbULkoS7hUuTJHVU0MCwT/OcxXhP6KNcbhynEEvK05IGHD9eJ3258P71"
    "/3x5OF1++Nvf6ejEfGQRf/rpZ+/96sOasakM9Oknn0BwRmr1zqY88P79h49gur9x6829+1+b"
    "bgRaWJORE2W9ukxJ6vBgQOG6cZkWbOhanCgikdabu/2H9/RqJWGlq52qs1iNxxNB0QDvVYk2"
    "I7JVER7vj7t1/fl4WocobBhEHIZR5INg9UCbEHhxGM01m1syl917fCjSdMVARmt7p43zBJcC"
    "7z/clJLeMl5RXI2zjGdejZt4POZns5cOFqd9qRt2zu/HisJfffXy0vO3VJxSLOp0yhZHxSVX"
    "xp7zUuD9u2++fvx88NHf/b4in3hz2rQ/u3v31s2ftnVp7SmK4r++/BLmrqHX3nnt+rpRh9/e"
    "e/LHT0DvgJfw4whXGknaTiKRZoCzMzSLaMJLEjfLOYpuIWnPshH4CoYyoyTIi3+6cUOB+9za"
    "+uT+fUGScfM8nU+9tFdTngznHUN5vjC7ujx2ot1GvSCT8XTFwgUEYWHa17e7TwajisQZteZk"
    "OlVEqVlVar/GaZhLgXdg1uAfkfTCxIig64rBc9yGVdoALvx7kkxABK2vgPvTaTqd0hQFhnfi"
    "WGRZgaYDcNDgpouCp+m0LOEISC+OxvVfIElwzihNRXA9JSGwLIyMRTGuGCCsUriWgFl8nmcQ"
    "J7DDLsvjMIP9eF4gjk3gjzyHMTzL+EEQpHlT16M4gmFxmlG1C80TnMf7wdODhePfvv1TdLro"
    "gkXKg9HsrXfeVeX1fCaKgCdAqKw3Oq/v7q4bNc7Sfc+TkEYVqZ/krao2W654jvH8dLtbH4/n"
    "kqbJAtAPINhUYC94VGXp3HEilkz09s7o2TNVk2RFXk7nWCJJiA7duRVvdyqP9w63mlUfJkqZ"
    "jq3gWqcZJnHqe3kaBQm8oWSrXQHaVG/U9h/vqfWqUMQjO373yO6XAu+goZOcqFVe9ItJSCVp"
    "rtPdxghcswGfSeMYZG8QJ1Vj7bo913WTOCpxJa+E+Bn6AUmRosAHcapIAiiAOCt4hvKCCChH"
    "CTAuSlHgzKUp4N4Q4D0kABx3ukURrnskaUWVCYYr0hjITpmnHA+8Ba9hs1YrmAAM/KvIGJZL"
    "00zT1OVyhat4vg/0psjgKVmRw37/UuDdtcwnBwd33v9ARydpI/jXYDTr7V4TuE15sX6/D++s"
    "0egI7bVlGc9aTuZLnoHpn/KcILCkG+YhzqZprhdMp7Nmq+EFsRPEnmPDm8mi6I23b3e7W+dP"
    "EkXRg3vfsoLIiqK5XJhe0m7qj58+6nWaAdhXVtIsZhnec1e+H4IMBqXWbDWHh/1KvTIczVSJ"
    "HlpeRSojUjvO/V1cXuxc3UOQULe7TR4tVzw+whyBBeQfXjK/ZgO8CxzbuHEjjDfVPQqCEhim"
    "IEoZKaBCA9cSeImnWTeMRJZESAIn7jg+MgyGJACYkg4a1ecY6qVr8SLPAjFP05qmCRpDF+nr"
    "r9/Mk0itCIHrgyQAdQqBVxCkLC/TNMdZbiwUcAbQjzKB4/wkYbkYJvNF2v37fUtpGHogVs6O"
    "4GZ1UBwEubn0ARN/Opko8Ojrh0VwTpqxLbvBcyRB6412YK3Sgtnd7symC10TLMcxqjonKXSZ"
    "YtdH4uaGUX+QU0zkrAqGlwVelBXgQWVBQPAHrWSuVlvd+vPDSVWTV6ZF52VOU4Ce2DVplo8j"
    "h6AFgqLrMJNsq2rglJ8fBxwjcbjH/0L9DEi47LT/PU4SkmSzNA1OM2U0I8Q5zbPUBiADBsGl"
    "qpqWb6yQAObSCAhk7AeJ79qaUS4sB3SrItLP+yOOLQkGQTzfe7qvyXyeppPl8uqVa/PJpNZq"
    "h0kisdx3f77/+ltvhVHIk6QfRorIiBJazhbAdJI0lRFyViZF82Hgw8UUJB4e9qtV1rFs07Rk"
    "jpwsrd7W9mQ8kpEOQvfqTusi7S5JIn/a9FI2G0E8RLIsnfbXC6JIJqAx2c11j1anE3iuKMqb"
    "13vo1YZRzXkexpCgb+HSFE4P07feuOb4abNugDk6ndbKTRkiqzXbuq522s0sjVc0Xa3qlUoF"
    "ojdTpDQnwA7c5MJ2W532fGHBC8sJStP0OM9UWcY5BpK4c+fnMCcs24PJI8uagJYUzb15603f"
    "CzRNiyP3Iu2OKxXliTcfDgaTybTT26XLExrOcvxwMIEj3Ho+Aw85GgyQohRRuOGrHFEY9Pu4"
    "GxlsvTTNWmtLIOMgzjleXM7HNIOG/cNmpwUuYmEnOiKdmPkJTWQFEfv2w8cjcESiJLXbHXMF"
    "DAelJYlzGbS0mE5MJyplab4yNSSabpBXUxAAge/ZttNoNCZLk6OpJN4ny4yVK0VkpxkBLnG7"
    "a1yk3XEr1ekHo+rNNgPhDL3AbF7ghlaKhAC1tjUT3txWr+d7LssLG4YB9771ViX0PKTpt7AU"
    "Kn0InqDRyqLZrDM0ffwtjzxv9dK0zAtRRgnu/s2adb3a7EkiG4dhnOWVWpViQDGRIs9YXqCq"
    "FUZIWZpEEGY5WnJDRZbiKBCE2navR9HM9k7P8/zjdBj+ZAu8+BJOX4S+fZF2p6kXfZ/L2fjx"
    "4Xx7q3WWbQfavv9sv97uovXfHgILPvjzd0hR+Zzg+bU8MmKor76860ZZnsSAXFlRzcUsCEO9"
    "WkszsltXnh4MOnVtNPN1jTHtuNasIpaxVgs/KxiCAR9dqRidbicLPEGW86O6R0IIdGENJsu6"
    "oU7nSw0sXlKexUkqby2X04kFgQHEl+WlVUOlaLpM4owi4iAHsF+9do24JLrJ9zysRwzjLOkr"
    "CEhSKqD0qI15YDA9cD6KZsEjrxvm2lZWkqqq0BRE6ZAEnkFTQPPM1bLTebFiFiIzDhJladm2"
    "rus/vJbvOgwngq4C9e8GARKFkmJgmoC0AjrrBzENeCYoeDpw4hAwxO+HHJiRLMsC8APvQut8"
    "38sTjJ5/82Dv9x9/bJxmBYo8ffjtPfXD3xnKprbmLz7/HMlIlPWjyv1f3kZ99/Dw2WDmvfvO"
    "m88eP4wyhi7jnRu3DET9+398trNVv/fNvYLmdMT6UXLz1u3RwbMiT0iW9WPqX//lH89e+1ef"
    "3+clieREVSCiQjBk7/H+sNswJgtLQ/zKjTs1Lc6JMPBmsyVJlaqKbC8jc8+P8kq1KXBlFGaN"
    "TvvqNr7VS4F33H5bEuc/pCirRndrh9r4aUXA4Ol3rjZ9OgYwDkzmuH6CF2pROI+Ge3pP17fg"
    "mvjRN2WyLGfAwZ07clZ1Oa6xnP3keI3G2SXOhuFJw+PcAwRYiOe4d4MoQNaBXoNAcvzzS1T3"
    "+N+7d7978vwf/vDPdfUE74G9+rf7e3//h4+FjcvY/vTH/yQpStZq77/3s3Vj5sODPz0a8EQ0"
    "W9i7V68up6Ppwn7n3b8ZPz9IcSM2Np8iinEeW6YrIDkHEwucJvAZUM48nq9ccCNqrWmPn4uq"
    "AVKtJjMLv+zWpMfPJoDxycpu1mpRFomMIKvcaDCbLVYsSypazTYXN67fGE/mlmNriJb0dmBO"
    "fvm3l6bO98Pt/2O9x/HO2cqWl5a4HHeCwJHVagWE/ezg0ZgyiuJXNg2+dEvAbXCzjSj8X3PX"
    "1ptEEIV32Nn7BZZdaNFUm9qkF6ONT8YHo3/B/udaNaZJ44NiY5W2FBAK7FDY+4xnQIlpLE3a"
    "RnrCAyHL7O7h7Jnvmznf4cJZ7lC8f/m0v7v/+c32duHPvnY0Ih923z17/sLSZ3n27c4O3Ipb"
    "vrf19NLWYPXaj9rJSRhTeM5h+j06qq8/3oCM/P7j/ubGpkDjRquVJFyU7XJon/nDwHEsTbdP"
    "ajWAPUsV5/RsUDC9LOzLBq9/l4Wo2YuW77sHhyeVkuMPIx0jreihaBilIUJiu+NDVsGamsWx"
    "kJNhOuHNAwWRCtR11IfLdwbPAMPOGF+imgaGohqaYXul8oxngssqOAdAcFeWeek27Gg4SpII"
    "IDlDWNWUyXIVYhQ+MkybZQkVUBpHlCHdMESegqlPiAiOkxRGYT7IUYFxDV8QYEkOozhvmTmM"
    "s4QPiHipBuVqRRgyo6oGeRGgZ1cec2OIb8zL0HLnAxIlFGIfSyLLuP7vTsR7s9P8VK29fP3K"
    "ntZx5ADU/3TcBWvm0723t5elablcKXmXbsY2jmvVw2MnbyYpeEfCKD078w3TxKpqa76kqhjR"
    "eqMNc2+WJkCpTFPjbMh9QI4Pc0KiO4t+p5V33PNuR9Z0eAWk2/HDpYpb/Xa8tOiFgCSzIALo"
    "y5UNLIxDWVLJgEiyNt5QBT+nxZIH7OGslQqIApJsNJp3Yh1Y0vMbm2sSFw5OK4RjyymIiAVB"
    "cNkIEO+rKyuihEdhMuMwzTBXHy2PV2QZhDagb9crc/mSxDtrBBCGKi5nTJaVJI7Ki8DdeCWa"
    "bamKWAIyXMxbmCWqYSiYYVmNgGfkF4qLEkuira0nNI15Tb1WgZlTFHj9B7DfJKV5t4hhxkZ8"
    "ZRtczQXH/LlIh6PR98M6IWRueQau9/T01LJst1i4+Zi3aOAaRTU9z735UBfs4Gu12+utLHOR"
    "4tzivd3uNJotn5z3+715XcM/DaDL2vrmzce5YIBkGs0mIYM5+73kOeVScbKOONUWT8nItGhr"
    "3I+Tl6BM5eRTWMbfT5pFskmfzt9AEAxI+YTmXNNHWdhu3X6P/42/ik3m5vd6o8O4BJRCNnQK"
    "9mBwDk6zLX0YxKah9PsDEWPwpWVpPgnQ+FDgjwXbCOOU/+sHE1UF+I3Y6RKAbpatEx++IvHa"
    "alHq9/rwC1p23ilYuTl1zp5taH9vF5Lsfz5rGAyv7GN9pU2U7VEcK/LcesFf234BeQoe5Cj8"
    "EHEAAAAASUVORK5CYII="
)


"""Help image on default search page for information page."""
HelpInfo = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjkgYXVnIDIwMTkgMTY6Mzc6MDIgKzAyMDCROc9hAAAAB3RJTUUH4wsDExscmjbXjwAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAABasSURBVHja7FxZcxzXdb69"
    "3N6X6elZsBMrsZAgQUoiWbIcOrJjy0vFsqv0ErsqecuLn1KVH5L3POYlDylXVI7LTlmKyypL"
    "dCRxEUCABEFisMxgMPvWe/dt38EAIAiCMxyKEjSyTwGD6dunu0+fPvc7yz0NYun2DdBrRBAE"
    "TcNjg34Q4E+aog5HwjD0fe+0hT2ZaPybzaQVPeHZpqqq+XwxHtdb+yrVakRVdnZy/f3J1ohj"
    "GeWG3XfAcGpC07CY293MFgjfJSBLgICBXN9AMp/Nyoro+QTD0AQIbdfXNZVhmNOV9uRbwL+r"
    "q6sPHv6vaYcCJHyAAkRysogc6/zs9M07yyQKKToURD5fsWSGMDwg8QwJ5X/6+dunKDfDsRFZ"
    "cG06CEOWZX0foTB0XSebNRwb+ciHNMFK0WhEOW0Nn0xEL+IMhIznuccGA2wvJMUwj/EnQHiE"
    "JE5b2qdpO52hKZpmWf60JemOwhBhvWP4DrHh4E0A0mU7ygFR4A+fB54BFE0smvcSVDxOx2r1"
    "RuD7mhY5bdmb5DgOLcuRwZEJ07RYFlq2J4m8bVkMyz1tKFtbKUWNURQhiSLeNAxDxF+w7wr8"
    "es0QBKZuejFNyeWL+CQsSzs+FQYO5jGaZIqiIO4d2CLbdmgK1A3Hd51YIt6VVeay25ZpAIIE"
    "JIsC1zLrDhPLOw1RwN4V0BAGnoNhJ+ftohAtOnffpK8v3l3FT+L6G6+ets73id7XguPndzN+"
    "QKQcCwO8GtFGhoeIJ5VRre16jntncRmEBAp8WeZyZa9PYzczxWRM9QIPMkKpUJI12axZZ89N"
    "0q69/Girf2CEBlZqI3tmbHhneyeRTJRLJU6SrHJ+aHIWP6Cl259dvHp1dmq8W9Gx1fueE/gO"
    "hDBi5INm6KLVambda0R5ieVYlmDT/s55dg4zx2MRx3ZOW9uPidjeWMP2fnAnIdiL0p5xnyHe"
    "1fo8ZN4/y9GRvY2jpzp24OcnbO/53XR7npd4uZdOm1tp+uh2e0Fbew95nmY+OvL095erhdHx"
    "GUH6isYqzyLPdVbu3skX8uAQZzChPe///GdpTvMAQfqJJxf4AUlTLQV7nocR4Iu6CYIwPaJk"
    "g2EFZOoAy52UQeu6ZQtoX8lAAWv405u3QoQGBvr2tZbO5Aq5TCKZLBaLCIGx8TFZEo8dtrqy"
    "IivSRx/9KZYYWF68Of/KNV7gylsPc3UvrumxZOTh/QeyokGBsapVw/EmZmYvz899cbchUuD9"
    "LPjVPaDz4GENjMvg+gT4zQMQZYAVAMiAmgX+cQF8dbAGm/U333h9PZXCkdU+vrfg+BCyiT06"
    "dhhCOBFvwTSJjR2bu+MhzMaxjO3YLMO22Bz8nePDILBdVxLFbgR7XsL4LkqKKCp5ExRMwNOA"
    "pAAkgMKCggVcD6g8sLxmjDmifoX0jtO69bXlR4/WwSHOPA8E46zkyBYFKOqwRiLwwuEOQRBb"
    "3NIXBzL7QoO42Pw5SuKLFgUK2a217UJcU7AWWJYbGhxoje+kN7OFiiKJqhaNRTU88t57v5ua"
    "mszvljQ9MjxyBtLUC1yOfoFjvpaE53Eumy7l8xz0oJg81Duesqmbd3iKnJi70NI75lxaXiE8"
    "VCjl9L5B9YX0vo8z1WrNdSzH9fYcI85g2UQ8dow1s5naSBd5JqQ4GdkGLyv5TFqPJ/zQ12KD"
    "2c01Tdcf3l+bXbg0NJD4QnW0jzOS8otft2NLSCDGA9cHWQM03HacY7Lzi9cQvv9GrSaKEgWh"
    "IkutXZ6Lh8NavWoZBgIgqscokkCuVWk4gsAjz4EsR0EmGlE7in0CzrAMpCiShn4LaSj6BIiA"
    "HD9yZpAIfVXTy4Wcouk4ctE0zbZtkgxj8ZggyTPz53T9y8vF10rgSBZxnHwABiSQrQGRBrd2"
    "2p0HIlQqV1KplGnaoYMP6P/O9Sv7+5C3sZ42bQNbWHrtAUVzVOjgZ2lbjXKxSASe6aHhMyPP"
    "o/ej9ETe1Ct0aO+fbVT6hXYV9rpHoZDg6YAhw/bnjEajFEW5puEASha4Y3tNs2EZtuO6oqKo"
    "e1PBNA3LxAkw8n1fUiLiU4c8TSfYe4/SRsGUNLsNw2KJR4ggSTQftdufqogfZma3mCsLMo18"
    "mldlq1wIaOEnP/4BxoBMegtrfu1R+vzChZbeM+ntbLYocVQmV7mwcFEU+rqSfN/ebccPPNty"
    "HBwUBkHoOrbrebIsBwE6rOFhyXKlBksDNRpHvknSXClfUDStXNiNJfu2U6mIpiMCqPiP1t2k"
    "65YO7X0rV5UgasNpB03gpMmQ6hROKrKMQgDhviEGQUBRRx1m2Kg38B8M5TzXipjDer0hCILR"
    "qHOCxMDOFnyCvbuOUy7lIcuTBGkZjSAMGQaWKzX5wL1gsiwbh/Ce6xVLJQ6Gll3HThiEyLIs"
    "o9YIEHJsO8RT1f3yltbS+WqC99sw/HZTlWAgMv6C3sHeHaNy49MlhYdWAH3Hwrf1zTd/oEcO"
    "olTkriwtLd9bf+XalfOzk3sj3s2Pb2sxJfVwY/7S5bHRoa4k7218385Vxbb2/vykqurRMgm2"
    "d5LqMEk834N0FznK1wfftzvZ+/9sqCKNVM671Mnea6Xc4spD1wliiVhM13bSW4XdPKvHfvz9"
    "7za1j5wPfv/HldWNV79x7fL8bPOA0P3D+x/2DegrSysLV65Njo90Jfm+vTu2hf0+SRIUfug0"
    "7XsewzCu6x5dFK5WyjiAMur1eF8fz8LMTjaZTOZyeXxYf1+8UmlEVMHxMUzVGJaRRKlULNqW"
    "qepxu1EDFIOjXoSa/t8NwmhEcTykyM1Z3DAamLkroZ/f3gOE08/mglRHfJclKQwD20UYvmvV"
    "MoWjZg5ixMepTKuW7fk+/iRwlt7C/TCsG8aeO0SQYajnKCmeYO+GYRSLFYImo7LkA6JareAs"
    "CjLQ97GnDDU92t/XV68Uby/dI0MiXyr6ngsI5u7SosAJOO6/dfumXTNkTa7WHE0WIUusp9Ky"
    "pI6OD733/gfn5qa2N7ZoVpIUznVcq4FDgzpBc/gRKGpkYHDo8sJ8V3o/pI72/n9pGeLcgndn"
    "Im77U1WyO6uZHQZA2zL+7offp489J4LY2V7/8MbSxVcWZs+Ot0aKhcJuZgc/V1GLnZuZ6kry"
    "rzm+11wS5zkeIjq6AY7jTMv0ccqOwsGBgacrVeVyMfARDl0kcb/KvL21JUmS5weRiPo8Fe+/"
    "IHz/024TypKiOyp1iLLowEtX6kk9OT4+fCIDxs9bt1bPnpudOoBykqI31zd85JWqsenJsa4k"
    "P0HvrQWQjssgIY4pA4Rx7ck4t0n4wWKZmjiImUKMrQQOTFsZ/dPMn4f6dbl9/H4RQpkJLJ9T"
    "Ob/9qViM0WKNJJ9ptgzLnzs/re6VxlqE4+d4fyIEpNZlkeCx3tOZXD6fYSgYSyZLhRxBwTDw"
    "aQh9z9cTybjevNinN27UDANrEOMaRTNWzRAjEsvyrtOgKNYxLV6knFCJsF7FsM2aKYh0td6A"
    "jKaroGiSUQnnWdnYwOj3vvu3L6upJVduoLYKXSsJ2Df2iS50O+gdo0e1XBEV1bbd1ZUlv2kx"
    "wquvzB1KigJ/I7U1QkFNlVsjsqyWC4UAYSWhM8PdLXHt632gP55MaIBoKkSPRnF+1FqJbvb9"
    "HEDd/OXL4R5hLgKQYO/L3gC2OBLLiZ8TznKxdWOnH2I3j617b94cXCsMUEjT9EvsJFIlTmDa"
    "2XvCZ1XGN31REDrgDEVDiiRwzl4oFgEREgTDPVngRSiMxnRZfLzSUCkXWZ7DcaAiCaBL6m2/"
    "etqCdEdH/WoXC9l/pZdIPax3wwVr5eaXVBlsVsBhnbdkHufEI+kq2K41l14b3v4hp0s9HEeK"
    "FFjJg1/eBSMKuF8FYxJ4cxL8ahWoNGg6HAiqFrjaB363jt0AwAC8Wgb/fAn85yogXKAIwF4D"
    "dAggCxQKYNB+q+t+tc9FPax3PFevnwELSQBJ8B262Z4qQvD2DAgCwELg+NirA50DSQUIDPB8"
    "8O0QRHnws/OACoEXNvmx48TeHwc8wpfeIt/Let9r3FDYJ8a4p+Lv/lbUd8CWeEbosbv9aHEt"
    "E4vIJEXQkJ2bmW6Nb28+erCRiamyqidGBvvxyLvv/vfU2clcpihFpPkLF5kXWtfuYXx/uQRZ"
    "ngi9esO0GhU/eLwoGI3GcOheLleog864eDyeyxVwTul7jt0pLXgW9bK9A/AP/9Vu76AKhiRg"
    "umCn0exnakNnVftfr4rz8/M4D5JkmWYeL5ZCSF26cKlULdeKufxOJjkwOD09i1wLp2yqqpR2"
    "tsqQEUUppke7kry39R62XazGOyNcM+w5o4K82eE8pu1ubW54XlDIboV8M0c/2Id2s7uOZ0Vj"
    "icZmKvADw667PgGpMJfNYtfiIpxzde0felvv/3KpNCy2K/CWHPqySiis/7OJDv0EqqrNzZ1z"
    "jZpNQJlnbdsJkQ9IiuPk6Vm5VqvYpqPHk6LAaZHmW3Z4RLX8vbJ8ICtyt5L3tt4LNSdGtltI"
    "2qxgxCA2QnBOs9qfKvWonC8USoW6IJGBT3OyaFfLAcm+9b1vYwdeKhYadWNra3dqbrZVBSsV"
    "i5lMXhZgNlc5f/GCInXXCdrbep/r5yTYbo5PcxRJhCyFINmhPh6JDA+fGeP5fWR3Xe/oK2qj"
    "Y+OlYjmR7OcPOm1Hx8YUJSqKXLyvonb/1mBv632nWG9ff/99WhYhYungQqf+Gd9qfPLZMk8T"
    "rX4CEjivf+utI/0E/lYqdX9t88LlhZmpvVI7Cpbv3tPjanojPX3+/PBQf1eS93ZdrON6k7+3"
    "kyRAxyKojMOYVqTY7DEPMWrTNHWkHz10nKYjISnq4FWL0LIclmVc14GQpagXWl/tUeq43vTr"
    "DVWCSGK9y8/RT3B78b5pesmBJA5mMtubuZ0sjOjvvP2jvX4C95MbN5bvr7/2+rWF8zPNA5D3"
    "4QcfxRKRB/fWLl25OvFi/QSnrcDu6Ivon5Flae+FWApbeb1agZwg8B1aHo/1W3SkvyB7/82m"
    "ytNI47yO+F7KpO9tbQMP2Jb59+/8FD6JS2Hg3rl959ad+69cu3Jh7mxzBHl3bi8a9epONn3p"
    "yhv7oP/c1Nt6H4qr7e39pwpBk2Szw4XqsA4nDg72jY4hnBeFBHzaGZD0xPTs2Zk56jB8Iqgz"
    "oyOKImPPQZBdq7G39d7R3v+QkWkyjAnuWaVD/0w1l03lS33x/pnpEyrCBEFWi9kb/788f2m+"
    "1TqAR2zb3lxfx25Y1GJz05NdSd7beu9o738jUAKNnIBVmA5ugGVYSY9jbT6LQZAib7xxRZAf"
    "p6ZhGIxNjPsojKgv2k/Qo9TR3j/JiSgE/ZIzLHYoHAo8u72VViIaL4hLtz7G3I7Hfuv6a4eQ"
    "49jGZ589mJydPkxNGYbbSWd8363WY2cnRruSvLf1ntQkCQZtGKYpRmUCw2dlrkM/AcOwyWSC"
    "IKlyuaTpug8ojn2iVE/RzMTkmHbEtI1GXdOjIUFFu+/37229jw10qL7Guzmbqh6m+yckn4lk"
    "fyL5xMjkVHc9kUfpr+sep0M9rPeGW7tTXneRt1ReW6mse8jHeU/WLPooWCo9cJGPvwQ4MER+"
    "1io4gec1R7AXDD//pT8/9TDOSDS1Wt34j7V3Z5XEUr06IfA/Gv3hv93598nI0EOjPiFKbkjM"
    "aueytfsWwYsUnTV3aJJ5Z/wnQ3zX5fKXTr1cJxAlC/mWb5GAgBSLQo+jeLwJKWj5NiSpEGc7"
    "BOkhDxKUEbgsSeEZoTHKaf1bmq9LnYAgeYrBPwfbzZYByDRfHeGpo10GzTKLADu0MKZT9z9e"
    "eqSrCk0DEvJXX71cL+/+8rd/vHh2EDHqytKtmamJzFaeV4XZiZGbK+ueVY3G+vWI+mD57uD4"
    "5O72ZnRg8BtXXntO2XtZ7y+VZFUfSNZxNEmTvqg04yBOUOemx0kSxXSdmJ0NAn9wqF+QOJIR"
    "krFIEKhRLRIicG5+rlg1R8bGgm7+9Udv6/3jB7cTjNaGYfHP7VxZb9tGEBbJ5X2IlkRRh1VL"
    "rp04rpv4rSjaBgFa9KEvfesf6I/sU5GHBuhLkx6J0yR27FqOrIOySIo3l0eXsSNHaSTLAYok"
    "QAYCBCxmB7vD3ZnZ3ZnP3kXOtsJUy+QFNp3KJawgCRQYWw7DkAd7j5Tl1ZIsD/p9kiK3NtZH"
    "hqdn5Uf2UqlcqZwHmtpQ891nEMKiWlt85O+33jmapea+87EUkyclPw4o6gKMV5okMavT10IC"
    "yyBvYRgkSRrBiBMF8vmbxnCopWlC0yxqf7ljBEMCEIpa6/X6zcaiqn+f/eqHPOwPdFma1Mn7"
    "i3CHMBKEmbWmUQSTOF5MDuQ4flb9VJIkEXz9tW2cJARxNmbdH6U4U6C4Q/t4RTjf4ENfLzHz"
    "jP67QGdz2H30x8H+oZiXCBy5aPpk0KvUVGTdEJEZcFhKgQyeJgiTL766NUvWidbbe7JjWm5x"
    "STINCzk0jucYmg4gTJOEoihzbLIMD0jCddwvb31L0/Rr5aBF8PTJfRj4/aGOYykAJIZjAFBL"
    "smRZzuqVrVO2nv3PT1obxFoOLCVxwBHEzfrXt5/9XGELyKAPo5hI/B+v/kBfBiTw/6YJgtsL"
    "v5rBOwS208MJFD/JuSTc32/blkWxTF4Qx5ZNg7TSaFIkPV9u4IeB6/993KE4sVEv7+4dra3W"
    "ut0uL8pH7eNiUeg4faVSZamLdYEihEFvQDI0hHEahRjS+/YnLzNUxdb3dJUjMCdOKSzGMZIB"
    "zHeNm2gugGDCOMAwjMLeLaWbY7dYKp8MB5ne4zi2vKTRevmdZeoib7KHKWreU6/rh5xUQL9q"
    "4+xxfXMrc30rH2fXpCj6mnB6rjenSBPCyHJhDmfWr03BIKJGmGAMw/huZoVkekn+zzIo0W94"
    "B6AdHz5ua4os5nAMBS3NlYY96j8+0mx9mAJyc2Nj/8lDwErFpbwx7OJMPnAcKS9WarX79/8q"
    "yeLQcFS1nMAwDGPf8wADNjevM9RUuAgI0Go10TngTO8EQSzXF0q7sex52W7oHEG+Nhccba7p"
    "s7muG+ns+ymGoc/HM93X9/14MRdyWcJwwtQ117YYAEleQXpned6xnnqu7YSJ7foovuwNUKju"
    "KAXx7p8719ZWjru9HKBtz4eukUEvpTmlmO902iwruXqv0br6it6nvsHpn6kPJ017u7sjwywW"
    "iugE4QXR559tT+ZtjOfp3ffcUzk7Dx7qus4JUlmR2x2dJULTDpM0qS8vX11v5rJAcHBlY2uW"
    "HKRZJCdwzTu/PkC2nSJJgCdMXv10o4nsuySf78UHh48K5Lxo8sDroMGX6TJ3UZ4ensOuX78B"
    "MLSnScO0LNtxTWN9fZ3EcmPXa31UL0h8bWwGCb7abKjVhm2NFRXLINXWvpkI8RyLpAUCxfRp"
    "Q8m/mjGZ5lI0NeQ1z/SOlp7jeOmLyqyyWhFEKQjDcrmEXJ/jnKcwQzjvtSwMof2cuaiUavWq"
    "H0QcS19ZEyjkSF0fuWiKYU8ZvLnQ1CieydhSYnv7WhBGSOt+AAWBR42uN/XhAxhG2Lwhdd2B"
    "CMST4OCGcEH9EgDE6PjIQXspBYEzGun2amt5595vMcVjadJa+Wg8tixzZLkY0vuzoyMszcE4"
    "LmaPTec4dnEU9nsDSeTRChxXVImfSmJA87p37+5zrBMyOzdV6k1N03ILELKtsjwTLs8wDGQH"
    "FpGDSFXVWTChQRCg7TKro6IoJ1oXmWD2kugpb50C37vzy23THOclEXv88Heef/v30Zci09AP"
    "2+23PYo3J0kS/wWAOlZWKcYk5AAAAABJRU5ErkJggg=="
)


"""Help image on default search page for pragma page."""
HelpPragma = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjkgYXVnIDIwMTkgMTY6MjY6NTEgKzAyMDDGfW9mAAAAB3RJTUUH4wsDExot0vPm9AAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAABZESURBVHja7FzZcxzncZ/7"
    "ntn7wC4OYkGABG+FEkVFiiwrsmwptkuVqCpHJak85CVPqeTJqTzkv8lL5FScxC7JUuSidTCk"
    "JAoUCeIiAJK49sDO7szOfaZnlwJBEgSB3TXguNiEwNVyZr/+erp//euvv2/Rm1P/izyTAxfi"
    "sBXYWdZWV9K5AcvQY7FYrVbPZFKd9xtyXW6o8UTcdRzPc8MgxAkikcqwNEwkrGxsoBSbTSUO"
    "XuH1ipxIwLgoyC6XkQSBoy7yW2v32enppfc/9EIaDxw/9EBPLia4lnV68tjS8h3fMVGKCRB0"
    "485KZnjk+MTE8vw3podjtqJ7JI6Gro+MToz/6M3vHJjCksBRNO8HQTyexBG30WwhGELTnGNb"
    "p06fxr59FvC/C7PX4QX6u4czvuvUGmo+mz7IQUOMHh0tPaqJ53oBQlPkg3d8b+XOAvI7aff/"
    "F0KIsUQmnZ/65ibH85ls1rV0RTXjIo3SUi4d3/1mCCsAXIBgkqT6oo1uWHJ9k6JpvaUxLI0i"
    "YUM1sMD2EQJFAhQjM6mY1tJdFCuvrgwPDzEcn8t06dcffjJ96Yvq3//12Uw6eWDmDhHk7uLs"
    "RrmMrt69XRwe6+5TgiC4detWsVhIJPqpuucBoCMEsafc43seTAbH8d0T2uOi6/rC0tqZk0cx"
    "DOuj8rtLGIb/9bP3atVaNLfKhvzp55cYlkXDkKYxnJLQILRM1TB0FMf9gCwWMhcvXtjRQCzL"
    "8jzfL7X+++cfUUSwsrZOoNjZ889X1++QFOc5tm67NI5mC8XK2poVBGbLePmVF2ZuTNebuu9b"
    "IUqn0uLExIlj46W9j/XeBwufTsn/JHCl0cEDsztIqTQ2WhqL/L0wVArbgnR4EIp2Xjdk2Q/D"
    "VDIFnrSjU8BlkKAJksTx/vAi3/c7o7edF22PEG535DDw1jcqQBx5loZos22bpum21gi8BifY"
    "+1h3V8rfzFS+9+oxhmEOzOgwnVplDenwSF2zqrWKKPKuA388jucYimg2FRQjdE21LYfAEMfz"
    "o7lZjiByzaZ+fHIcbfv71S++nJw8nk5n+qJWo6GqmoojiAVGZBiKpgzDajU2UVZEHIPleJrj"
    "UQQ11KZc9zCITpZR1JZjGQiC8QJfrzdASVNTCU4iEZdmRdeJ3MK2nSDwRVGCCFabqpRIFAt5"
    "WXGrim9ZzkHafUsiu4NvNxuy2moFnoXjbL3R4CnM8XGSwhW5Afy5JcuDI4PLt+9gBJEJs2qz"
    "CfEAMwQ3O3p0TJKkfmnTUhTLNk3LpwmvLrdYyudjWT9AqNDHaYakWIlnr09N40SYyuRq5Wph"
    "eMRoNdHQCXCJwPF6XbYsk6Io1PISEusZtiJXA9+nOL62UR4ujVlGS240MToy9OLd2udfrX3/"
    "5WI83jf99y4P8qrn+VBM7etmiPSZmRnIab1oAOAAjAJQQhCBF92nutuV6UKxvYiuG7eXVk8f"
    "eF59gDOGorz/q0sMTWqKIYl0tjAk1yoYTlYqtXQ6fub8S7mUuOOnAM64ugZhArXia69c3B+f"
    "+FYcx/7VRx9Ua9U/fvfPf/3rK4apKPU6yQmBa+MEe3S0uFapQhqhWFZ3sROlgbt373k+aTnm"
    "4PDgxQvPd22Cn/5yHvLqT0SudORA82pHIruzkvTjH779IKFFr06F7YcDL3d3B4rnBpKpAOuJ"
    "v4+MDNE0BcN957WX2sk0gEDsjA5yBl7ARRgWBgHE1sTkiTbIIfsljo/Iq+fzMQ4p5A+0rN2S"
    "yO4wgT2S5UdvhrtQLFqZikEGs7vTIHq0JJ8dGIL8RtyHrCegStsD+sWdigNpkafadOgQJJqD"
    "1dIufX45n0sZFoJjIYUGq+VqPCE2GtYP3n6DxJ/o74AzYAVBFCmqJ+0nJiY6L27euF4p12OJ"
    "ROgZS2vNQoqF4pkkKCHOEgRPE1BV6M2WE48xJJc8f3ayl0H/48MZwJl//KuJkaGBw7E7yTLn"
    "zp0J24FLkST8LowcwQkcuDmO7RbL4O/FQqG7WNlR8vliNlcAzOE49tgJG9IHJFUMDdurS5Tv"
    "2STN+q4LMYb3POixI2K93krGxR4/pztp80jPRzCCpQhT11GawdGQokiW5XyGwXbFUOAzN6en"
    "4/H4XkfbSaDQ1zQFyONr3/1D2/WhMpIk0XFcGLnVaqWSSReKKfhBfNtFSDriP/CvwMQJHOM4"
    "rutx4dEOFhMHSWYetbsf+vMz0zgJrDYQeGZjvZ6QaNUOsqnMmTO7xTLYfeXOMjJSIhj++edO"
    "dacB8Jl//7d/FYTI78D6s9M3jpRKdblO4RjDsSurZQL1FM2F+tSyEODm2WyyKdd0F5F46cUX"
    "n+t65pevrfzik/KpsRjPd//wupae1sVc1125dw8cxzKNZCbH0N2wGtMwrk99CS78xptvH+TM"
    "oYiV5UY+n+2RF+1LHuLvkB6hiss+tqAKmtG7mhI0bjSbjhs1rtbX1rpTxfd9UUq47Q+xHZ+m"
    "IjJjGEYHQ5qyzHACwzysRhjajuu7JoLDQ2+XWoGr6p4ksls3PlUair64qiWT8UOhNJHdITHO"
    "37z+qWKZSoPleYql4xIfkxJLy0shxggc9cYbr+94M+CMvFmpVXAxJuimO1jIA/U+efLEvjTY"
    "jjNLi0vzc7NuENCojzN8PpuVFS1Gh/c2apYTkDieSnAoxWUy2fnrV1ySRwJ8dGRo4fZ8Li2S"
    "bMZxtPJ6ZbiY2ajIr//grVwqtsu4P7+0+PGV2kCaHjvY9ciOPIQzYMdOnoEKBYj5U+MPnPTa"
    "l1eTqUwsJhmmBZLJ5kRhf3BpGvoXVy+bhvmjd97d5bIHurWl93zY0rR7q5vHx4d6XOfYlzyE"
    "MxDpzaaaSkXJ3XUcnCT3OCu4DEDAB69vNDvv1KqVWnV/qrAsc+HF3wd8cBwH/ACCDyhNgOAk"
    "Eemgqmpn3c00zc5Cv21Z9LfrvYCEQHYFUXrERRzbIWkq8H2k3RLpvAnT3G5icC3Xxzor3gcv"
    "9+vV61NfI55Ta7YsyxkZK732ykt7uRlmYml6JpMvFHJdawCW+/ij9+ubm+/8yZ99/fXNTXkz"
    "9Bx4CoXhEUCbWEK6fmMmExcbmgVXnjp5olEthwxnydWG6SEhOjlWXN3Uh3Pi6rqsG6ofIiLL"
    "Wz46UszcW573UBaPapCAE5N6o/zWO+8K7P1U8dMP5j+dqv/z32KHjzP7N5kzNzNdHBmVhO5b"
    "Tp7rLsxNr29svPwHrwuC8NQRgUo+/j4gHkmSnd97HLdak2dvVy+eH6Oovd7SuzyEM11LVKli"
    "RHl9rdzDhwD9YDhpoEg+ZNAw9IMQ6lUgGxBVGNSsIQq/n4TFHXMD7oXtNtVeRBK5kWL8N7HC"
    "vCfTwX+bVXV6dqpWkc9feG59eclG8Ga1wsZSZ8+eKuSzu9wMBNQ2jeEjR7PZVNcaROvA//NB"
    "tVodGxufuXV78fackEgV0/y1m8t44KQzCVVzj4/npxc3cafhkxIR2AhKXnjhzOzcnOeSlmsM"
    "FAfgzbriqs0aTZGjEydPnxh/6rjvvT/3yZT8k7/xR48UD8fu6Yx4QXwBHAXY+nCx6PkB0u4n"
    "keTTo4Ekoj89KjEyPNSpuY5Pjk1OjgWgFo6VJk5GzhiGoA9BYEePQYz6KIqHgQ9cC1TN5gv3"
    "59BeqwGQgYAIgpAg9oQbL53LMISfzx3cJo5H7Q4mftARxrC9r7PChFmBl+tV+OlaA4ZhvADj"
    "xARgxXao2TJf56/HcfuReme/dHBkMJuMcYfSXEU6dre11qXLX5G4efzUS3O3bogCDfZ0rVbL"
    "9pMSu17VJAZ3wyCTy9aqDd9uJTN5oHoIyZ86XrItI9oeimI8xw0NdROwQeAvL85tbGxMTp78"
    "8uqVZDq9vlouDA1WNtaBiXghSiCh7YU0S8UlSVFk2wqGhgvzC8tJgUZoIZcUN8obTTP4oze/"
    "u69xf/bRLPCZf/jLieHBQ1oHpgXxwgvnILRt158YH8UIyPBUGLg4TkAxFIvbDMuxLA1ZqzhQ"
    "dGyd5SXHMigm4jAMzTTNFk5SBE51t5EG8F0Q+EQ8DnT2955/oamoMTEWT8Yz6XTgO74fWLZD"
    "MyzP0ZDDA69g2248JkF9m0zEVM2EMi2dy7t2tHBAkftw+dIgt7HRiMcOZx241/1im5s1IH89"
    "LsEvzM9DWXT23HN7Z4G9C6QLSAk7stLf6KAPeKStaV/dnI0JeE12PFNN5vISSzZV1fMRgqRE"
    "kTv2bT/oEQE+s7Bw+8TkcS7ZPZ8BOXnqdOfF7M1pC8ij67ZaGjzVI6VSS1Wqm3I+l8ulxNVy"
    "Hcik3tgcGZ/svUn0y0/mP/u68nd/OjmQ78/mn31JB2f4oWIeaDSGbRJkiofixXdYUXIdKEMo"
    "HwrqJwikssnJ44LYt1AdGCyYNmCYIUoiYF08Lmqt1vh4icAww/ESiYTnQ8rhE4k+7HhhyCBw"
    "zIMsmrZLTzjzTPYrWzhzOF2uZ/LM7ocj99eBdV0HcoITBIqEUDnBO+3dcYQoCj0P8Ux2kPb+"
    "GcurVCpQHwI/QUOfFQTbcjAcg5obKu8+bm9/Jki7Xmk0mpHdeZ4eH3/6QtIz6YsYmrq6cvd+"
    "58wwjM67gDCdFvNeBC6+du2aXK/3SyfdMKPVr3afaEu29LEsMwgRVWl6ftC5ZkdVgf9v7yIB"
    "fu7YUqptNi9/tdRuch2CtFfyLHtTlp31VdfH4gKtG5ZumhRBmaYhxOITR594eAWmFJPEPu4/"
    "qW821m3Ncz2MpEWOsR3HMExAPwxFCsWi3FBwwMEg8FZXCJo1dTMWk6JdTUhIUpTZaiVzufLa"
    "GknRkJ4y0ev16CgKyUBFMDA4nEo81Ob+z49vX/qq/i9J6rer3xQEPvgJsesiX3TOpk/+gqJo"
    "30v2rVb4jqIo6sJS+bkzYwfc116YmVpcWo783TQdRW04jsfQJIoEph1QBEozbKMhsyyLtq0C"
    "hWssHice3qMKYX716tVisS99g7BUGqtVKqbtMgxhWh7H0vAwXMcBXQmSaDTVYmGgVqtBHcuw"
    "lG64PM9ggdeyHIkXDTNqi5MERlA0SZCObWqGJfIc+E4Y9a78ZDrDsQ8t+V79pvzZVHmwkMzn"
    "DmErdmf/DEaBXaNtBO0mMBptV4pIpBRjGSraGxoE7cNjO/hOoVAolfZxiu5J4rS3cYuSiJs2"
    "gaMo5lNgRQwLfC8674Nh+VwOHoMgCBRFgxP7AUriGMnFMNKgSBoncNsySZqOtgmAl1BUgmbB"
    "jQCmorO1YfB48w/HPFvXD6vP19M6ASQ3pdnoy/pMGAQQYYdigoOUh3DGtl1VVWzbYjnedyxO"
    "lNqNUxMnSIahLdsiCQoy2OOfAgB64+Y04HLgRc3BdDb99L1OjwlFkb5jVKvVc+cvWqZF0ZQT"
    "YQvS9nQybB/2AK/U9ejAGMexmqLgLCRVnaEZwCILkq/jcBwP6TbwwyAMaJrZS7l35es7V29U"
    "/uKHx1LJnvYzdyed/TNRFmU5Tmu1AGGi8lXTQHvXsQGCXNeDGvZJTy+bSbdURW7oLBXmCs+n"
    "Yvv2WUCYy59dqtdlpL3AqTSbBrApQAmK8B2bphh4qJbvoRgGnsHzbIBgPEmaYZT3bcsyLBuA"
    "23FcgHTb86NTQnvbdFWuNW/NVx2nDyDZpd3B43K5aONRKnm/yRvbdjRyF2cA/E2mUmNHj243"
    "4n41CKPkAU+ZhU+LJ+Lws/v1LBvR1q0qett3zeyvQ/3j7539/qvHD7O/Cs6iaRpJEgAvghCd"
    "tQUG2V4kiHZaKarKC1J0dNgNREnYzizB3xcXlyYmxns8N/zyK/e/KMayLAg1yO6QSFlecCyr"
    "c27bMB0+ghQbzORH2wtwKI78EHIjAqoCBwgizgKsMeqGB20BtwdeD64B4UKQlKa1cJwA2Nwy"
    "9MxC+ebC5luvjh7KGlRkdzAxxGtddkSBhciNStboyxawmMSZhqXpOswR5u97PkT/drsDwRgZ"
    "HpL61/dQmsCqFXB+miIBtTXdAAvyHOOGWOBaUCI1FU3kKTC40xbwDCA9sbhYrtTgLse2wYgR"
    "//I9lo9ZuiLGEy21xbJMq6WBF5kWPZC/b/frs+u/uLR+8Uz6UOz+gM90zi0+8n0AuwsYZW5u"
    "Lp/Pt7/iqZ+ypUyvpyWfLIZhLN9ZOTE5ccDnDh7wGU0z600ZeEImFa9uNiWJtxxfEjjL0G0P"
    "AhaVJCmf22HjGOAScIw+rhPML9yhyRAYuNbSBosD5Y0KzbFQQACX53hOUXWISLVZV/6vvatr"
    "ThqIooRsEpIAIdDWfkjRomPrjI6+6E/ov9Bfof/LF998aX10BnWcjtb6UatVoCSBAlmaL8+G"
    "TtUKanEpM53e4aGUYXJ32dx7zu49N51wykzrmXSP9nAvkqTfsNuKlrl+7QSA+NGTrfWK9fB+"
    "5lJp/tTm/cjYvGusemcmnMHMRoZZwCKLA6wQ+CawQVyeOJhcgFvNzc4O+3QEKy8VvXhXKzk3"
    "j1W4dCWNv+EMci88yWZzgADIJSCxCOj4yeFbxGK4sFAkJy2ovr1i+gd0+m+9jcZk8X5k4Dcs"
    "Jpdxux2MEyEeIRJML2TbL1hQHgAlsN3vX8aw19bX379/x8ubVqvdlxWATyCIuV03YgXvDKLj"
    "re97jtN0KVC+C6eQSPGfgDXx8j0W7Xu16rf9dvcff4AoIilVC4ef2o/VDuv0AGlop5rSdQRU"
    "x3aiBFtlRs5ot9rgTSx9SYp28Tg2j/dPeovFIi9v4EarZTOqJCSBr2x44rC9ObwANAG6cBPk"
    "cqyzoUREPZ0B7QB+F5hCSgfmkWX2lfS/CU4qG18er329c6Mw4bz6BxuW37BYNjc3ufghEfIz"
    "D/jl0uPJrcirH7d3VpYnl1cxfVtvN5NEBlQEjCCsPlRSZMWyGiJhW2TBARJtQlYU3M+Iqqqm"
    "TxUYSUFelSSpXOZQBtInXJbddGw7bjDUVUCgVa3ZbGopGcEONBUQPRb2saPHen0PCFKU5Sg4"
    "SOemRujVibz69Ln14N7k8irCyOXLSyAgGHx/ExyMQ0iyxgNHK4FJn1ihM1Oox/0yxmKA6po6"
    "G4RMuodbTBSFfD4PZzyfHbQTWUI6EpIiSJKuaX3lWyycHOUE+Nay6dGJ5dXDukYpnu5jalXp"
    "VzXI78WLMZ65MMLewACLs+EwKSk5fukfjo2sPl25WsSLg+cj2X/Vk2L5a/p5ocfJbPdbzXZa"
    "53VLp23UdcPAJ532/s72FutylPgD7j3FlH/WDVNpGAb58HH7Unm5Wfv8YuM1smlpcb5aqwVh"
    "pEgS+LoY70cZ07Pl0gREEWfSLi6wmSSFQt40tLYjm0ZWZOkrymYyB6DfnqvpGSIkKKGJ0J+0"
    "t2fNuPXDJpI8LBaBwnOJU3EftKHl6pS6XCoyAJSHVX94vp/ghKG5tagSWFkHq6WxLNs8PDM6"
    "ZII7n78sjiQ5O+4rkXCJKPT3rH1VIVJKlcXI7SU0Veq6tNPpTE/9l+ykbzFTwUCi+p7Vp4eu"
    "S1WN1bN82uEzkMQ4nndQq1UrlZcyEW/duZtR+asposDbevOu43mpZEA9b2audPP6GM5II79R"
    "rT+rvDKzKcehq6ucH53ALc7U6g1K6eAhRFFpkUMtnB+Eu7tfB3/kB/l8Lmdw0N+09tuO0xz4"
    "kUvptat8tDHnzzuYjH0HR2tzLI5WUwEAAAAASUVORK5CYII="
)


"""Help image on default search page for SQL window page."""
HelpSQL = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MTM6MDEgKzAyMDCprw7NAAAAB3RJTUUH4wsDEygIdIdmwgAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAAB3RSURBVHja7FxZcx3Hde7p"
    "6dln7o6Li40gQIIE90UiaUm25SR2kpIrdmV5il/zkMpvclUqqShxVR4clf2QpSJZkklRIiUu"
    "BiWSECDsuPs2+9o5fS8IQhTAcBGBgqRTIDicXub06bN850wPuZmbV9F3tOtEHl6JSiZX5DgO"
    "rmkSB2FMaSLLMvxz6YtZjqObPX0/kGWJ0o07QRCmDG2vF7LPiP+Hv/871BP64SMnKisLv/yn"
    "f7v84bXRYuHKlQ88JEoEcxwmBCeBe+XarWq1eeLUCYxxNpdbW10vDY8ahoEo4hB9bk6+FWTb"
    "9v++/e7U4UPczK2PiCCNT0yBNFkLTWr1ZjaleTEXBV4mk4F7K8tLmCl8Ypp2KmV4ricr8uZc"
    "rusmUbDXK9pXBF4F/HucJFzPv9iOo6kq3HeDSJWEvebum0w9HccCwpJpWQ2bsyLR9fzLy/FS"
    "3d5r3r7JxOIqTRI/Cnmen23JxAwuDNHzRZ4m0V7z9k0m7jscuSdEohgdmDiy12x8uwggDAHK"
    "ZrN7zcm3jsC/J2VzXSRKEFp1p6GIaS9ypwuT9+oLKhEBu+eVrBc6fhR5iTeRGfto5WNNUKcG"
    "jjXsdTMMKA0VohzMHtzrhewzArnjkjEEVxbmKIcjilRBAr8vExFgJuFwmMQJjYMkUAUtoUlJ"
    "L1bdths5IiYKwQIG3Mnt9Sr2H7G8KT8xCvretssztfsCUf/k0B/PrF+PKX+yePja6m039kHE"
    "r4z/oNJdbbutEaMwU7sbJlxWzUexd3H04t3qZ5ZncXyS0UZDr7ziOiLHga2cHT5XsypftObC"
    "JDk78ur9yieESCiOEl4+M3h8tnq77scFNWX67UujF+6UPyubyyKRpocuzNVmUnI2SnxCcSfo"
    "Qspc9xxdUF8bf+XjlasKUWUpS8PWTH1Ok7IcpYZEOEpyWulgdkzk90faAXK/fuL0S3CVgF73"
    "0n2e42MaQxPkqKDgcIdSSjBpey1DSvmhg3lYKAP+HDMIPmKIE7JZymOesqrNg7pN5MuCAjP0"
    "hzfdZlpO95swBz2TXmeYhCUR3cAG9wUTYg5DU++psR14urRR+YGuBDPGYBDrBQxTlu7BfZgB"
    "FCKjZGFazO0P43so9+9oN4nlTffvVCjP6ynRNAPfCY6eLMllE2VkFMSgmQjMoOf1mcqB+lsx"
    "GjXKa91G3UnltJQuGLpwe6YiSSLl0OCA6to1I1sgmNWAVFX3XNps2JYVaykRVHTqSHZxcSmf"
    "z4NS+15cKObMbpeDeSkSJQXFyI8SXZeElTZcozBBIs/YHE4h02M8AAkcWrMZV2GERrOg6sgL"
    "kECQEyGZRzkVEQ5mYRemz2aAngKPdBGtm2A2zBpjytaVUVBa2ju506RWtXlZrNQtzZALOQ2c"
    "CBox0EcrgDOR5aGcDq4HEYLCANxB9PKwZ0eeG9h2GCV2tcGdPZ733ahrRnEcaToT7r1P79DI"
    "50VVTWcNKbO2ZnoBzYQRbAyimU6zsby4rGqq7Xjn9IsrS0utZi1K8MiBieGBkuuEiioKwwaa"
    "qbOAHUQInM4wQlUbdX0m2eN5JmLHZ+4JGGu5KCejpotCioIQqSKCPQOZZiS01GGqA3sAWnBk"
    "gO0cc0IwxEODBgI92Dv6zs/sDRFQJm+vmfi2EcfkTpN//pebSJEUDcA7Vnj0/T86VF0zizny"
    "77+Zkwnvx9HLL4+iqGo7jiSKgetBMAhc+/CJs59cXl5vhRpBvhsfOjOs8/H8fLfRNCeODnmm"
    "++MfT66X7QNJmm1sFaHX6G9/e2d10Tn3w3GDJPfutzsde2isEPnBn/3p5NKaPaGkURkhs1ck"
    "heAy7f/rmzOcSF577QCm9WqzbWiagLlGqyXwOFcamxwf2WsBPiNByOJu37o+dvQMYLEkoRBs"
    "eABrPMOIEOmiaANEwk1AmXCFMRfFSRKFfhinUylAggDHGZLDDHQChIvjBPOYRUmIf/2QGPd+"
    "mC+mQRBzPajIUGCScJj1hK7i1p7cRh5GcRKGDClinqNJDz5inMQxQ43t7srqytdS3vA9x/dc"
    "zw8vXvrerskdhAERByIQ2a6R28ASG3uENy6gr7QJA7iH9zda8aPz8L2fXmf1Sw96TM8HHaQH"
    "fR4+nc1gFPLIdexOu9Fqi5pBAyeTLU4fe5bqXqNe/s1bv05lCuouyh1tfa+972jswEEl1c6k"
    "02B1HIefbZJu1xobO1BvdneZ+X0sd9MyDVV2PF/AAFDxwuKipqqKZuiq/OSTsJKsIKYz6V1m"
    "fh/LPQ79qgmpmRrQyOt0JCPbbbc4XnwquUMGp8hird7cZeb3sdyNTE6Lw7bl6qouEUHWUrls"
    "aq+ZelLax3KvrC6bAc1n0la7WV6vpwaHvpP7btDRk6c3ryePHN1rdp6O9rHcP3z/vVqn7cT8"
    "3/zsjf1S/t2kfSz3Sz/44V6z8OxEIAXttnc7mj8n9d/GfPaHW24Q8zwJQ49y/IWXn726Fwb+"
    "LguB+K594+OPRElgr5sg/WC5e+9lE8/7nkcEASxYFEVEaRhGgkBs11ckEdJ4yODjJBEFIYoi"
    "SPoh34c/rFxPkUh4ILgXQ37P2tgrIVEQPc/jCU9751gxj4MgkuG5lKOUCgRHMQ2DADrA42BQ"
    "HMe9oajvQyRJiqMoCENCiO8H45PTI2MHTcdVFdFzXVFWn0cKltVZXpzdTbljWJkgMDGJvQOR"
    "mL0pY9IHEcP6BUIoK8tgEG7v5RqIj1AEexDC4mFU1JMOx94I9mstLBNhm0cT6AMdmExhCIzZ"
    "eC3HZgN5Ep7039LhXkEGJkG9DeZ6FaEw6I9FwADPDsxy/aeAdgts59iDLNsimIOeQ8Mj+dw+"
    "O4pCNE3TdX37Rh01W+3iwABbp7b9CXdoarZahr5Nq6L0/3qYxUA6ubWDLO/4ukfpNanK9hmQ"
    "IDAViXy3aTmUlwaKG8f2d5MkWQGT3LYJ9M/smun0jqC20WgypVtdWmx0TASy1XXH7CipdKNc"
    "JZJ06tSxVquVy2b+cOu2pMi27WWy6XqlXCiWgsBzvQgWe+TIpGVaKUMPY0oEKQ6chWTpU//u"
    "IXHyhDS9vl6BrRkaKr2IladyBSNLHdsur69B2jQwkN9NuYPQP77+MUifHQig1EgbYM+ri/Ny"
    "qnDq+CHbdSWBm/l0TlUEx/WHhodM07bMTjafGx0ZaXc6DM9ohgFGDh43DnwjnQbpoyiq1uue"
    "t3GqvVAsgLcVwcPGSXFwUNPVbhcCmuCH4SYfGPMcL4DTMRMTc1jg2Myu54FfekErrywv2l6o"
    "pbNmp455cZfljno+GQKZoMi6rrFw6AdHj00H0cZxCo4nEI9UNS2BXYukGYaFgQJc9rw14q59"
    "8LtavbHT1BKMIIJtP+5M9kAhpyhKwoiSB873hRo+PCmVGx4fH3/+qbqdlmW2b9y4cfDA071F"
    "WVuvQMzbqTWXyzabrZ1aM+kUhDdSKu3oB6IohqjIPqZB7J0Gz29fbnW9sN8UhDF68dTfWsib"
    "5ufWxaw2mDHCwKs3O4ePnz53avqppgJ88N//9Z9hFA9vcYaPWekmFQqFx3fYSapgHK1mi/vk"
    "2mVR4Hca7Pmhokih74H7Bizhe65h6FHoJ4hsHQXifswkT0uAF9lLrTjZKa6C3BttO5vNPfmc"
    "YCJ9cAWgE+KeLMt+ECiyPD83W61UeILPnz3N4HJvckC0AnnGgv7/S8sr6/V6/Ymc769+9ebp"
    "i69PT46/9eu3JE3z7dYP//yvr115G/IN8LCcqP7lz/9C/PrOx1157/LM7HxE41/87S9yKeWr"
    "HcCJFbKAwZ7ioyrIDGji/vLN/8DsGFDAyxlVEn7y6tl33n0PxVxhsHDjH9/M59Kh7/zkpz/P"
    "vrDPE2FTZUXBgKGfRN/75+a2KnW9Vsvk8uSBMX69+v4iCDCCLBHIb5UH321FYdDqWBCcviqa"
    "F6rvgiDOzX9BwACDcMdO4PgGUgXU86eQK4rCBtNGemBrt80myOABzPR/91eRUPQMRastM3w9"
    "JCogd8mgX/reM7udi+5lhdHmSp+KW3agLqE8xjutAjrMzd6rN1oEssetqvrJjdvnzp3elBPs"
    "ih/EU1OH4Xpx7u67v786Ojzy/R+9LnxZJo5tvvP2O4OlEceFLXCr69WDU5OaSFbW1vxEzRm4"
    "2+mOHzxYr7ccpxtHsarpgEEhBRgYHJR5tLC8WhwcsFrdQ9OHlhbKisovLq6Xhgqu7RWKg6+9"
    "evH55e553q1rH0YccWw3m8t1243S6OjqwtyBw9O1hpUW41rXy6pCuVz90Rs//fT6u8u1QOCo"
    "wAOzLH8fGR2q1hqB7yAsoaBDRR1S7QQJwwMpXhDmZucPH51aXatKnF9pexpgZ0maPjFdXlly"
    "bZsTFduyx0eLtWZnIKufPHUafrjrH76P8UMpNhr1bK6AHwg+CKIjx04qCqt+OI4L2AbAk6I8"
    "6nN93welDqNIEFm1pFcJSAhhm8oKO4APogiiVgAdeAw2BCHOsmxNU8AYwPOKooAxKyGAN4C4"
    "3ahVZT1NcO/cL4c17blqL5schmHAY97zfUjRE3a6mDEMABySDIGQuBd444RqqgJLYDUkRDlm"
    "6VwQhICnIVHqHa6EFcVElDiGhSKAPbDMMAzjCJAcLwmwcFDWCGMC+9KvKUFulMQRIOyot/DQ"
    "Z6D8UX2noQ8iEB94NxCf2bX6yMG1unc/+1wQldNnTuIve44ocBaXa5JMZFFutVuqqoH3BFZU"
    "XYNcWtWUTseEDLdQyFOedCxHFYGJsNnwINPLZtIQLYxUxjK7qpHq0/ML+qvUrFViyhQi8CPX"
    "7ui5gVZ1tTg0ZruRLgSr5VqxVFpcWHrllYu3b94EmOgGPko4LZ2RRd4DpfP8KA6JAKAOfIBr"
    "aBpoUowwiPruvdkDByb0lMpmdp2uZaXSBZx4Nz6ZnZw6HkdBEoX98pcfJPkM09pHfShYU/Jl"
    "J5j0giozVQBeqlYspOlXPooHrWS1wiCo1qphEHXbHVCTTtdst+qW4zVrtTAIwfNBq+M4fhDa"
    "ptlutxeWVziaQDfI7bqmaZkWWNuLkPiGSoGOE95xPLBDUdEVAol6BhQo8F2KSSaXQ6Gf0nVI"
    "QHL5vOPYsHLwIeW1tUaj3e10HNtKKK6Wa7bdTeKk026C+za7piQJ6UzW98CXOFanvbpWhlbH"
    "tlvNdqFQ7LTqEOLW1iqVCiyNs0xzQ2KP+BkwGWFLSAE/c2Biqn8yywUvbtocz4PaPhIoPdcB"
    "DABJMAzf6oX6s4FrAmOE3yB6sFlRkoWehcEdyNps09IM3etNDus0dK2Po79eAj8DosRMPyLw"
    "M+1ORwVvE8eKqsYROATSbpuqInZtt1jIVyvVdDolAuDrjXVdFxYF5uuBwxHFx6+RQwmkOqDj"
    "/T4gaJ4IiiJbZgcLsiKJZodVBx71M9cu/+7kpdfTCtlU9ma9MTTEPoAqry7N3J0bLORLwyOP"
    "xFWaxDcu/94Ok3atqWazI4X07PxiVhdcqkgoFPSU74LLo+PDuXtfLHOUDJUKoO+FgWK11oS9"
    "GBwcpp7lAuugh4YOKcyL0Pe5z+7EWOiC28zlaAwYji7Ofz48NrFaaY0X1Vt3licmSgtzi2/8"
    "1c/WVlevXv5g4vCk4zm+4+UGBxc/X3zpwqn7d++DerXa3Uw+n5HxUrUlcrGoaLEfqoYOEQIs"
    "fiCXrdabYRQQnsScEHuWqGqnjk0tr6xZlod4dOmlU9vo+yME+n7m/MVNlZGk7Su3j2l6DAUs"
    "ou7SIfQn5xDCOzD2DMt5wsm31/ePrl0/d/68wD+Mqzdv3bx06XvgWBqV1f+5fnt0ZPSlixce"
    "0ffQ7X5wdQbzSCKk0WxOjI+2mlaxVKiU1/XsoK5LleWVwmCx0+2m0pnpI4f7o/r/uc2uEeh7"
    "iPgIsLmkuFYrVxpeX5wbO3R0/v7y9LGx69duvfrq2fkvGucvnrn+4RVJVYmQttrrRMsg32t1"
    "rYPjo4CDB0sDEJC6TfZNC7gpgfCW7Q6PlGrlasKhXDpTb7VTuup4/vBwaeHzBc0gCZdK/I4g"
    "4NzQFDUr6QEGUrhrV9+n9GExq1wuF/6vnCvrbeO6wrNx9oUcbiJNSdTiyFuduElRB1mcAEnT"
    "9qmvBfrU/9e8FEiBJECCxnCTGLBdxUskS5a1UNw5w9n36bkzluxIcRIgUhb0Po24iPeeOfec"
    "7zvnu1OtU+STAA4A6eLlVxjU2MMMw4DPAxpT1fIRJgShH7Kl6wdYEvmeX6ALkIwB/9m2JYnK"
    "FEIbTsLdjTEcYAAgxZ/S3PkAf9e0Cex90wKOWvHDmGcoD+4BRU10A679MBF4eqIZs/Pzjqkb"
    "pq0Uy66tExTj2lacAsZDWmi6ABgGpwksiiOG49M4sWxbVUsowbKc45gEQbKcgKeRaTs4RtCA"
    "hbwA1g7IVZJLUWDnTBiSAcmyT7OEa0uKLB0GHkC9lmEosy24DjxnvzckyUKjyR7BkRDfx5Op"
    "oogQ/kReJAuoGA0MhaYZRuBLRApJwsW4lbOLP6PcArY2QDVId2mKB65F0yXftdhiBfgPZFdr"
    "MADz5MW4wb6Jk2wc+UA8GK4g1+tAJcDEAFgURQEH58DE1pSmuX6/A14IQSniE4albcuQFAkQ"
    "Z1FRAMIJsjLVtZnGjKFNGE6MA4h1XBL7aDIp0rA/rSPvPN7i5SJ3oMCGBG07T4rv4O8TTa+W"
    "S0neFP2G3SO44b3uPsOwsiKN+n1aKnmG7nnO8oVLie8ANo/x8Aca6JQGzIEgaX1qFEvgrBEb"
    "uMAqCjQ/Gk7QViSZ0LHHg0Fy8Twg9f399RR1hBT30RaE1uFoRAsSqhq7bl8zhQIRATmiWEOb"
    "9ns9oKdAx6gCAf+t1+3zIqdPbSy0Hm+DQXDdsCWW2NzYVsuyWCxLHLLt9+fVSy++DCwLy6g2"
    "usDxAnW0ipkrD+D/5O2OMOv6Y1kawbMBr8C74D7AeHEce8IA4HYB16bIvKKef4wE3JN1TfIv"
    "npTRIc7A5A8b6xl1RKvOZ5XJIFKSwOEaZg7hkedF9OPZDPLJYZkyIl9jvq58DfnMD1d92PY5"
    "tmo8aw0ljqVjx/Pqh//64NW3/yCxT3Hkjes33n3vXbju7m5d/+J2vVp7+913juTVwJ68/89P"
    "lZJqG1axxPeH2sKZ+ubjHaVc8QyrPDPDYH5nODF1p9maac01d7c6ITr+5yjVOQoiYeADL6mV"
    "VTcMPNOU1JoxHr7y2usrSyfQUTocX3z2aULQgAIbzaZl6M1W8/Hmw/byudu3Hlw631pd3bhw"
    "YeHe3Y2//v1vO/fvrz9YB0eaP7u8uvqgxNMexVyYr928sz53pjmejGda88F02Fpe3lzbSAgK"
    "zbkkj4ajleX5r+5vSLJCxAGjqGWJ2djai12n2mhUGs39zbX22cW5Vutb/B2c+lmYceI40rKs"
    "4/KFEKg3TjH0KYrXfjyOhPSGUUzguc+VX/yAVT8XR+497jTby2zhKY7c3t5eWUGqT2s6uXnz"
    "ZrFYufLyS+Q3A0AcemtfryVJDGyWoWg/9Kv15sO1B0SaAjriZWHz642FlSVgT3jib25u1WqV"
    "KEwc31NECK8jx3UazdnBYD9JiAuXLpZLp3IKYOfRZpwScRITZCHyLL5UGew9ml1c6Wz3qjVp"
    "Y3P73Avtre3O1dde311/EFM8EflICARGIBieCjp9W5F5QeQn4wmQa4BlkwlgGCDpVGd3Ry2r"
    "NCv6nkPhYAVOFoidPW1x6Uwa+iPdD71pgWHLlao27LZmUSOXwp6pwMAosDzchcNX4P40Zmby"
    "PwFLnX1hhSmQKNB90+44oC26EKYFyNE8DFLEorBWB+QuFkjKsvVasxkHLqQ1lmFSdAiZdl1L"
    "FriUIAGEiZFcVhVUqY4j23ZKinTiRocpMxwHlF2fmjMzVcsRVQn84RJEXlmVOJZtz8+VKjNg"
    "O5rEJVm2vMQPo0q1EqBiBotFeLPBZkosKpN2SaIk0QXWcRySIuuNlizxgF4MfQpAGji3rmmN"
    "pgrvSjwvCSmp1LGUQG3q+MmhVSpBxfmncYYXxUyYdTDdFAOyw2SRh6YLpmnDNIpReCTfBYEv"
    "F8sCz9iOKSkVEgfbJmGSVitluHWAcPJDfHk6ypRfhKJIAGFDgPxUIfA8QHJNlh6OjYqqWMY0"
    "JQGVnWQDC4AZgfqriSAgvRGwDBN+PfDimIHEDnCXS3GSSCHMBkicQrbnz2SVaQz8AGIORZXg"
    "AvJtvV7LMyeqWlMOqlaVS9gBVOBnauCUE33abrexLLyArdU0he8Cm4FkXq41PHuK5bpU6pmo"
    "8dknH1177y8l4aAZRuB7u7uzs7Nw3dvffbyzWyuXqTZzpAsGkOze3bvAI2gi1u2vsQQrloTh"
    "0OmU2FFvHEZeTNKLc7N7e92L55dWV1dDgrH0CUXgZ1fODfs9XimrArXd6c3Pt/976w6OR2+8"
    "88eTZepgJn08Ah5jGKZSLOaF2e7eHieW+/udoFUfDCZWo7a3vduYnQXy+OD+GsOTUwM8yiVp"
    "DqK7Wq/xNHb37rok0p3driDSjdmFQX/MUInpOERCeHG02G5Tqb/dG0d+ALvWdGxZrVujzuzi"
    "Uq+nmeZYliovX0HnDk+rPnMIp47IaZ7Crm8zzempbn6C+kw+/+etAnZ5Jht9Tl799ycfv3T1"
    "LfmZeuSXn3/55ltIaT7Y377++e3ZM62rb7x+FEc62j/e/+jyi78JHWswHkocF8RJ4FumU6hW"
    "Rcy3PKwA+dZx7CDw5hYWcYI0xwM3SJfaM1u7e63WgjYedrrdoizTgnLttRNo7B0f9+/cCjHS"
    "90JRlkx9VDvT6u1scXId8u2LV87fuHHr2rWrD++vv/mnP9+8fr1AcQuLjdWvtpbaNYwSPFvX"
    "pnoQpaWSmrjmQLN5FvgAgxNJWS2PJlMijUaasbi8NB313CBpNOv9bq8x09BNczoatZcXVm/d"
    "mzvbng76v3/1d9hxf9d0vZQ9m/aJQYPo7LlLPJ/3+RySIIMwyGVMzw7PdUzLLRZl13UzRo3T"
    "JJHghOvYKDdAQE1SSA+2g2R7OX1gWS6MQlEQIPD7QYghCkWEYcByPMeefC0Q/B3iMyR523GA"
    "66PHrlA48FKKJMI4gV90XQ8CehAlpaJim6YfxYBrQ5hUEqU4VSDxKApztTRqXeMEy6CSMoPk"
    "K/CtFLgkfB0+gB4A46Dn+051DXIvqlnFoSAqge/4YUJiccZBj/p76hi67fqLc81Dfw+QTb35"
    "uaZnm4+2dkiSBjx0pE6QxEGns0/hqWYC0xPSKNgZabNzNd30K3g8NgKALsDNUYeSRETRssMo"
    "SkSBGw7HqioBh4aYfvnKK/SpqSeQS42Gbqa1dxzPNjS5XNNHXZYvToajxpnqcDBmOQ52aG2m"
    "/vD2nReWlwxDd7xYLamQb4HlWZaDHAIHOBeMxqYgguXpiaYDPQp9g6EksKzleLxUigJvPBoL"
    "kjAa64rEW57neAGi6QQJaDF/4sBRqtLr7tNK7dlXwMFxEuEZxwMMhKtF8Xh9BoBkURa6/SHD"
    "Mbpm0OhIQdLtDqIAnxL8eDDEq1XH1oOAkIp8SVG18SBK8JoqdQdjhm4rRVmRuV6vP9dqnJ7d"
    "s/YWrU1NVNIosETi40QBhWN0SoISgGVKPAA2uPNqqWSYum55IZL1FgDRJSkhC8xo2Gcl1dLH"
    "qG0Je4hwgzDSTadRVcfa2LFMQBYMTY/7uigWHz/aTAg+9GCD2bxYHGoTAOKNeqnX2+t2e9+f"
    "Vy9e/i1ckOj4h2vbLiCn0rHTzdmjFSKAhnGMWua2ZRQYgSTQUiFBAYoi8AQ2YxxFanZAAHY9"
    "lh3hgLcoJNGk8hJQ/nWAeZ4fCgdi+fzFH2l0SJWe55IEBeGC5zl9avCCgGo1SCOUAGa1Ie5z"
    "NBArjmOMqS7KxTB4MkksU13DwvGsOJi33WEJ8GemkX4yvcPUHR/o4tFaIiQ6RFEUpzgWnZP5"
    "+MMPhsMhvnbv1qOtxxBVmzO175j3fndw4eLF03PG/4fxcH1tommLbQTKUZ4ZjcYEOXWd7xJb"
    "W7bzc0/71z1gb3V7PWAPud3xr27/B8ue+AKQA9I1YqgZ+SIOQngOPI9fHALVQ9x6eIEdAHaU"
    "QwAzEqeYLX+lgzJM1zKnwJEdNxR5NisyxzTDQcRWFMGy3DgrzhAEyTGU4/lxhE7aVSplYzoF"
    "yJfJUUi1JAHFT5OIYfkogGyTlsvScGSqRX6s24Cwmo1a4dQOfvwax8k8hzzPJOhoIPWLVgX/"
    "csb/AAM3BftMsKFIAAAAAElFTkSuQmCC"
)


"""Help image on default search page for schema page."""
HelpSchema = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKXRFWHRDcmVhdGlvbiBUaW1l"
    "AFAgMyBub3YgMjAxOSAyMToyODo0NSArMDIwMCrsy/cAAAAHdElNRQfjCwMTHRolD9U8AAAA"
    "CXBIWXMAAA7DAAAOwwHHb6hkAAAABGdBTUEAALGPC/xhBQAAIVNJREFUeNrcW2dzG1eW7RyB"
    "Rg4MIBjEIJIiJdlKtjS2x2Ekp/GOp2p3qva/7eet2nKVw27t2LNbu+MZS7bCUBSDKIoSE0Dk"
    "7gYaQOfe2wBEkWAAKVH21N5SsYDG69evz7vvvHNut9C5mVvIKwiCpNADflKqVZ7jUPSg3xHH"
    "cSpKhWWYVzGwv5MgXlG/AKph6MVCUVW1kiTFYjFZEnt6ExxLZ7O5ocGBXDaj6SaGoXVV8wne"
    "eq2O47hHEKCBYZiSKLNdLu62bftDcZrhYDrUeh3FSZoid17IMkyMwGEWlUq5rpR+aTyPGq8K"
    "92dhF4slrz8oiUXTxCzTQBC6+QMktWXqqVyRpknbdkxdE8tKOFwLBUIc18p0AD3eMxCJxr/+"
    "+stCoZhZWy7Zns+uvzs3N7++ttbfF6rWjUh84Pr19+/d/nF6eurvH/dqtfrn73+4cf199BXx"
    "jCRXyuXyvj8BysGAX5Llg851HCQQ8AmCPxCKhCOx50ebAQTV+uxkMvl4PIY0GKtclrPpjV8K"
    "0OMFLM/v/vNr+GvZNo5hJ9KnXFZ8gudYp9i2ZVpOva42TxQleXJirLE4/t8GAaBXy9LDh0s4"
    "zfv8vnDQN3xq8CU7jcfCR298/97fxIpKc+xAX2/zRF3XMBiVqtNMa3OuKFUbpXmONUybIl81"
    "N77aIAnUNlXCtEySYSenp2u1OsexMA3rG6mX6bdcqQJwR2/vD0cCERfeQrHUPLEkSkMIcufe"
    "giTlBJ4lWGFibJDl2fTmqlzHbV3tHxp44/LFXxrAFwyxlE9vPCEInHj7g48VRREEoVKWTRvB"
    "HEup1QPBMEiLn3lMlmUtzt0jCFexjAz3hoJnQOTAZxBFsVh4YKAPPsuy7PP5JLHwSwP4gqHW"
    "q0hTz4iiuL6+PjEx+j//9WeMIhN9ffmtzanXL/Hcz6+gnZn7DyqVSrKv17Jh18EAX1XXKZKS"
    "52ct2+JYVtd1kqIAegzt0JdhmsVSJRIO5rNbNMNgGFatKhTN2I6DWpaqGzhJdsejHcek64Yo"
    "VyPhAOSlWq9ZCMbRpIPi9ZrCMCwIM2BFIEDLsbpinXtrhot7KBTyer0URX36u08h8T0eDzI1"
    "8bMj7gaw3OVLF1ZX1+BzNNbV15eY/ZuUSW2sbeb6koOIYwDUaq3mj3YF/L7Oc2g7I6OncdS+"
    "PzMTi0Y30ulIQKjV9I3NDb/PjxFwx1g8Hu0oJ0DOjp2ecCxtce6+Q/CopW9pOsgQmucrslyU"
    "awxFgDAAqxiLde6tdad/+uM3737wUR3EhKqura2Njgzfu3tPlCRVs5L9Az6BXl5Z+/DGbzrl"
    "1smEZZkrSw9WnjwFYwW2qwUfKH3LIoiT2U6hN8CxSV8vH9AV/MWOLwVbNwPjgJTv6elhWO7c"
    "+XMlqQzkbjkogTnBUPTnAb0tKIpuYrR9VyA3LcshSEIUJXAAe08BgmKYDnsSLKmTAh15IcSb"
    "8TyJIKGAYcBQPX78eHx8/OnKMkmzpmHSDJ3e3Ih1J2KR4EkN19SqP9y81zfQb2iqCUluGiRJ"
    "BoKRcOg5ewDoP976MZ8vsTwPTSgSD0bjW+tPxyanKsV8tlCw1KrtoKblsjbHM4LgMn5fouek"
    "BvlKY9fihdmDdABhg2Ow8diY5WZYTTMFr+dkXYyDYD29PRSBaXU3hzmOx3Ac4G9rNn12qvkB"
    "RgXTYBpGf08MpxhQXBhOMKGQYZg4itT1kODhDBitbZEk9UtD2iE0TQOYd+EOtwfQ8zyPAgw4"
    "Ge/qqshiMBxl6BO+GVhJyb4eqVKN0IwDCx8SFcNJon35txHC9le3NrAjdjLO9q7wMgE2giBp"
    "x7ZOkJG2YzOVhkW5C3dIPVBpwDOg0vKZ9NpGCrXt8Wmqp+uo8ujoYdtmMZeVJKla12C6cYLw"
    "+/0T4yMdT1x6vLEwPx/we3kPf+G1s0e/4tKjlbJYkivK+YuXggK3b5t8Tp6bn0VQXNU0wrEu"
    "/uqaj9t/w7h19+FIIuDQglgSIWFqSi0xkFREcfHhQ+AGVyyR5Oj46Whof93V0jMAN6gq+Ass"
    "DxQPRA97FBDOicP9HPeGguZYBtYdTbfubaeeQQ5I3qa8galyEIc4Tj66Zf1yheU5yGLsgOp/"
    "o3O7UXmDv1hj/R/Y0nHLc63nCO7+D4NxnFq9DrfTPKdxdvvp6xupffId9PvMzMyVK1f+97tv"
    "LUr47ScfvCIxY+j1pYXFzFZOdxDbNAmKjoTCFy7syt+iWPZ6+J1HqrWaKJY9Xt8LCImKUvF6"
    "vHplfyLStDp4omJJHBw81bErjsG3tjIUTRm6AfoKsNc1PRQKcjxPknRDWyLN2chkc6HA85Tn"
    "+VbFcBfukAiBQODatWuQ9Z98/vtXA3graNZz7rULbQch33eNBwP73Mpoy9BmFlfGhvojkcjq"
    "k83P//kP5BGv9Kzn+dm784urDMdVRMlEbRLBrn/2ecTfIpxSIfvVl1+gGPnW2+907G3u/u1s"
    "QT41NPjW21e+/OorlqGvvfVeRcprag3W6O1bt8o1A9CfmhoH88bzzzmNfFbUa8/3Wq02Ozt7"
    "8fXpv/zlDnAUWL5YdzzA4T/OPgmwyOnzl6MB74ngrtYqMw/mGYoWZQUSHiPoaDQyMjywsw1I"
    "TFVtldiANLtjEcO0WI678cl1o6ocS2CB1KFZ70cf/wZDMZgD19y72sGsVZUW7qVSItFXrtS2"
    "jxwSQN5vX7sE3JLdWjs7NQb5IZcyhq5pup7L5boSyZCugzKGi5ZEaV9p257vwOwg3inGc+HS"
    "BUmSeZ4lCUySK5denwLD7ePZEwEdguG858+dK+QLPYleWJvAorbttLWBZQcrd/ur1+dXlGqp"
    "VKzOzgpeobknHfFysBkU8rmNjU2GZWFHCYdCbQ3qNRdusALLswsIu3st1Y22IwRmbm6maZqC"
    "zADQIQDxaCTMsmw8FgeK59gWUNaem9oHd5hAwzC2trYEL7+VSsGe4QsEpWJmK1tAEXR8apqm"
    "Tqz2bRpaajNlW7ZcqYIyRwjSLwhe7y42d3e3Z8xTlUt/vbf45sVzHq+QT2c2NwuhiP/08ND3"
    "f70Fwhe81Qfv/fqQy0GOLy4spDY2K0a1/9TI6ZH2ZwxNnkEwcnrwNHI7hRAoAkqmUEUAuHMD"
    "yKAP2bFDAs+cnjwnSeL4+MTS0hLwTDQWL+XTjVqjvbw4l85JYIfOnTtjW+a+49lHvzNu6Q4l"
    "CAr4tSzma3UNLCuG4gR+Mg+kWpDaDnQLAgMsMUUzkDXGHt8E2aRpLTrBac8bF8/DEY4nf/Wu"
    "S8G2aRTE8kcfvt9sIEvFQy9nkyR++Y1LBzXO53PAM6pmyLSOXI0gpg1ZDWusOWuIvOvJLWhE"
    "tVqiCefp43kCdUzN2NpcAd+nG2Y2m4t0JQKRboLAIY9LotyZZwB3WNpuiRUno/EwqOrsVibZ"
    "n3RtIUGYWt3Asb3u5sUCRBpFc/EYbzkOUBn4pr2iEAazXW8BvY8akBZoLl8wLUQ3Eb/P1Qap"
    "dOZI0+w46dTGo+UVr1eoq1qyr7etQbXi8gzIj6N06JhmOp0BJQNpCkvW3SgsMxwMMCzT0x0v"
    "iaVAIIi2hm3v28M+vunRo0cCP/Htdze7Yn5TqwLL2KiDOrYsKZevXg0HT0bUQ74Xs6liSaq5"
    "Ge3Od8AfmJwcbUfLaY27qigPFh5NTY4Lgq9aFp+u5d//8MOeeOiIl2sqpbIoaqYzeWY60RNv"
    "a9DgmRlw6UAdHXsDnhk5PSlL0ujY6OPlx8AQ4UhEKmW1eg0GnNtK3/zhNooRLs/Y1r49oF9+"
    "8a9K3d3fmzWQna8TwY5/0GkvH9B5IxscSBaYbzgyOjp69uz0Tt8E+4qwm/FVVQVSincdu/gF"
    "cIBMAJV8UINcNgMbGwAyfbazB1bKpb22xnILfBYsx8blWkjm8sWpHclEkhTcneubgFWXl5fd"
    "9dKouMIJH3/88Tf/8cfhU4OwXWi6RtH0woMHhmV3HM2xIhCKeHmW5VgMA4IhTMMg8fZ7gR1l"
    "W7/DrZQVBcdwSSqzvB8mAIylaZpd3d35bAZ2HxJDLQRlKJLzePa6RLCfxXyhrKimXld1yzWs"
    "KG6Z+uCpEZflABG37GxvZfIEmYerRKMMRtJez/46AiBOZ/Luow+aBnUEi9V998TvBYUTj4Wz"
    "mYzr7BAb+jzoUTMBZ4I73ZnpoEAvX3yt+ZkmRdCqr1+8dLKg7xsUwx3yqyKLM0urr02OgXp5"
    "vLDkCQfr5Yrg91Zr9UJeJBjCVk3HLbBZF998K+Bt17uQi4VsykZwyiPgqtmX7Hmy/NSwke7e"
    "XrYh0kpF5tHDOdgMPVzE52cc20Qwrq9v//UxP5sbGR2vVMpDg4Orq2sAdzAYksQc8AzSoMSF"
    "hWWYtsmJ4YNuZ1d9pnmoXq/D19XV1ZGRESXzLzTTlyoNFvIZnPHqao2iaJ/ft762Nn5mKtnb"
    "fbLQt9Vn9uUZyBDe+wJ7jKPWNdj3Dvq5AIImn+M5Ptnf37EvmoT9rp2BbVf1Ok2e2Y4DeWZv"
    "p0C4kFPd3d2wFGRLMLFQDBZPNALkBb4ABCk08Pt8HqHzE86XjG2eqVQUCkfKqsXRpG6hBE5R"
    "DAOWAlREvab6fF6a5Q5/4mpb1sPFeVlWON4L2mx0pL0IEwlHqkDbojg8Op5MJg8f2OrKYiYn"
    "Aj94PF5FUcCagtLyCxxN4wBVanMTByeIOB5BOJBn9j9KEF6vFxg/3P9PwFP3ZhbOv352p3r3"
    "+f3IS8fd2z/BwtcNjaepgqRMTp6JhPfHrlgq+TzcVrY4lEzAblCrlAuizDEsBsZRMzKZ3Kmx"
    "MY47jKZgJbE8mHGvYTmwLe9tXFNIhnHrIiCjD++qGcPDo2BuE4lEKpWi3Pcb/GW3PlNvXiud"
    "zqEEPcIeaO8P85/bjE9S1KuoSgaCYcR1DJgkigm3WtCu303L1g13OXd3uwJmTAgAzximCtlO"
    "E4hl1ppmEEj9ydLck06XAwVBNh6Or1TElUftv4LolkQpFAqur67Av8O78glcWXRlPiS+27OK"
    "VMsuvYBYB56hGE8i6XoLsJySrPQljoM71qgbNT/6PKxaV6vVKrCtK2wch8AJutMT5I4xOOSa"
    "9Vxmi/cIFImZVjtj7tQzWk0plFW/l0MpJpHot1C87zi7C+Tg3INZWS5zHoHl+InTo20NxFL+"
    "v//0rSTLn372ecfeFh7cyZcU4INAMAhJA/lOEKTgoYFvgGfWVp9aDg5iKwoOSN//VdEDcW96"
    "qOYEPH38aH5xyQeOReBWnq7zHi8IwKtvnozIAatSLG54PXyYDxzSTNPUkiQD7kjjjb7+oWO/"
    "xEmQVLIvaQJYocjeXyGreJ4rSeWjdIWi2MBAPwiQeDyeY1kwrmCDYXcwGmwOdK9ICkWz+MH/"
    "t+JA3CHZtxXO1Xd+DQaHbjxlPTN9jEdrRwnOw4FjokgS2fMoY5tnIBhPYNTT4hn4uvhg5rgX"
    "Ap6pyCJ8yGfTe3+tgdVEsN6enls/fN+xK8g/RXaJJbXuMpKhIXXF7bnJMxjBhMKucKootWPz"
    "zM58/+aLfysp2qe/+30kcLwXrI8S2XRmYekheKju5Gh/YteD3J08Yxr646friZ5u4Bm/z58p"
    "lAN+LhjpTnTHjnIV4JmFufv5YoUkCbWm4hSu1dVr77zneVbgFYu5f//mK8tGb3z0acfe5mfv"
    "FCQwbkY0Gsvn85CRNM3wkPeIAzyzsrys6jZMc7K/r1lEOgbuO/P9H/7xDycO93YAY2yThnVA"
    "1dQNxwqGWq93g4TtImieIaRyuTt2pBJNoxSBnhoaIGlGrSrgUASP17Z0y2pRgfsuVDCQ2sod"
    "Nobn4GDJRJeqaqFwiCLALBM8x9WUstl428UrCGi1HmADLE1VDujhCPmOWDdv3ScJK5uTGIa8"
    "8ubln27dwXDENhCUxMDcX7xylaGOXaS8c/NmsVpDdI1keds0isXSpavXEl27mHcnzyAo5Reo"
    "Js+k05twoPn/Re7eyR/xirqm11V1+6tSFtPp9efXMgww9704effOTx278vK0VMqB3kuty03V"
    "V5EKOA5gog3fhHON56iSXDk2zzzPd9vs7Y1jODZ4ahi6Lkvy6NgwuFbEsRGMAF9O4C8iMpND"
    "Q6MsCw5PM2wwf6AIoLv2we3gGTGfnnuaPz8xDDxDEVQ6Wwr4+XjvgJxNa45WyGs0abMcE473"
    "jp7q33s5yOJ7P900LUyUipZDxiL+9GZGN/VPPvusVSd49tzjxoedeWbu/m3VJHRN7W3od4Zh"
    "eN5D4pZjmcAzD+fnG6VGEGzJY/OM3XgbEWmo+IoskYzrVA3DqNY0r4dleW84+FLWKRJtUfnm"
    "2tpaKh0QeI8/6vUcaFgYzjuYdPMAMqCruysQjv5fc1f23NZ53e++X+wLKQIgwUWUKFGUqUiW"
    "bClxPLHdOJ1M0pk+dPrQmT72pX9VHzrtjDt9SWI3rVOPGjutLTuiFtsiJa7YgQvcfe/5cLkL"
    "FCGFpHIGI4EA7ne/e+6Hc36/851zIHDks40qoKyMyGfTTt/IsoByB1JEuBiYcyyRujh3XlM1"
    "oFDF4rhrG4EHX2p0mR1FAYpea7SHKZoAJ5ETJdcReIbMZZJgdjiOtUw9QLknXjqXEyy0v8pz"
    "bK832NK8iDf180MwHO3VBMDEghBsrE1RpK5b2fyJJVLFk6kChnaZ44nDUZcw9HXd2PmLTEgC"
    "OHlBYDqtCvxtqpjMgrnraX3w55hYdImdIwwPRWBGrw4PDEXZ6tGLhra38VQqjsFj5bv7x84Z"
    "hUL7uT3tFiKo4BBsE22b2LbT7nSw7byBsNvrAQd+Ob3DFW6nPofhpSvzhmHG46eSxgTLxPMC"
    "liEADov8gVkCuNyfBLF9M05vT+BPFvjOjY4Mha+O3DKN/CqI51q//Y/f6aY1zHCvIDhBtZqN"
    "Xq8HN/q1KOu1yFA48i9++hOUeY5hJxulsVFQN+QFfmFhwfN8DkWRDuyuACj+88/vfSnp77Ih"
    "GQZHer/95L8aXS0Zi42VJ69emh3yHMfKb371a4wE2uJbmmp45M2bb85MHcBcFEWcSH7vQGFZ"
    "/iiLBTY6k04ftSUN76bT6fCV3m21tt3JMOud+eBnP8P6GS+GdTynGF5+/stfHHplGM5yUgJK"
    "f/zokeN6FIpu4opqCiwZYsFYaapfT5KEW37/6y8xJiFzBE6xBBHG5Fg8LkfvPli6b5huJpP0"
    "/LCnKLIsgkEYGT23e+zjhw+9kIKjeIaGt7L5kbgsRF4XezGO3OVN33x9v9XVJFEoTkx8/+ih"
    "5eiWywSOJoj8aGlysvQqJRZffv55WzdCx6Y4MfQRb7rx9u1DvOkMlE9SNKgscGxQCo6TkoT2"
    "K3bfnpw+32xrQIwphqnU6qnUHjceKxQ77TZy+zgB/INk2BhLkfuShwHaKz0NJafgSJscezDj"
    "7KgZARcA42sYBuDI8XL5nOcDDqs22qlcjucYVDdNkSyMRbyi/S2WyzP7eBPL0AF+knlRx8ra"
    "+gbNCjTisQiw4ygqF2q6BQ9YYesbm9GyAzZq2A5mO6IgtJBgosBvbm5Z6Chc1RDMxUkSyI1u"
    "wMPieW6rUjF3YIizY3BqtXpfq2yU8TlA76BuoOPr6+uiKH700Udg6N99512WIQmWC7wARqQJ"
    "rNnqkAQpJxIsZSwvrywuLrysy83lB+Ct/XamUqkapnmWd2JXtD3SMEB040WzMl8I/EDpUVxh"
    "sN59lIhrCYIA1gY+JwgcUADfsDDPozkGOIPtOAS63RQd4/3ghFM8IslkTqyM7fXKbq2l5fpg"
    "h5h+wt0AvUcpkvPz86D6Dz/8kOtLoTimm54s8UDVGIYu7UvOL5QmTmO6nueFO71PoorTEEVs"
    "yBc0ahpeGk20SSSLnBcEKPTfPwWI5/too43AgZyf1LlcP5DklGl0Kz33ace/OUYKPDdA77sI"
    "MsrIIQj82fKKZvRqTT0tUorufPCXH0rcqcPq+398WK1WQoLuzwEbzSWbra4cS0xNTcVjf2o6"
    "OC/KVxau/uev/u3bpxVwpXI6p3Ya4FqX15qg7qnxbK3ZlWKZa1dPADSH6HZ6ruPEKX8hR0aL"
    "aXAeB03TsNxisdhmTWF5bn7hCkUzu5U+rmNrmi6IAnESy+EoWVi8doMTceS0cM8P4Fxg3kKc"
    "pimCpAjPDRiW3LmwftLVzlwOZRsOlHiKUjqdy4s3Ly/uvQgQ8Oad7WAfcDqCok8kCTcKSIJb"
    "dmwgKt3IaQ1e77qu37t37/qNG/cebDEMdbFIrq7WAD6appeKxwrT093Ks4m5a8Wh00JfQarV"
    "oNuxWoobT3GZGK25+J2bpY8/XoNvYX40UakZf/93V/7wP3frPT0XS4Qc3thoSPHEj965Xa+p"
    "+fyrFKWMT5ze1SABpf/LP/+uVBrHYtLg9R6Px69fvy6J4luL45lUTJalCxfteqOVzuZZmkSx"
    "yYkizZ5ut47L88BCCjaqXXFkeVuPf/O38/s/c+PtO7vPzYtGV/GXv2tatq9pruf6AKwLxYTA"
    "U0+ftklwa5Yv8ISPAVUPkxmp3VANw4slBZbGWy3DcYPyZKqyoeAEmU2zOMNIwgnHi2A1g9LN"
    "o3AkrHfTNJeWlhYXF9Vus7L5LCELtaaWTEi6blqGgrHx+QvHF72diKw9W6s3W2+/ffPYT/KC"
    "UN1qb270RnPC0/UeE/jgGeNJQNtUp2uaGnjQQNVR9mssxo8W4lubPQ/MFkv6BLa5oUpxlmWI"
    "jfVeMslrPd0JyMvzeY45SUoBuHwkn6nWmoP1zvM8uLLp6eko2RVsfXlqJpFWUTpViNkCE+Bn"
    "FzjE8aA0XtxcX7ccP5uJaxqYRyvEiKmp8vM2XOmaNEuplnduRJq7sNtrK8S8ELFQmkylWJ4h"
    "WAY3bf/NURlzA+QVaKpQ6oe4n3V/+OPy53dXAz9QXewPv19FAWpAd2nBNYA3MbPT/KMnG4mY"
    "6DkuwfETpTGl1dVNFbSEEs2S+WxmWPu2rUHwRbDGO51OPp97/PBRQFAyz29aGyOjBZrCVlbX"
    "5y5e2LnMM4XVUizeVRRggzjJNFtK4NmmE3iOFWDl513e5HS6stkjaSqXOxC1FyVG4OmAJEI/"
    "5IDNM6TEU9h4Avu+jekO5oeY4aJ/59AWWCYruq6fgUUGoBI1PcBYiQ5pnBNYILUwTrfX5TnB"
    "MfpMFcccy1Z1HQ99MZZVFDORGAprbesdQVfP6/V6mUwa4HlPsxSgVq4jSPFUSrat0wq+Py89"
    "VdtP+XrdriDGDF0NHcen2ZnzF15w7MOlWqtlAs5RNeeNq/kdVIPPXhhU5w/gdPZw/zk4YGb2"
    "RTGimZkDqdWJVBwer3CZe/1nwLxMTk4Ca0hlstMz8Y2tWjohhyTru/ZIfgS1bDxR1BgG/ura"
    "mhxPweJNZzKGrosSIC5ciiXmLsUxbDtCO1Yo2raVTMgWWDyGAyyMEwSKsu6i2n3V6gtvjPYU"
    "m6AIhgKu7wk8GQQhoH+0d9Cf/+4VEKjhSBg9QRD0NAHxfgl2ikUPW2pN08Cjvnl94btvnxKh"
    "HtJ8t1ZnBOHWnXdS8eOzZIcX29A2N6qCavZqG7WWKkncWGlq/tL5VDIJmuzutG375n+/wGje"
    "0tVkMm07dr2j3vjB1eUHSzpNZwW21eqIsWSv01EN7d33fvrfn6zYfsCTuIHjSYruuN7q941/"
    "+Mfbv/73B5bheuBSAyIVY3mReuvOxL/+09fpjCRLpDySmh2XBJk9bd2DBTHtIJfLw6raqzsA"
    "/xkxjqjgZncJIKeBYRx7Fr314NTN+lakdzmRBRzZqNWT2Qyx3YcBhTqajZoUS0oiaqh2qE/J"
    "8pNWGGAhEbIcUyq8xG4w+E+KOvVoqAnmstfxfa/drG2vd8COqqqurq5evDD72Wd3Q99pqQ4Q"
    "xLFSMZeW//h4+a//6hevpdvVs+WVrx88lFBom8ZIvFlrgj0VZdV1Dd9x37x1AF8yDPl0pS1K"
    "XDqJGyag9WHZ5hko/fAZo/+ijhCwxjleeP+D99WuotveSA65HcMwShNTr0XpIOWZaaBANMVm"
    "huiy1WzqNEPheGi64fBKPzOB76vj2F0FJbrt2XewLeBaAdKAfb927dqDLz7dyo4ojTotyrLA"
    "9Xoaw7Kj58ZsXemoNoF5tu1evHwlPahNxN3PPvOQA6QJzK/VW9euXamsb+JsXGScR08qE2Pp"
    "tmpyLJiC0acryyOjxUa7KfCx0DGu3zrMj0xdw2k6cIYCVJOTqS2EI+lUnH6p9X42Albyk49/"
    "A5QV2NPhvhCCIExNTQGUXHjjBwAC8rkcPCdpFvQMuJJhGSyUxkTp2dpGcWI8Jg/2tNPnzwNc"
    "4QRZVVrnZy+wHCiZSaZHlHa9UJpyPO88w1imAVY4kbyOEdTY2Kimm/zBGKfrWJ1WXeqfAsxg"
    "o7Z1bCvDWlWzDAc4ka7RzopP9OMEHHvWNuQoAXoESqf6YecDVxL1EEKONAwA2MB1JtIZpVXv"
    "VKsUxZQnJ5+tfEfRPE4RhUKxVCwcZXwA+YE/dF2XoMjRsUmlswXOQ1EtR1P4RMozdZ9g0wlR"
    "U03AE45lwISAOIrygfoNU+9ZxuAkNxgZwwb0uaBQnhPe7+DhiP3okaqY0RCO6+yfbb+a5cja"
    "1EN5BjAsfkQKy6FhdwUGH9iZqFg4B2YTFczsfzViT81mcySXVnuajwFZAbyndTXUlgK1eiWp"
    "J0+WsdA7N/4iix+6Vr446Rpd0zBxzLVsJ5GId7taNptnBaFtGQRF+55Xq9YMK41jfqVSkyVB"
    "1RJxeS+LE5xNlMTRbneSO90iI5QVtYp6/rygnehHFhKpFBAuOKlhWgLPw0HrBw8BvUSD+57b"
    "6vSymZTjuFFhxfODw7CtVkuO5hYGum7pBjgSNpWMrx8xE1A6jA+LuNnqZNKojgXIoCDw2MA+"
    "V1HkfWJiguHEy1cu6bqxkyYXmKbT78qBz8ycP5ZljE/NhoG3vKzwogAGJ5lKUyTOcbzn+cCn"
    "KY4TBBFuTmkCNU+Cr1e5XI5sCCy0ra2Neq0xMb7Xt6HZaILLIQhqdu5yNnV8AKTVaCw9fiKw"
    "VKfZpnj+1lu3+KPTxEmKbla3vvry/uzcdPm5ZhG7UtnY/GJjCyPpVBLVGAGJ01X9reMqjQLP"
    "adbrX32zFBMZVfXef+/27lsD+i3dv3//5vWrn356V3cDKgyq9dZP3vvho6VvK9VNxw0uL7zx"
    "o9tDVDb59udf3JsoFxIxdn1diSfByRGbtaocTxQLo2sbFQ5zGj2jXGj+370lSRJrtdri9VtX"
    "Ls3Al0BRFNB7tVbXddQ6Gu7SRBkVJoDlWdNRCqrnDU6z2arWTMPgJLksoduTH0HNHxq1KvZc"
    "XwxV0+r17fxVKZGaS6SilYih3w04bNy2KlVelmf3laLBhDPp1Obm1lG5Tc1Wu9v/QQcAJRd3"
    "gtjR+FaUvvDNV7+X5djAvhBnLzCBer0OU4ih6tk/2/TTE5D/BxcqE+GUrjzdAAAAAElFTkSu"
    "QmCC"
)


"""Help image on default search page for search page."""
HelpSearch = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAH0AAABHCAIAAAClA9+5AAAAKnRFWHRDcmVhdGlvbiBUaW1l"
    "AFIgMjMgYXVnIDIwMTMgMTY6MTU6MzEgKzAyMDAqPnlpAAAAB3RJTUUH4wsDExgHO35NoAAA"
    "AAlwSFlzAAAOdAAADnQBaySz1gAAAARnQU1BAACxjwv8YQUAACLjSURBVHja7FrpcxzHdZ/7"
    "vnZmT1yLG5RA3aetOC5HUmynKs63fEiV/8FU5VNS/uCyS04pphRJFkkQPHAfu8Beszs79z2T"
    "NwBEgiDCMJRtyDJfobAzPW9ed//6ndONrt/6HHlBf3YirnoA32ny/JDj+CfbMQzJ0uTJ9jTN"
    "wjjhWO4iP45nSXi+pcB9OBzBI0FgLdvDUISiCNeLSBLnONY0LZIkCZJI4yTLcwLHXc/XNNV1"
    "7KIBQQSeI3HUtD3gYSnc9qIkjjmeRXIYRIqiMERMkqTRyCAJDEHwMEkIFGEYOgjDLEOg0fXC"
    "sqYEQZikaZ7nwE/TNI7mJzJJhsKTNEuSNM8yjCBIDAU+EI6iqCzxeUzfvMuTRCYKmeNijVrc"
    "61FRgi4vO5KYfXvcCYIQ5ZJlgTTe932W41Ekp2nKNHTdMIYjY252ptU6FkTe84KJRi3Ncp4T"
    "ypUaIJNnSX+gS6IIMMJdv3v0xR/WFFlaWZo7w11R5CCMAFOOYxAAl8BJksoKytWSkgBSJBGe"
    "LBrMlmEZWBuWZWnACEWBCcMJnmNxAmNoOs1RDK4BNgQF3EkCR1A8TWLgJzAUJwgOhpNm0A4o"
    "w4qeTIPGTh5Bv0AwHngEtzwPcnCaIkDp4BmsB/QO/CAPblHgQ9EUhTHkcYIGIYrjueejCJon"
    "CZZmfwTQTykMQpphYTq2G934r88YlpxbWdUEkuc5wL2wCS/s9QdpHJY0DeZ4Mv6MIKk0ibA8"
    "/ff/+BVLc//wi5+BSg0GozAITnFHX/j3p1CaIaC8cRwXRk888snmeBgGPlIsPXqeP0kymuUE"
    "QQR1BH06/3TQOwLoH77yCHdgRTESeVzQBcphWaMo+7+0CTQTJ/A4Tp7CA93DVKI4fgoPmAVY"
    "7qXdAQ4USf451+CPS9jpD7iUyZklVdZihDJMnxFKgljiRKU+OdvrDt0Qac5fqzVmGF5WFMU0"
    "xsORieQYQdKwwo7jgpwoDPv6WFPB+WsYTrIsT5M0eD2eo4aGYzmeZboQIcDllUoFD/hqpvBW"
    "DPCwLGMYlmmDHDyKIt0wT+WAJ5dlJU1gdCgM1DDdYb/PSyo8ggh21dA9D/3+xuee5yGn/v0E"
    "9EVVK/d9v9M6QAjG3twoK3Jf1yemmpwkGcNBlq+EYRHccQxBIZznhBdEaBh5QVwrq/CfpFkm"
    "QXlRBoFxmsPy9JMBgRF+DFGUx9DEdH21zGA4zQoS+MFTnsFgQFG0F2YMK+R55njQBY0H2UM5"
    "ogQ8w0LjMZwD+yUQmhN5Grds+6oxfB66vvoSxxXZDrq9cUetTPA8/yyv+RBEwvBZOF/QpeR5"
    "ThQGxkgnGIYtldRnfA1086pH/pdNx+39T//zRrlcLvyMftz+au0+RzMZBM48aTYam4ft11av"
    "7+5tm5YpCprA0yiGsqJ0uLUpy2KCMWQWBbHnBggkdPCI4YSpMnt336BTZ+WN92Ya5aue4HeU"
    "LNuZmJgMAh9tH2zXJpqB70FYo0gC0n2oFOCWF8Q49Fw/SuMIHPHIGJUrdchJIQMlKBp+0ywN"
    "QyiviChKaCiESDwI4yyLRQjIUAe8oMuo320NeseHraNC3yEzFUQJ/h4+ZmgKKdI48WGRPMFO"
    "Fj+Qp7BsccFzTwoVr3pWf0GEXfUA/krpBe5XQy9wvxp6gfvVUBFX0yRud3oCy0RZ1qhWocWz"
    "7QwnBI696uF9b6nAHSfI/Y1bN768z0hsvTqlUMnd+3spyzBIZIyMf/rnX76xunLV4/y+UZG/"
    "VxszrcMWTdNBEDDMWeoN15Cbo8Vn74u+6DzbM9IzvpIjeRiGDP29Tf/jyHVt4yx/z9IscIad"
    "ITE7UU3TaHNn96O/+/DT3/46IoWSQI8M483XXzvudMNicwGjGL4kCpNTkxck3rtzZ/fgEMXR"
    "t95+v165+OHhqH00HA0xNF5fu0+pNRqJP/zop5/+7tcVRTbcLEsijMBkReZ4WRH5er1+1fj8"
    "qQjqJsAdebi/6niRpBR1Eyi3JJfgQippCEljWcIy7FGn59gWhuJImgqydqlEWVFUByBMOeby"
    "bzi9Xo/n6Wq9jlI0llNgYVCCeWFKU5SsKaNiJyHUyhzy10GFnylXp3Z2dmRZHg6HmnYG6/nr"
    "C/TwUZqlOIY/SzdPkXaesiwzTbNUUtIsxzHssi7yNMue0inwYxieffNWksQYTmAoGscRXIDM"
    "ywSe9XVeyCnPU5iL3RgUBclPgnC6P3Xp8B7zM0CBU2kuVQy96wbx8uIstBwd7vz29lqjMfmT"
    "D39CPO7h+53255/9XlTKtmXVJib+5gfvPgv0m2s3CUka6e7kVFXv96abze3NzR99/HNVeOTN"
    "kyTZ27q3ubm9tLjQ7XdFST5s9V5Zmjo2gymNv/NgU2AUP7JXXn5p8879nKQkPu/2E0UkxJJm"
    "j4049KebC71e1/E8ikAFUTjYazUX5hfm5rY3HvgpwdB4VZXbnS5NMmEcEhjJ8WSpVN7d2aEY"
    "IXQtSRGGhu24wQfvvXFva3es6/PzM44X4zkS5MhPf/zWv/7bb6aaDWMwSNJo/tprqTc86poU"
    "GrogHItfef3tu2u3Tdv74IN3b319O83i+eVXVZFcX99gWWxm7qXAtk62kL/R9/19SylVwuBg"
    "cnr6dD1brdbExASs6pNLt7+3K0gKLIbj+oLAQ+gFVcrSBIInz/OGMS720pM4ydBarVJoRBKP"
    "LYdh6Lw4GRBmCInlCcXxiiQWO9TndhYB93vr61PNWfBohu3XKgWalhdNNGpZElheLPJclvh9"
    "3ak3qkkc25ZJs1xJkUe6TlC03u9DgACJ5bJqjE1VLRVnGsCZkuTJ4QYM7IAg8CiKsZM5wn/o"
    "kaSoPE3zExXGcbwwEazYwc/yHNohs4BGeBH0O8+BgcBxLIeQlKbQbtu2KEl5lqZJ4oexIksg"
    "ED05AxCfbGGe7tYnSWoauliqjPVjvX/8SN9VDalUIPoRDy0O0hgcP9vgv0B6t7N2515ZK1mu"
    "D3jTohJ5DnQliaxpWBlCAJ5rt27zspbkKUGz7vD4xx//Is+8sTEWeKbb7zB4SghqRbvku79r"
    "m198/oWqyp1Of3l5MY0TvqT2+70s8k0/j2Quj4MHDw5lhbt5cz3wbIxgpyZrMFiwoTiK4zR9"
    "/723D9vto1b7nR98wNJnwQY7m1cxHYZ5NKmz3epzfub8/vU5erwR4D9RR1VVz55S9OmpGYqi"
    "vmF51AtkhuVqkSw81LHnObfUmJ4RlFKapGGCv/Pm8u1b24osjm3v1dffoqkzge//8EfnX4F8"
    "BlKgZrMJ1wtLT5WOYvVaVR+N5hYWTMvAMdRshTNT5Z7hpHkeehbD8ouz1Qf3tqoaP8TYalWk"
    "8KyjuwsL81EYWo5z3NXBDyuK8If//hLw5AWm3TpWyxWSQHCKV+h846BXEqFIxHiO4xjSMi1a"
    "EO3hsRdTaJbOzICVh+3jIQyDIvLDoz7YdOQ7mqaO7USW2CRD4JahKS9KRZYJopjjeNuxk9Dh"
    "RY0miZHRx3Eyyykci3IE07RKv3tMMByWhTSZw5I9J+5ZscefUyw7PcnjOFWbrIo8O33S/BzS"
    "LlC13gBnVZuclAUuR5pHR23TdGGq9UopAPNJs7KqgPKyggOVBUE4nMCDH6uWSagP8ixXSirP"
    "skmaRZGPoIXfoymSZjieF+LQSzOcFenXX6vSBN4+PhZ4DpaiWVKSFBFYCkw8CONKtQqehOel"
    "OM3hlWZzmiJJUVp27DHL55IodAd6RjOSLMho4V0FRY2jcGpykiRRfTiGYaxOvNLXRwRBqjI/"
    "GFksRSytrJiWzbFsnvrgcJ4Td/B4L6+uPrxdnBe+PdwP6ah1eNjuqGUtC11BbaxcW44897Mb"
    "NyhWKFfKjYpqmeP1u5sMlXJSI/CdcqKgCNYZ9NfX1yGCjvQB4MUwpCRr+5t3UUZMfDfJc9Bs"
    "pVTq9PXVpebOTlurKaPBCLyT5YUSjXIK3JoCTw2dUCYT2yeXVqatkUUw5NJs8+u1dZ4iO73B"
    "/PKKDfiNjZfffmd0fADgjYfD7mi8NDfrmP72zjZJi3NzM2tf39Ld8M3rS5/87hPPS+TKxFRF"
    "Gg97A8Nu1OslmXpO3P+kBGHqo49Xd7e2Ft95t3N0YOmdcZD//O8/0m1P5lma43Y2tj740Q8P"
    "trfUeoOjySAMwZbnF2YheNAMrSgyy/GQ2w314d9++KHjBARVhMIgiGpVbePBZrXRQAkOyaLV"
    "669lSfxgY2N5ft4LA0NzFpoTlhumcXECUSurvm0hkIPixFuvrqIUu5onBMWEvsuwdOBYKMF4"
    "jlWbnFZLsg+GGAavvP5WHEaeby9eW5nNc98LPvr4ZyN9yMtyGoUzs7Pg0FAkdKxzddN3h8BO"
    "u0dHjKS65nhqeqbX6YSO0x9bgNF2+7AyOZPEwebmBpIgu5vbDMdOTlTb3W4Wa73+mKVzUdUG"
    "/cFopAuysrtzADkIz7HD0ahSawwGuihDIjsmKcI1zU6nC55lZeXa9tbm9Mx0SZbW7z1QtbLv"
    "uG4QjccGDaHFNjm56pkjVuSiIAdV9cJMEqX9vT0oqgVRabf2sJzgRBFyp1b7uKJCFSRv7+xC"
    "5IDVC0MfAj3IGw5HxRnTDNHkb+L8VeN8kUzTGo3HeRJ0jg63tvYJRmhO13Y3t8DMY4yAbLJS"
    "qydhTLPoxNQU5LgQS/MoanX7aRZCSdHa3fWD4uSsyAu941aeI7AMFEGao+FAH+3stRSFH/YH"
    "BMO293b0kXH//iaW56397a3dI4Ygd7YP0yKpzLEif8wMJ+cplGXIOMpNo4/iTF5UNoeLy0ug"
    "wjmSyaKM05TAs4CvBSmv48KFpqqWG1SrZZHnIePa393zfU9WSqAiCHqm6N85fa/VaxTDOY5N"
    "EFhzdp4isE63N7swJwoy5Kl+kJQ1mSSZKLD4klaplMBHLywueb436HUhm6rPLKShC5k46Nfy"
    "tZWcYOo1dTAwBElQVeCH62GprCFJuPTy9cC1+kOzWq24YTKriHC9vKziaC6ipMzSO3tb773z"
    "Bk8jD3ai60sLezvFwamFhdlut6+VVBKUIE9omoWkh2JYJI3eVbX9/X1GECAOQ/IG2T/LspAL"
    "OY7LiyJUD7AeR60da+x/F3Hf29rMCFoFN80KX3315bDfm59bhCxtbbT20srK7TvbEpN5cXEE"
    "nMLpsso5IVZRyJ5uQu1ZklilpED1BDVOhg5pHM/xwkRcN4KcB9wPy9ASQxgjPc1QcmxarkNQ"
    "IgQGJwzBLGplxbNHMcIH5uGml06Uhf2DXYiiSejt7LcELO3pxvptf2Z6+ubXN4em/8t/+cdP"
    "fvMrSVNtvc8olem6pkpCYFmg7GEUGrpu+XFzemJ3ez+OXak6na2tlTT+NKv/Vt9nnp3+n99n"
    "SudbkOL7MHLhE0px/vuJFuRRfXS58FOGJzkvtJwc0UUhK8X+907DMKRp+tJewEWhjzND4Qvu"
    "Huzg4vcZmqzwUsX3nPZhm+EIkpEZCm+3WzQrvvrqKvb4GWEDNGRsQKRyzCFK0MZw6IWpJnFu"
    "GOh9fXqmHsc5RuDN5rwsPjr+51ljlKLAUXIC29rfn52bsx3v2kv/w86VNcdtZWegsW8NdAPd"
    "7JWrSFmULMkjjy2PJx5P1dRMMn5IVR6Sh/zAvExSladUpVL2OOVtLFuLZdLauDXJ3rHvew6a"
    "lExRtkpjOSWVPeeBBTaAi3sPzvJ9F+fetZNtA8kGiuExABsiACcsSxmGAb0H0kugcYJQnaY8"
    "GKlZHDu+W61UA9+v1ur3bt9KiFIeE3M1NohTmhM9dVRfWE0D13YcWVEsXQMSL4p8CHYYJjxH"
    "iJU5XZugGO47Trkip6EH6BOcII2jVrsF3ROrlRzwfxgvdZRv7u5xkkQgqSiJmmYCYSZ4KQ6D"
    "yVTvdJpCWez3djMEi+MIL6qUcUGq7j+4a8YpliHNppzEQNFoRSoHUZJ47tFIj1/IaIRYFhIF"
    "AVcWKlKV5/koTgSxUlfEJ18pS+E4xRu6BobpeQGK5KJY5jgWPAxunGpGAC9E1QzrsdLRElYq"
    "0mAckTgOvlUC3oaXkifKejme8xw/y1PTMHhBpAgMAiXcCC1DwrMsZzwaO54H904n4zjJi8UI"
    "hW0CA4/H44lr2/DkiiznaTIajdI0db0AKU5jcAoAIvTW88Ik8sF2LNOGA0CKtmXD9cB1CxvH"
    "cGjLcx3IkEkYkSyEaBrM1XM9wKbQYcCUljp2XI+iCRXShaYX5hxH0DiOleIohhcG3QvDmMBQ"
    "dTK2ba8/nIRBCKMAlnc0zGN7X31lNj+DKI8+aBwi6ZMfN45kOtUcP7Vt01mYjx3jAAAcSfSx"
    "0gSwKscSDF9rCDv3x7b+CUO/W384CQPM03ERScC+PBg0FGEwnFz5xcUnGwewkWJEpSx4nvfZ"
    "Rx9aHrJ+dmF3+67jJjSJQEjuzC9SGLK101+Yb+49uLN/eOgYE4oWK0rFHA2rnbXUM7+5OymX"
    "aXBWG3DMeATDdQ09RwulsByhT81R06GRUAtMlsiibE8dq0VkyOM7Y920AXCG584u3rx+/fKr"
    "F97/80ckkkNkX15dDQxb07SFpQ5fLk/G0+Fh/+obV27dvO35QX2uThH49u5EEnlNVcF5GJqt"
    "N5TI1b66108DD/hw4vvApo8md4/ju2VbtVrtaBblWE0njk/J5sbm4tJCnqPApyHsxklSzKpA"
    "MMrzpJjAw4rlNbPVB/lsccFRa8A2wfqKHxG0WJRVKqZHTrV8NB+5tLKiA+JuNLfu34XbWV6k"
    "SqmfYZHvSWIZ0I6pjimuzJCo6SYUDqE/06ykIrLQLEXTruMAdUpifzy1GnUZegYuwjDFXAF4"
    "usSRhyOtmBTASKaoJ4SIiOVZoukadJakqIoEmdYC0p+jJAbgvISEaQnMdr7bGk91gaV00wKf"
    "UKqS54fgvmK5PBt+iWUZz/PBxm0vZpli1ixOUoYih6MheFG1Ivm+j+WBqk6+je9/lUCUOLnK"
    "jXg4A/d0+c4s9KQkcfjl59cSjNJUXalXe7t7N25snl1ftaejjGC+ur1Rk+VWU772wYdliR0O"
    "zFpLkSVhZ7d/Yf3MFAw1zViWD4IQ1JWl2J3Nb2r1ylQ1xbIY+pZQbYp0NjGCqgRYpQcokKTI"
    "JAz4iuKZI8h8gR8sL89HUZQXs8Z5BLgpC/p9XZlTEDDaMN/Z0lZWVwxN3+/tMJyoTcZlSYKQ"
    "aWp6d6Hd2+2VCDLw4tW17ngwDtPiMwzPIFMNsGPeaNWbVfqxOPPyCJB+XhAgqPq2YZh+o7vY"
    "arUODweMKIOjLF0BrkQO+oNzF1YhtrS7HsfSo9F4YXneC8Ll1bP9/V2MIGuyBKD63sbtTrcD"
    "BGdpcR54EIoppmU32ws5Cu7CyBUJVJZkkBcCkqVLmcLzzESzdHVC83JNFjEU2d/fqzc6vKjg"
    "SAZxHFxQFrn+waC7slSvKeDZnYYy1Jz2nIIuzPf2tjvzC4pc0TXdC5JLl18FOO9HCF8W2p2S"
    "adrwDlU7nXnCy6d3CAgAX0xDbTTbQRg25Epv/6BWV1KEqFTKLEX5vqsodW3a56UaSeE0TZ0R"
    "xDiJ1KlWyhOhUhPLvOfaELIuXr4UAHxLEtt2KZosPh+mqe+HBCRENF9cWY2j8OBwsLTQgVzS"
    "arfzLIaMCFTXND2I9gf9ycraOYGhh9MpTVIYSdVqCoRQXhSrSk2fTnCSsS2zDtyfhLCVNVpd"
    "13HLUgUvoartQxgWBMEfqwzHlzkKJ0jX9QkcBcb3MupdnY49L7L8lCRocPUP3t8YTb1fvLZu"
    "OdN7X13vrJ67c/NLrlq1VQPZ2GY50IXUn1hri63t7b4scxTDAi+3XRtiKxBHL0o4lnJ9rywq"
    "C1Fw0NvXppxhOpFnNOeXMSTz/Kg/HBvjMcaQtm6MNXf9lRWCxvt3Bhwr9HYfABTJ0gxyAE7R"
    "o8EojX3wxU8+vc4KnD7uzy8sOH483NsTZQn0u721Jd26hVOUIFS2792BnOeBmQThhjbZH5vt"
    "Zm1puUPNiNNLp/dmq1uWRIi8g/4hQVFrvPBmVRkPB0uLS6+snZmtfL7UXVzQppMSTpQBdPr+"
    "/CJWkfh2uwuY1DKtleXlGUkBdGgRDAtsJfR9mqGyNJUbXSyPdnsHjeZrM6iNarpVr9eSM0uQ"
    "G6qXL6dhLNeV6URdO7NKM1yWRKJ4SDFMt9PWpqrj+3P1GlI45RbYMrq8AOi2LJbN82sTzZzv"
    "dt66+qahTktkse5Zqsj7vb2KrASepyi/0k0HzSGVuLapvox6B4V6YcQxFM+Ljudok0kaRJYH"
    "CS/ESqhQlkLf2dzcyBMESBPNMp1O42DYTyJ5MNAAnsQ5bhjT/YEmCxzoOi+RSAKIGhVYMkgz"
    "nuYGg731i78k0WR3Z4tgBUubEASOoKAotFat7uzsQPKIovDw0G42G46pRQlKZtlwMAAslCax"
    "ZdkoUpCFe/ceQGqpNVq+DyjG01UdshLgO3jxEYpVeHocDSG993vAuarjiXqwf3Dm7Ko3PTwa"
    "5kun91Kp+CIclZCDwyFOAXTOKI4P4WXkyJmVhb98vtlulIGSAGhjMZ6mMACFbUWaqhpN4yhW"
    "EgVx1NuRBTZBcWBTGJKMDC0N05ClhHoTECPPsL3d+8BleAqfTHeBAAaWObFtWRRv3PwKQ2I3"
    "QCEn5Ek8He5jjGgbmm9CwHc902ovzQNVl2XZdty5ZoOiaGM6dWmIP4OVlSVQrm87QDtFocDH"
    "u1v3a51lGkf29/bA69rzi9v37wnF+r3ZguMj/D4cDoF8jsfj+qwuFeTk8Sl5yqnvk2e8BfLe"
    "3u5OpVoFsI2hqOe5QBEFgctRPAh9gReKUgAkBdycpDnL0CReiqKMIEtAe9M0JwFwI3kQxRwn"
    "QGKE7JrnxaYGKBAGwC15kgFYYiDcA3Uslu1naYTiVBJ6aY5CHmZpAg4wnMwCO8aZLPAgpiNp"
    "kiIoR1OQopEsKSA5zeIYOtatdr1qOT70ArirUqsxFKXrOoZjJEECIZhqOoQa6KJh2oY6qrcW"
    "siwJXT2O/G/xu2PnfBkNfBe4Mk0RYFCObYqVKrCANMtPrYwGeBuEAUMzfgBPpaErhmFIogi/"
    "Axwm8OOLwQEJkgbqjBQTQ7lhFN/VkjjlOcZ0PDCKKMkFnjs5P1OAPazECUKWzvYtwApMicz4"
    "VDljgTGBtoCaJQUrT8s8D6r0oxwIFPyFYI0Xn4wzYD1IHtMspAnpqFngBHGGuJbJlSUgMkK5"
    "eAF4Cd5ZiOEEVqpABIEeeq4riBJ01w+KQmhmrjCUOIlhRDDSKs3AMfSEphnoM4Aigec5XgAj"
    "qFZlTZtChxmWKepW8hzeH4R7P4iBUFWrFQCdM13xFpoY2ol54DThPE8Ap35wf4ujMFqqQ9C6"
    "ce1aGHpemAJny0tEp9O++ubrxcWR/+WN22JZkDh8+0A1xn2mMrd+pn3r67sii4cJWkwVSEJv"
    "b/ed371XqRQMy7Ksg617OM9rmlevyw/ubK6eWwc+/fY7f0dg3875wahcx/r0o09BEUmSX75y"
    "8c6tWwDuas2uRGcHI/fcK4tfXLtFkniGRCVMuHR+/uOPb9E0cGA8SpAyT1y4fOk///TvWSnO"
    "SxBtsxKB1+tNkcQW1849uHMX0qAXR3gaqpaHoniZx9cvXd27e2N/6PzyjQufffy5XANET5Qy"
    "b6K7b169Ou4ftFpNdTS8v7unNBbPzFduf72dpeHaufP7B4Pza4s3bt0kWamliP3+gGQZy4kv"
    "nu1+9fX9II7lqlRTFGAAjpeeP9vdHWjv/f3vi1xyZGEP40xRt+TYzzRPsHH7dkWpW2Dj1ao2"
    "6kOIRJEEpxjftWmG9lx/rt2pVaWTt0Brtq76KaC1YrMMANAkxc13T7cPyp5Op0+pSwUwnqEl"
    "HPuBn8mKiQoMO+lhTyk1fPYqxGd/3GPr+UCA9osiRJtnag4SOHDn4ssDRbHF7ATSPzTqczgE"
    "NV03RKHynQUdEDQYkuY5arZ7SrHpwA8YCUTr5/ky+WQZ1lM0+5xK/87HPZLj9asAnkqP12z+"
    "uIbwjLfkSLH7xvMP+KWVx7574Djene++6C79LOSx+ncAUnuH41a7Begl9F03yitl3lAnQY7N"
    "yRVDm2QlSq6I4ByP0sLf5DllZu8k9cXH748CnIqM9dfe2NjcIDKHoKqOb+Up0Wo3NH0KqQyn"
    "y//6z//0ojv8E5FC73GSvf7Wbx6tP1p+GHOA/p7aGg5gydObe/KWv8lJAdJ0dHC8vqkslmu1"
    "YsbnP/70b3/8x3+hiQI1PAklQ8+6fvub0I9wEsAccfXN0ysOnoI+X5Tc/PL6g53dLI/f+e3v"
    "G0rl+Rt8Hjm9vgnY2lEtAy/KoPPj6on8ib29ZhsIcjxPUSjHiU/u/PUdt7xoqc/VZ/uc5QLL"
    "vPC+zXZ2K+Rh/cz21iNWfXwFggCflCoSHD0Fh54SVZ1WqlW0WOORnizgB4BYbDE4+wv/xUlK"
    "4PjD2piiKO7Rqo+ja47YebGTIlLccFSR8hOQKHQeq5+pzeTR6cBBemPwhcF//8+fF9v1K2+/"
    "K3HP9HU0S+NbX36RYLg+nAq12lKjdmdrS1EqmmrQDI8V+3gCKU2r1fJoOOUEcXfzxjhOibg0"
    "V6NTpJRSlSvnVhzL7B2O//DHf7j2yQe2k7W7Qnvx1VfOzL9opf0I8ijOPFYv9ui06yKmhVDk"
    "/1ddWBSF37dlluM4PP9jFtS/VHK6XqxWf8zefQ+pRYhrJbbjkDjeXlikiGcKNbPdUDNRLEdh"
    "lBXLsmLTtOeUau9whCKZXBSZEMWWWSyVQXTJUi9Oq6KgqdpsJg/p7ffb7VaeQRxCHNtJsmy+"
    "2/4pvYbTefWUGBoy0hCqZEx0tzUnp1n+jO2iJUwdHui6zgiyp+5bQZ4mvsAwu7tbpunzwh2C"
    "kWN3Is910yDECCLP0QsX1r75epMv8xTL6+pEHY1JjlleWppMRhW5trPXe/X8+otW148mumEN"
    "xypJksf7EwD+e3K9ZBiF1F+5gd4PuOVnJRgGbo7Ypl7YO2h8cWnxRXfpZyGWqQV+sV9qwY+S"
    "OBpP1SQpFv4is70zHl0Hx0lRhoccnfUfnjq5e+fRBZ7rRHECADUIQgDxpmkdncpPXAYtpEmx"
    "n/nJrhz9fvKhpmF+T6eNhxEvH4/cOD3+3XEQz/OKZov1yse/FruvusUIfb8oQT06MGYHINOJ"
    "G8bf3h4FfpRkML4wilzHfdi/rFgDfaQH309m32KOOvxIVz9YCnvXp9O7D3Z8z3GLAv2SIst4"
    "6g41mxd4vIRGcWY54euvnf3k488gxcG43vr1r+9uXEdQAl4YgjMYElJMZaFTv/nFFxlBx0n+"
    "h3ev/Nf7N7ptqd2Yu71517bCZrfZbij9gwN1MklJ7r3f/ep/P/wLeN36qxdHvXt3tnp4CX/7"
    "3d9ub9wM4gwwfIaTgakrDcWxbEGq1yTmk08/S9PEzDE6NpbPvV4T1/A9btBDUAqxPaQl2dLC"
    "mMnMm1/v1JVy6Cdr/1fNtbQ0DAThpNlsa0tW06SPtCjUgBfxb3jp3/TuUSj2UKEHr+YmFKRK"
    "SxOxeTaP5uEkQVooaLVI9bst7A7L8O3szu7OJ0tX1zd1gbi2T7MxVyxSTMXzHQbhZutYqp7R"
    "bOd1Rnk+HK4oSaKF5sjVNW1ulzFr27rQaJ525Mnz+G48BT5Va9x0alycy4eC+HA/THA5odhu"
    "95L95gtMGC4911E1NY3v7RP5i9VhmoSQTzpEWdH4B9GSvOA8iaMYXEvHYUwhpgBsRbhUPiit"
    "97dMo4BwJRN2ijLd/c1y6XXjYF7XjUxYOFgsVv8yMQ7SstPt87u3wLZWw1kU1Brpd9pU7B7l"
    "dycRlUnO70LqTUxenvq3PVEU6dGjAhmNZdk8f7S73Z/BtJx6vba7nb+MNDS5C0VRILUkhEPh"
    "ctkf9lqtdhg4+5rT3HAIt5Uw9P8FhJfBYABMz1+VEcQQaMCWAknUvubE8zwcrfbtmd/FTFXB"
    "z8D0vPkOwAzQi9cnDBoAAAAASUVORK5CYII="
)


"""Icon for the Data page in a database tab."""
PageData = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGhQHKMo33S4A"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAH4ElEQVR42pVXW29dRxX+"
    "1uy9z82XxEmI09QJqotJgQJqEG0aKoqqSIEoKgiqln+A4AkFHhBqeUAVqgBFopV4Kg88VELC"
    "SAXJkYAgtRQKJJUS3IYQt7Spg3Nx7Bof+xyfc/aeGb41+1wdt9BRJmfPeM2ab93XCPrG9MUl"
    "/+eLi5hfqCKt1xCLQxZF8Bgcnhs+7EpYS/tXf6SfWHofhWIBU7cN44G7x3H8wLjcQvKd6Qv+"
    "lWoFD3ysgIP7tqPEvxQjj5QkynMzCNc+LF7CRwAkfQzbQDtjrWUw9+YN/PXCCu7atw0/PD4p"
    "XQDfev4tP7cMHDs0juFSA7WaQUNiSOxQTB1Zy+DtvFQ8NWNSOJPxIr0pCnvYTBvAC2wSYZh/"
    "rlqDmZeWcXifxfe/sF/kD3PL/vHf3sQ9B/ZjTyXDWqWMKHJIbIYmEkTi+jkF9o56zowg9hki"
    "p7JHyCQhLoPE2VsAqF0sdVl0MdKmxWLdYvbSAk4en4B5kTYv7tgDWymgNlSCGAMh04yHXKSq"
    "NrBknjPK0IpMuND4hHxjghHuxcFQEpRDjUmLe+A5EGgUzGP4t3ps0CqXMELNDg2P4wXebf55"
    "02G0QkkTlYyMrUeLIDwBqErFKQCbS+hKwRfei85LStoy4szwcvDiethTulKWUQhqrlDA8LBg"
    "ftEiXm3FGHNUpS8EphLE9miSScG67tq4rb8302217gxLOL7t0UJhNlIw0rwElRIDmpRIKXyq"
    "kgmaId7ytW279ebvzXRbrbuR452ioCaNIkDGZeydOohwQSCpnrOdAKO2pLsWOljRWHxw2GDv"
    "kMHtFWqizbtFY1+pOVytAdc3KLWTAT6dEfEmF7CrXzCCeHds6bUaRpZMnEPfoc5BJhHe9Mmd"
    "gocmYgKgDc1ACumyZ8Ti7TXg9ILH+SXy84MA1AQhUzk1hQQtxfofTYYsa2c2bwZ4x5T8Sx/W"
    "y6Ur8buNhEc/tA3YT5A/yyKcWRxMX140V9g8lIMpHGIXpKdCsjyl9mcvNd99e4EHbxfI/7i8"
    "fxTof49MCS6vAgvrgwlJ/xm9UwUOPsBFRm/QiaAWaaddHy6d2maCZO937KLz7+G8vNKTiIEJ"
    "q6Hp0b6PACLqv8XdNI3aBSYPk05VeXHe497bBCOF9wfg0jvAqzRBansANOIck5RFmRqgdDbV"
    "NKcaAAk5Mx9mi+haaf59/rrDz2cdVpv//+XXax7PnnNYXM/59GaEui1C7DpN3aKTJuoDjhh8"
    "cEL1BekztppH1zNzDrMEcmwqwmE647bSrTGgvnNt3eNvVz1Ov+lwpbqF05AoSat0Zhd8gAWf"
    "AKztOqG1eaaSkLlpI0bAifsNKkPAk6cdnl5yeK5MAGW06dr2Eg05YLmmZdeF9eNHDF56nSa8"
    "3CtOnnkkY5Q5GUKUrvB8gwB4UuNf1e00Pjm7hZrzd68LnjwCfPchg1+96rDe4EXrwl9mvNAU"
    "sGQT6HDJY5Rz73bBVz5usDsWnFugs9k+D6ZpIxawVsGiZhKMNTNGgbpexwQkyBNE7oTCeXZe"
    "8NO/AF+7T3DkWIRFSvkv2rhFrWn207FvyIfQu5MZcje1tVD1+N5pj+urGGiRYq0NJrg+Wqw9"
    "Pg9DDQuGHpFmzN0uJOtcfCP5enpWpWFCutvjc5MGB3fkeeF+RF3maoKFVY9TF4FTlwjynR6f"
    "HpFBLa5ghFm34NfI2Woq1oSQA0hbtGXkQsRqRjTcf+KowdiY4MQvBE/dTPHsGYOdRfYB7Ia6"
    "dLwoY8ldpGmqjSicO/nVCDPnHX4/11cLfA2SDkMSap2lW00fnFA9ynGVMn2qTwQbcE8Z/+Y1"
    "i598McGPH/X0gSjYfr3hORP8ezkNUk7sEvpAjDvGPX9d8IEx8jjzNnmmPQCEjTREgARTh2Lk"
    "fG7rzCqxUS1185CmzJcZUj96weLEZ6MtfMAEsJt94MoK8M1fZ7j6n8Eu2aIY2jnnJI80307F"
    "+hEAaCSEitNRrQvr584Cr7zl8NinPI7eFeGesdwHDn1g0AfmmXanzwme/7vDpeW8UQ3FraMB"
    "FVSBuDzn5k6o3Y1u+jxtuk4PqhpAb33hmscTpyye+SPzfEVyZw1OSKC6YpW7tmawWo/yc9Lj"
    "080Dos1MroFQeIkgltB2srVGITgt++Fgn1jDs28tdBrL1HmVGW5xLfhvly7veuMtz8V9CFzQ"
    "CAVmKKYmN70ZLRN/o4Uiodhog5sNFFistRvvX7/b92a6rdadqcpkOUCJbwnXZOIqbsB8erKI"
    "paUFbB+JGJvUA5vJWDZoOqa8bAgJW3HDFFqmwxvNmOwb34sukRoiRpN20JLUETFcdU/pHFux"
    "EsN1R8Vi9cYS7p0cg3nsM5NoVq9hnW/Bid1FMnFo0PGEB2M+TTJbYfcWhe7WSyEUkswNocXu"
    "pmHyPX28ONJZpTM9utRVcrqozBa9gHK0jkk67lJ1Db5+BZ8/dGeepn4w8w9/cvoN3PGJwxjZ"
    "PooGE0pLm1UVmU+0brnrs6f0/XZm/mYwt7wj1c8YgBjh4+dG9SYuXziLpx6ZwtePHujV3qdP"
    "zfpnCKJZ2onRHbvgkoQATHh6bR7Sj0Vk8O3Y/5TrA2DSOlaWlmm6VXz70Y/iG0c+0nucdsYv"
    "/3TRz7y8gDdurFJ9VKiLIb2bun0hA4kKScOelw6FCT2l6RSzNsb8DAVhKz05keDhg1P48oNT"
    "3Xv/CzAtpFE0X7e2AAAAAElFTkSuQmCC"
)


"""Icon for the Info page in a database tab."""
PageInfo = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB90DBRIcBgK8oMUA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAGdUlEQVR42o1XS4tcRRT+"
    "TtW93T09D/NQEyURHAnxhWJACTHgRtBIEBTRjWtBt7pQfCxciGSRhf4Fd4bgJooLweADQXER"
    "iNEQfESiJJkQMpOeme66VeV36t7uvt19oxbM9Dl1z6k69Z1HnRLUxrEzK/GbM5dw/sIq3HoP"
    "mQQU1iJickROxDQriZfqV3+kLixjotVuYc9tCzh4/w4c3rtDZkReP3Y6/rDaxcH7Wti3ews6"
    "/NK2EY4iuua0EaFSliiJSAZJbcHK0OFYGxic/fUivjt9FXfvvglHDi/LyIBXP/ktnr0CPLV/"
    "BxY6m+j1DDYlg2QBbRe4tEzuzk0lEhnjEEzBjXQnm+YwLZuMF/jcYoGfV73Bia+u4MBuj3cP"
    "3SHyxdkr8a3PL+OhvXdgZ7fAWncO1gbkvkAfOayE+kpp+UCcCyPIYgEb9OwWheS0yyAPfsYA"
    "9Ysnlu2QwfU9Lq17nPrlAo4e3gVzkj5vb9sJ322hN9+BGAPhogWVglWoDTwXLxcqMLAmbWhi"
    "znUzGiOcy5KjJIFDxGTAOVAPNNQm9xh+W88MBnMdLBLZ+YUd+JJ7Zz9fDljazpPmejIL6yMG"
    "FMwJq0KajMk8l6CMzwh7SHJHHtQl29Uf8MaPPskZntSji6xg/HCjPK6rx9LoFAU2aGzWamFh"
    "oY/zlzyya4MMWwOhjC0Ybi7p2BF9mUPLhxFvwiSNdKYaysE06ik/HGperCJaQgcbDsy0KAlS"
    "2oA+4VeJ6ChIaPsp30reV2E9oqfGRmjWU36UOTGoFYhqrKY42SwGDRAhQ0Oc6vlhgkGoPORF"
    "zAQ9PfquWa+eFZY7hXQOjQtmEPfOPKNW08gzYhKyI6WhYjP90sniBt9uxJcuSJUq6GEkoZTp"
    "P7oMRVFVtmimqkmNvxH9f/iUIVorfJnKyRUBWUinJyBFWVLr1UtkXM2G9EeHZguNjhc/i416"
    "EwZUpdLonnrgFANkCkaD/qV8iVKV3ZgWGvKi0MXmzXUUDo169SJuUICFkAag2o8GWOI/4Kxz"
    "trpgKp36rVLjnz0eE338GTthwMDHf9VLyNCowCLlMUcEaKV3jAGvCAAaxLHCbfg7zCDlm+j6"
    "cIS0Sa8+tLANbBsdXOe3AdMy1xgItCGmINRYkNrq5WbSSM8Y4NCoNxkErKduFYY1QGOAFz4N"
    "8H4UhN6XlUpSlaOPpMZLnKCnR39wAz2ML7NoWK6ZHUHmYd1Vft+kASwGmv8KYdD85N/oohaM"
    "ed4BdXomCAvbrFcHgoFneYENWh49k2Nrv2AWoPRdcgEFygJRBo+kU5e8mDBBT98FzsVGvTpa"
    "md4NJoU+Brx7YpmGmhZMGcJfsHaHVKzLYxgZ84ZFpE7PBmGz3gQERKWXdbHIqtuKa5TwWoq1"
    "IJQGuAHTxFano69MGPPGT9IzBvhmvVQRq2FjD+IWIDkREp9cn4JQIyaQc/SjxkTCjnOKzJBX"
    "1Ov0bBY069VLItsXuJQBklyULqMQS58VPIFTF5ix67RkDnltver0dKF3rlmvnjCezYu2cyFI"
    "mSGxKsVKJAM0E4yMoWSUDPmULTV6xoCiWa/ugkwPqoaEsuaWQaidjk7SEOdjdSWX6Gn3N+TT"
    "qUj/9e5sAOr4451W+r397Um9ej+vTatHiUBKVVqQSWo72VqjlYKWXVzyT6bpWeNFgwY5/mvI"
    "lF5Ws4BVIB1bmIrOlK7PluYM1jYHaLfn4e1G6uVy30p9bNEa866id785prNiKNcb8TKlF2v1"
    "QttExjk6fEv0+xFL7Q2Yh5fbWFm5gC2LlrlJHHQh2aDrNik9j5ytuGEJnXNlAXTsG/9NLpce"
    "LHeJbDolX4fl40XnVC7wMuqIw7aux7WLK3hkeSvMC48uo7/6N67zLbjr1jYXCdhkAInRq7LP"
    "4Oyye7Opu43SShdJEeYxYDHaNOWcPl4C5bzKmbGcC91Szs7xfdDCnL2O5VssVlbXENf/xJP7"
    "7ypD+b0TP8Wjx87hzgcOYHHLEjav87GhzaoemU+0MoImX4hNnZ9+DXoRzcRF0ATEIh8/F1cv"
    "4/fT3+P95/bg5Sf2ju/MDz49FT+kEf3Odixtuxkhz2mAqXJ+asG6LSKTb0eZrVIp0N06rq5c"
    "oeuu4bXn78Urj98zc1fh46/PxBPfXsC5i9cIHwENGWS807jRgF5Mrox5GUqY1FOa4SVU2Vjq"
    "8CB8bS3vyvH0vj149rE9o33/AZd4Hw2lBI2bAAAAAElFTkSuQmCC"
)


"""Icon for the Pragma page in a database tab."""
PagePragma = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAHp0lEQVRYw32XW4xcRxGGv6o+"
    "c2Z2dr3xJY4vJAY2chzjxMhGjnIjPBAUcAxIKJcXxBM8cBNIEAmkCEIUIYRQkEBCEJ7gLcKC"
    "QC7gB6SQC0KylQQrthPLdlCCDV6vs3h3Z3bndHcVD2d2Z8ZrKKk1U32q/67urvq7WhiSgydm"
    "/OUT07x9do7Y7VCIkULAGRV3cBwQAKT/i4AMG8vgT9ks2b5lgjtv2sSBHZtklcm3Dh7zI3Nt"
    "7txVsve6tbQEmsGJCA6rnLD+YHEB6TskQ4B9R5dlvlJOnjnP347NcuN1V/HDA1Oy4sA3nnrL"
    "T16E/bduYqK1RKejLEmBFEYzGj4CC7ggHnCNmCbcHQiIB7jcFnCE3AhMBJjLyrMvXuT26zKP"
    "fmKbyJ9PXvSHD11gz45tbG4n5ttjhGA0cqJHgyA2jIQAJk5SofBEMMcJJGngojQsr3IAcTKR"
    "phXEXma6mzn65lkeP3At+pcT0zTXbya3SzrjLUQVMSeJYwEMJUujD5SoguIE1BuIF5gIVSiQ"
    "/j65GC4VVYAskDTgOAp0C6Uaa7GmMMYnNvH8iWn0jQvGZLtBaIBJQLNTqeLiiAfElCy5XqG1"
    "KJIipmh23IrVfRJJMkaRlKSgdHGJuDitlECEoiyZmBDens4Ul6qCdZYIXqLZEQtgTk/GKLOt"
    "6GpGSwK719fBdWRmsMMNhbu3Cue6zqudMTTaCM6yZLQOTAexFosRCnHBCViCniq441FxEXru"
    "K/qaEr6+U7iqhF6G0wvGuW4NvHuD8OHNdUx/tBf40evGog1wVjLHDTK4KYiRDAo3JyMkEzyC"
    "e15OMERkRZ8zxbzO/WaA/e8RnjyTaQb42JawMkmVnU4F2QY4yxLIGOAecCJmTpEt4+7kLJgx"
    "NEiGqEKYT3BmDj60se7dtU747t6iBh7KvDNz0KuuhFMfAeJgiruAOwXuZIOU+szmujImCGSr"
    "dRGIl2VYWJ3ytBRyAjNlooR2AdOLy/QREM91KmdwMwpzJ2cnpppSl9lrrIBHbxP+04OTs7Bx"
    "DPZtuhIlgw45smej8JWbhWRww7r620MvOAuxJiQE1J2cHAwKdyclIyUDF/Caeu/aClvG67Zz"
    "/ejEvQyH3oLXph1z2HU13DsltBv1ruy5ZtT+zq3w9ClHSWQFdfrzQRGyUWUlxtC/YOo0ee/k"
    "Ffa3P/kjLxlvvjvoOzoNL//TeewuZaIxah8NUnZidsQFk4rMGDkJ5EhBdlKqz9f7++/uPPEK"
    "nJ5V7r9R2dgeAB4647w+7ascO/0uPHXS+OwuXek7Nev88lXj+EXHHcQDVWjSYgH3CvMGam5k"
    "d1JyqsqJEVKCTg9+fyLzneeNaij4Dp+tba7UXjkLeci3nx02/v7vAWZMTmNpDu1V5OR0KCgs"
    "55UgzLlmKkHrC1eU2a6PXKspLafZaolpVC9FqYa8d80kV0zGCXEWYQk1c8xq71IWUgqkpKSs"
    "rG8Jn98TaBYD0H1btW+zuu3drCOp+dAdwqdvDBRS4+VKoCqoPNPRBmVKqON4/whiZcRYH8W+"
    "LfCLTyp3Xz+6qgM74OaNToyjbWqtc/9No7Yb2vC1W4Uv3yJUlWM9p5ecngUqL/E6DUFd8Kyk"
    "qBgZXGgXyob26m0uA/z4XuGp48aLbznZ4bZtwn03Ke3yykdzegZiFDClU7RZk4XS58lkimwO"
    "VjsQK8GCAcpzb8Dn9sLaMefYeVCEO94HQaFZwIO7lQd2X1bXAeZw6E240M3s2apc1RL+cBxi"
    "FoJ3kDiBNByXjBl1EOKOmRFTwKy+L6M7X3hS6OaK+Z5SeIOH78k8+MGwuuYcksPvON9+Ruh5"
    "QlCaIbDUD84CI4qRk+Au9WVk7og4KRsxKqY1vYrDuVlf0bM5S/8j+keqL4Tu0mBcNTQm08TE"
    "MZM607xPxTi1A8kxFUDBFXVb0c2cnZsGJHNhwfnqbzPvdp3H9hfcsq3ejxs2woa2c25hgLMs"
    "hTipvxgH3EC9voPJXtNlTAzakO7uTLYGq/n5y8YLp4zXzznf+2NiMfa5IEOQy3BWmpJSnfZ1"
    "rWMUgqEknBIXMBq4CwU+okcy+5+Ae3Y4+7YJvzqiGPXqXjkHj/ypzoinj8JCNYozeEsEcEPU"
    "iVoffTE5pswvVTSb4+SwiFigkUscJZUDPZaLLMbAM6+V/O745XYdfn0kUKRaz+Xo9xUHAqQA"
    "LU30es5kcxHdN9VkZuYsa9cESndKCxSyiOsSpHEaklDNjEVQg6j6f+0a0iGkgFsLaXQJGmlI"
    "B9clzAMtiaxvZy6dn+GWqXXog3dM0Zv7FwvdDtde00TVWFJBNFLQI+U2kUBPxnApUTGSjVNJ"
    "YEnrviCG5TaZQE8HdtHatV0YI2nJWFhgamNgZm4e777Dx2+9vk7l7z973B8/eIr3776dNWsn"
    "WVoQKnOyGkgx9NDzVRwwXPk5YKKr3pGC0cRY0y45P3eBfxw7zA/u284X79kxqJl/8txR/+nB"
    "U/RaG5hcfzXWaJBVCeZXemkNfBEZfTsOP+WGHNDYZXbmIqVd4psPfIAv3b1TVpHZb1464c/+"
    "9Synzl8iWiZY0X8b9ylGlgsmwz0CgsuyhSII6sJQYdUfo4RCmbq2waf2buczH9m+Mu9/Aadb"
    "n/Uqw9R5AAAAAElFTkSuQmCC"
)


"""Icon for the SQL Window page in a database tab."""
PageSQL = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjYgamFhbiAyMDEyIDIwOjA4OjAyICswMjAwNrNp7AAAAAd0SU1FB9wBGhIZOulC7wsA"
    "AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAGuElEQVR42o1XS48dxRX+"
    "TlV33zt3HrENxESykTLEMY8IEUSQeUjZRMpDJosowBK2zo7HAgErTACxsBRYwE9A4AVScKQs"
    "QER5yBJZJJYcJ5aVRASDbI9lecZ3Zm53V1W+U9V9b9+ZO9a0Zm7XeXTVqfP46pSg85w8txL+"
    "fO4yvri4imp9iEw8amsRMP0EMkLkSqSleetLusoyGRS9Aoe+tYDHvrcfRw/vl20qL548G/66"
    "OsBj9xZ44OAe9Cnp2YCKKjrnViN887EEiYNokHQmbAxtn7XS4Py/L+H02Wu46+A38NbRZRkb"
    "8PxH/wnnrwI/O7IfC/1NDIcGm5JBMo9e5Tm1TK/ORSXQM6aCNzUX0pVs5GGrbjRe4HKLBYpX"
    "ncGpP17FIwcdXv3pHSKfnL8aXvn9FXz/8B24fVBjbTAHaz1yV2OEHFZ8d6Y4vaefayPIQg3r"
    "de8WteS0yyD3bpsBGhdHX/Z8hmrkcHnd4cy/LuLE0QMwf2DMe/tuhxsUGM73IcZAOGnNj7xV"
    "Vxs4Tp4mqlFaExc0Iee8GY0R8rIYKInOocekJA/8DjTUxvAYytYzg3Kuj0V6dn5hPz7j2uaf"
    "VzyWBtxprjvjxC6gpBGBBqhLxasBLu3Q92Mu3EwvSEXdOWS14eLgwuuRp3r9uuYm6LmiwMKC"
    "4IvLDtn1MsNeT1eGIk4qcdsBb9y/0PGhvck43xX93N8dw2BSYmoouZmNCqy0INGltAEj7kg1"
    "QmXiR89+7qNyaLN7xjhwRybV5Y70bx5kEnJOHzgfUyTQW9ASJ5kFrwkiJGhIpeu7JpMZrw4t"
    "YmaOEy03pdUT1cjz18XyDVpBTErPtTPHrNUycswY79H5CKiqaXr2eHd0XUsMQUQqrxuQ6O1M"
    "f5xXhQbZghnPEQ3o0DuOd0HrXEEUK1wq5RgKj8zH3dMhdYLULnqp1S0tgpnj3dDJgKZQ+ac5"
    "4nTDMQdI1MwG/W+yZgy7VRXGtMjsccS5BAA70rqqzsXChNPSDGjWowGW/i/JrSrbHDDNN/zo"
    "/cdNF852Md6ZrrTEaZQnSDnM0QPku4o54NQDqoAG09u3weMf1nECpaU5On77hJ3ity5vZUc/"
    "qMd0K//4yYwVlQCrtD30cYOykmWZaw542hBiEmouiEx2UJYTOhkh2/hbZbqZLj3Jp6iIvFqF"
    "IQZoDvDApwHOjZPQuYRUguT6qu7QjHubWFN8zSQxY1lZYkyP5Q0/GEI6q8PLPGx1jfJNGkAw"
    "0Pqvan2biFKt7Z8+bTHrmeabadkz2RbtJK81+5h4lgdYWTgMTY69o5pVoKnXhoAKCSBSDB9+"
    "r46oFbHbuDg+fWyar5Aq0TtJduRdN6Zb+eljNoaN8Sbcx9RHybMnpDLUsmDC0MJa8TqCdYLP"
    "mpXR0kaaMePW5UdHixnLtN7HdOiiqkQEHGYDLBJ1i7AGPZ4IxQoIyYCqZJlYP3ZblzauHU/z"
    "FfGM78ioN6GTvOXbMIRUC5CcHuLRraGPSagZ40lVtY0HRNsB/u15/S068Sx24E/oM8/KFN0+"
    "CkRsX1DFCpAY6ngY+VgyzAECUqUhMJMG9Luv0TBTxn7Gsp3S8YWXelN8rW0NYSv7zq/9mG7l"
    "F1428Sxw6MV2zntJFRIaKNZBNEArwcgkBB06VouRbfwYAmbTRNalOyEgP9ONcux8wtyUhHS9"
    "qioYKVz6Tg/apU2YjKf0NInRkdXTNMKEr02rQ/JAPHhpQSax7WRZMWaatOyHUyny+fK4xax2"
    "bDY/0V8dn6bbR48mbUl028JSrEwKfbY0Z7C2WaLXm4ezG7EnzF2BA4xbXQwjndUFqmJj5jie"
    "cR29WTSaYtR2k3mOPu8So1HAUm8D5gfLPaysXMSeRcvapB/0Q9lg6DapPY+crbghCM0xiYwi"
    "JvvGm+nlMoTlKtpBS74Oy8uL8lTPMyH77JD3DRyuX1rBQ8t7YZ56dBmj1a9xg3fBA9/scRKP"
    "TSaQGD0qR0zOAbs3ixFb7SBFPEhqP4+SwLRpEk8vL556TvXMRK/yg6Rn59iiF5izN7B8m8XK"
    "6hrC+v/wkyN3Jph6/dQ/womTF/Dt+x7B4p4lbN7gZUObVd2yNNgeJvjQurR9t//pzmC23SM1"
    "z1iAWOTl59LqFfz37Od485eHcOzHhydn5tu/OxPeoRGj/i1Y2ncrfJ7TABOvXlsf6doiMn13"
    "7F7lOgaYah3XVq4ydNfxwpP34Fc/untyOW2fD/90Lpz6y0VcuHSd7nMRfCYNmqA1V/M5aA+v"
    "Umk1TOwpzfgwa84iSTLLa9nygRw/f+AQfvHDQ+N1/w/jDD9W5IqYSwAAAABJRU5ErkJggg=="
)


"""Icon for the Schema page in a database tab."""
PageSchema = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAG5klEQVRYw32XT4jdVxXHP+fc"
    "33sz781M2sS205Ym1NhQbVWw2FJiRZCCWoLiHwwouHOhSxXsorpwIbaLLuxaEFeCWbSLCIJF"
    "pVH8t6rEaAm1pARJMjHJJG/mvd+95xwX9zfvz7zRHzzOvfecc+95v3O+33N/wtxz5sJW/P7C"
    "VS5d3ibvjGjEKSkRLD4REAQgAEgnEZB5Y5kN+it9TjywzjMf3OTUo5uyZPL8mfPx1+0hzzze"
    "54mjd7MqsJKCjBCwFIR3zhIC0gUkcxt2ge49t1vlrbev8MfzN3j/0bt46dRxmQbw7Vf/FW9d"
    "h+ee3mR9dcxopIylQRpnJTuxsC0QgkQiNONaiAggIZFgvy0QCNZLrCfYNuXsG9c5edT4wWeO"
    "ibz+1vV44VfX+Mijx7h/WLg9HJCS07PChB5JfH4nBHAJigpNFJIHQaJIjxCl57YUABIYmRVv"
    "yBPj6o7x5j8v8/Kph9DfXbjKypH7sWGf0doqoop4UCTwBI5i0us2KrRJCRIaPSQaXIQ2NUj3"
    "nkKckJY2gQkUTQSBAjuN0g5W2WictfVNfnvhKvqPa86hYY/UA5eEWtCqEhJIJMQVE6v/0Fen"
    "awGENxQZ0BSd+obk6VpRUHYIyYQEq6WACE2/z/q6cOmq0dxqGw57IUUftUA8gQcTGdA3n87V"
    "61gx1BMcIMUT47ToN5HBNBOG1sIMEF9lN0MjIQQJLzBRhQgiKyHCJGI6tyn+lI/fF3z+WOq2"
    "rfLn7yh/vhZ41gW/kFlRejgYhCuIUxya8MAQiguRIcL2AIaITOciSoQhkigWS9VeDCbZAF3w"
    "m7dLGA5EJIKMe9CYGxGBmeDOnJPMUYUs0Ib7cqFbgVIO8pOFFCABrkQIRNAQgTmU0v2r0H1s"
    "MjfvxlaWsW4GuV22XaSPhIRVKBuEO41HYBbkUil1nr1EZmy2NxaBG2N4Zxs2h1V3ZQduTYRc"
    "lv32ExICGoGVAIcmIijFKcUhBEI62g2kAruyvkTVS3DuknDu3eC7T1XdS3+qZFNtF/3mSVwp"
    "mIIG3XnQJHNaU3JOXYPpfOa7ysJ8Jr07sLXF9YP9at9waTEGNY2WabCgFMhGx+kzuYegiGCG"
    "ptlBEUEE5DJrV/O2sS8PEok2rbDKHSJaPHo0Ho5FUEqtBem8H79XOP2Y7G+aC1X+yOFaM987"
    "yRJS5sc/+1tw8T+VG3p5GxXHSjCiQd1sWoS5KJMW2lbZaODJB4VssNMKOy2MWhakOXgsr++N"
    "swlPPiisJWhbmJgxNmViG6RsCGMa98C9vkZ3JVwRwDqwv/iGcnMX0Kg69al88dlal99/fW5d"
    "vKLZlSMDePUrgblQTKA4KRravjHSHocnhSa6XJYSWPGOIKB0kCo5aFvqASGIzKRHgghyZrpe"
    "0RNECDnt7QFtGzQeTDSgSbTRJyoMQUMIU0pWHIMQzGr+shm5CCoJx1BmMqJCL5fZOqGo1H2y"
    "SQWfQc4CroyaIRsm9OM2htGYB3gNILeCJ+e1r/VY69fof/JF5eIWfOu1qlNreO5x+PpTsLle"
    "gzzzVeWVc8Kv33aIhLrw8ueER+5RAF74pLCb4fRPR0heR3pBiOEOjZtBBO5OLgn34OHDszo+"
    "epcwmtQidQ/UYa3Hgs3Dh4VBAznXStcQHtgQjt5V9ZvrXSqKk8WxIkRIbUYeNWfFnJwV1wMo"
    "NOrmrqAe2AG3LrNaC0Sl2oOo+E5ewSVwFwStTFjzSA2gBK4HXyr3dOq1eR0YQKnNTMM54HzM"
    "ggKYR3ejgibcK+wiyFYhudMuOu62THUawSQv20wKtRkFKMFuxx3zTy6KUd8AAhGOfPT530R6"
    "4EPczkNu3up31yahqfem2VxsHwb+hwwW/ebehYgR4Wzeo2S9yYM3L6KHBoqPW1YawdIuImP6"
    "boizMN8bqwFphEtLzxwxXZzv8xNn+nMgJ1jVgk+CQyu76JPHV9jauszdG4l+BH1PNLJL6BjK"
    "Gj0pqBqDDOqQVf+vXU9GpJLqDbq3Q9JMT0aEjvFIrErmyNC4dWWLp44fRk9/7DiT7X9zZ2fE"
    "Q/etoOqMVRDNNEwoNiSTmMiAkD4qTvE1WkmMta4lcdyGGImJzuyyD6tdGlC0zyDd4fi9ia3t"
    "28TOu3z66ffVdvXDs3+Pl89c5L0fPsnG3YcY3xFaD0wdpJn70IsDeuLsF4CLLiFAcFZwNoZ9"
    "rmxf453zf+FHXzrBNz716KzL//iXb8YrZy4yWX0Ph47cg/d6mCrJ46AvrVksIovfjrKMUcHR"
    "vMONrev0/Rbf+fJjfPPZD8j+5s0vzl2Is3+4zMUrt8huJG+Q2UmziwZORAaEkD0LRRC0a2bT"
    "C5FUXWqU4w/1+OwTJ/jCJ05Mz/0vU2Ofu8TsaboAAAAASUVORK5CYII="
)


"""Icon for the Search page in a database tab."""
PageSearch = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAB3RJTUUH3AEaEgYCDBpZCwAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAf0SURBVHjafVdLbFxXGf7O"
    "uXeeHjt2HMcuiV3i1k3SlFSNUkjToCoSUmmJWLRReQkJEBKPLUiwQKKwAMSiC7pCILGoukBk"
    "gRBBdEEp0FaljSIUSJO6CWkdJonjsR2PZ8Yzc+85h+8/d96e9kp35jz+85//+f3/Veh5zlwq"
    "udcu3cZSsYyoVkWoLOIggEP/47jg/Kryc9X6lz/VS6y6g3QmjYW7CjjxwDRO7Z9W20i+f+ai"
    "O1fO48ShNI7MjiPLnUzgEJFEeA4KYVuHlVN+4AVSPQxbgrafzabG4n+X8cbFdRyY3YGfn5pX"
    "HQG+8/trbnEVePLYNArZOqpVjboKoUKLTGTJWvXfzkuVo2V0BKtjXiQ3BX4Ng7ReeAWTClDg"
    "dtlonP3HKo7PGvz4iTml/rK46n7w0goe2j+HmXyMzXwOQWCRMjEaSCFQtpeTZ29p51grhC5G"
    "YEX3ALFKUS6NlDXbBBC/GNoyY0NEDYPbNYML7xTx3Km90H+jzzM7Z2DyaVRHslBaQ5FpzEM2"
    "EFNrGDJPGMVoBtpfqF2KfEMKo7gWekcpbxxaTDW5Bp4DBQ28ezT3aqFGM5fFKC07UpjGK7xb"
    "X16xGMtT05RoRsbGoUkhHAUQkyorAphEQ5v1sfBhdE5FpM0hjDUvBy+u+TWhy8YxlaDl0mkU"
    "CgpLtw3CjWaICUtTurRnqrzaDg0ySRvbmWs7fDxIN2zefgzFca2IVlRmKwIzzSlvUsqABjUS"
    "CheJZgoNn2+O8aCxJw/sKwCT2QDFGnC17LDcoNbo0g2ea887meOsSEFLapEAMaehs84ziS0F"
    "ieScaScYAgba4QmHT85ofHRUIRt046rcVFjccHj5psP7lf5zipf2zttPwJusT0+JC2YQ7w4N"
    "o1bSyDBirEXnkCaTR3crPD2viQfAegN4/ZZFsQocmFA4xPfolMLd9OULiw6X76iBC9U2AcQF"
    "HqmsuEJ5K4XyQ5chjlvI5rT/O+ovJ4Jx+sr/HP685LBS9RCAv3M+V3A4fa/CwZ0KX1xQeP5f"
    "GjdqvcmvsR0+BCtMksreFcwx67WnQWIRQvGfJqQ7HtuTmPzVIvDiJeBGmekm+5FCneZ/Z1Xh"
    "V/9mLNwB8QM4RjfJnrxtPu15520KD3DMO0VhKq7F/DGjQV7ZiBkHs2R4zw5grQ784V2HzS10"
    "9qKoOy5uAH+86nwwPTQFjOhkb5C2/VouRLHzr9wn2RAGtH/TiPRBq8AAC/RvLgReKzpcu+OS"
    "1GlXmYHx+VsONysaMyPKW2Kl1lMAemlbdcMSpAxytAAdYSLGgBFpKKn4pFU9pnJJEL23TrCJ"
    "nV9vZ9PgeMMmlpodA3ZkqEzUv9+PyAERMoMsKtxrMi1TEgOWMjgfhM2m82Z7dzU5cGgXmRh4"
    "Adt7g+NRWmqamguovL++fb/3FdOn6mXoRtPHAAs+QmtMJwiNSZDqPANv7QHgwWmNe8ctLtxK"
    "Cr3zxUj3jR9ZoABMxf8sO1wtKW8BFpQuLbrFzGlCOrPDqhEE0Tr364Kqzue/DwwjERzg2prG"
    "+RsOLBH4yoMau3O6sxfH3fHh3RpPHdSe+cfYYzx7kutmkLb7GmYBCP1NmrWqU0jTLMHcya8/"
    "G+cm6beUj1zjDwPLVYeje4D7djHXGeGVusXtiqQgsCtv8Zn7FL75MANvFDhHXCgRA47cpfDV"
    "I4rCMDveFl58BWlNMlZU0rCEG1a+GvmMN9egTvzony6ePAAdjtB3NI8H6wTBPjGr8L2TwN3j"
    "ygfpEqFXUm8fwWfvjsSsb153+OlfgesbyblfntY4+pEkCs/Rit840w3EFIWphgqjbLeaW2uY"
    "2boG9cgP33Bu8n6ooIDaFtMkoGjiO0asJiDtm4pw6mCA43MasxMJuMW8a3HV4uUrwEuLCmub"
    "28/9+guuT5Cv/RbIugo7rQJG8w71qITpylIShBIxloEQ0W8SEz6Buaap0eVly5fmIiZPjTVZ"
    "I+jPOESxEpFJ60LJ74FzX34xEeiFL4VeCAEiti+IWAUFA1zrTGh9XksAChJqqRMd/NAiWGu+"
    "2pBa4DxYSRv2QXSD88//pusCg4xv56xVSYYIErqkx04EiOWgaplSk5HtzH22DBkP0g2bt59Q"
    "FEUSmN5eST9gvV8FjCLjWiU5saZ0f+2512rIeJBu2LxbDaWBSSzgCy8lYExK28nWGmkf/OyH"
    "vX9CMXbPXCkzdDxIN2ze6YjYkojaSlNZnbhejxFkLJM7Q1FMsMXFOtIs1tKN984/aDxIN2ze"
    "fsUorHnI8lvCMqbGMlvQD89nUCoVMT4aIE3TptlMhmqLrmOFiUeQYiuuCaE5gpQWxGTf+GF0"
    "KVVFwGySDlqlamzrIr8mdJYZk2WHvDNvsLFcwsfnJ6A/9+g8GuWbqPBbcO/uDJlY1BlASkup"
    "bDA48+zeAt/dOsXO2TeTBC12N3WdrMnHiyWdETrdpYtsPqELcmzR08gFFcxPBSiVN+Fq1/Hp"
    "Y/ckTdNPzr7tnjtzBfsOH8fo+BjqhNymQKiorMJ2be2LqGGdX/LNoLd9R0qcMQEJQGksl1fw"
    "3sW38LPTC/jW4/u7PfMv/nTBPU8hGtlJjO3cBZtKUQDtc37wUb2yKNX/7dj7KdcjgI5qWC+t"
    "0nUb+O4z9+PbnzrY/ThtP7979ZI7+3oRV5Y3aD4a1Iatb+OEtNNokKGTHl52VZtC+8907bvd"
    "bgYmZ6gIP8vm96bw2SMLeOqxhc69/wd0rhV4d9yO5gAAAABJRU5ErkJggg=="
)


"""Toolbar icon for case-insensitive toggle button in data grids."""
ToolbarCase = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAA8UlEQVQ4y+3SMUoDUAzG8V9a"
    "dRLqItRBC+Lg4A0cRFCX4uYiCJ1cvYCLZxCkJxBRJw8h4t5BF0HcnUWHuKQgbQdB3QyE9/Il"
    "+fPyCP82ZhHRj4j+d+unRpo7eMdSRHQy87n0NZx8Kb3OzEtojAC3cI/pug9tH4+ZuYeHik0C"
    "bOCuIBtDMTOPM/M4IrYLPjMGiIhlfKCFFyyWJiLaEXGOXo09M+kFXaziDIdV1K3cKQaZeYBB"
    "5VqjgB30MnM9M9dxWxqsYA4L2MRsRLS/zn6F5zrnsV3xUDvCU/kubnDxO3szIW6UN/H2U0Cz"
    "fr2J1z9Z/U+ezzpfbRKKFAAAAABJRU5ErkJggg=="
)


"""Toolbar icon for reset sort/filter button in data grids."""
ToolbarClear = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAkElEQVQ4y82SSwrCQBBEn5LL"
    "1BHEa2SRTRAX3kbwBCLZZZGD5AZ9G8dNR5r2g+AiUzBMU10z1NQ0rI1NqAdJ/cKZWewhqXhZ"
    "zGwAjiTBHTgDra+Mhb+4FoAmuZmB6YPbKZx5utv+m0HlF0gqIf23aL4181fWmUF8QgH2gRuT"
    "tvN959qXUb5JOvw4ylfgRBV4AH70JI5OrydaAAAAAElFTkSuQmCC"
)


"""Toolbar icon for commit button in database table grids."""
ToolbarCommit = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEaFDUPgk08NAAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAABHSURBVHjaY2CgKajn+w/G"
    "eAATpXaMGoDNAFwhj0OcEatCfKDxEyN+A/AZgqYZtwHYDMGimTAgIiVSDBDOItUmqJcoTgcU"
    "AwAXqRhzWeRKpQAAAABJRU5ErkJggg=="
)


"""Toolbar icon for data button on search page."""
ToolbarData = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAcZJ"
    "REFUOI2dk81qIkEQx38zjh8T3KsYDyLxc1T0CXLMcV9Ddm8+iA+wz5B3kRCJDoiCeNnTgLDg"
    "qNNdtYfsiMbLJgUF1d3Uv3/9L9oZj8ffM5nMPV8Ia+1vT1Urk8nk11cExuPxD09VHYDn52dU"
    "9Zwics7LdXo+Go1QVcdNksQVEQCCIACg0+lc1e12+6YWEZIkcT1rraOqAIRhSLFYZLfbISKU"
    "y2V2ux2qelOrKtZaxzPGuKlAEAREUcTj4yMAi8WCbrcLwOvrK8PhEIDpdIqqYox5J0ifEIYh"
    "pVKJ5XKJiOD7Pm9vb6gqd3d3vLy8kF4mIlhrHdcYc+NBvV6n2WwSxzFBENDtdtnv9wwGgzOF"
    "iLwTXAqkBOv1GhGhUCgQhiGqiu/7zGazKwJjjOsmSeJ8JKjVajw8PHA4HGi1WrTbbeI4ptfr"
    "0e/3L6dwbWJKsNlsEBFyuRzL5RJVJZ/PM5/PzwSpia619moKANVqlVqtxul0otFo0Gw2OR6P"
    "Zz9SAWut68VxnPnowXa7Jd1brVZcEl56EMdxxouiKJ/NZnl6evrvPwCQzWaJoijvVCqVn7lc"
    "rvqp7n9xOp22DuAD3wDvk/0G+PMX80pIbz0EU9oAAAAASUVORK5CYII="
)


"""Toolbar icon for delete button in database table grids."""
ToolbarDelete = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEbFAgjYsF/DAAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAAkSURBVHjaY2AYBcMAMCJz"
    "TvDx/SdGk8WnT3B9TAPtg1EwKAAAoFkEBI8Fc8MAAAAASUVORK5CYII="
)


"""Toolbar icon for form button in data grids."""
ToolbarForm = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i"
    "ZSBJbWFnZVJlYWR5ccllPAAAAWhJREFUeNqkU71qwlAUPtd7ExJLKiREUEKHrnERJCVDNp9B"
    "8gZ9AZc+Qbc+gG/h6CgEpKNDHR26OIg4SJb82XOuEhpILeqFj3vhnO/jOx/nsuPxCPccMRqN"
    "nvF+QRhXcg+IT5HnuT8ej9/a7bab5xlkWY5IIU3pnUFRFHAyyYExISGECrvd7msy+XgX2PAY"
    "x7G7Xq9lMwFFJS69Ee50On0QiqIUw+HwpvlnsxkTaJOdbFbDjKIINptNLbHT6UAQBDSiFGiQ"
    "rfl8Dpqmga7r0Ov1QFVVCMOwVmCxWMhRiFsK+L5fNlB4GCqsVqtaAaqVAmmaNohA+H0sy7o4"
    "P/UTVyRJws9qlYblcgnb7baWbNs2DAYDIC4JlBl0u13Y7/fQ7/eh2Wz+mwFxSwee58mi4zjS"
    "jWmaf2ZAtbMAF7hECmMMcB8qTa1W62IGxJFcwzBeOedPtywSuvhmeOvnjySu5FPqB3bvd/4R"
    "YAB0Lucj40EubAAAAABJRU5ErkJggg=="
)


"""Toolbar icon for goto button in data grids."""
ToolbarGoto = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABVUlEQVQ4y72TTyjDYRjHP8+P"
    "ElEotJ3EmdSUHdjBcTflZklulChScqJYOU0pTbvQymXkYgcuylKyH+JASnJauWFMWXtcXvyG"
    "0pC33sPz7Xk+z7/3hf86IjIlIjERqfoNZF1Eqh12zCqQkeevqt2fAL5IKuyLpAJfZJ81gLE8"
    "/aOjd+Eqaeih/aGG6LdtNc0ch8WyPE5xoLfJs7hyamsuFzqdbImaCuaAZuBEVcffAI0Tu8nh"
    "wXbP+R3cZ98htSWwsZywL4MdrY42OoF+VQ0YO178eJ+2Z4PxvLLqe/ye7XDcFssKOYL7AK9z"
    "Bqrq/zSDisBqEiB3cxZ62JqOOgDzQIsxR1T1CKDY3DqgBijKXB9e8HRrZw+W9oBSIGOyDX85"
    "RLOacqDsw54zQBp4NhUsAi7ApaptP3mFrSKyKSJuI1WKSKJQThew8woA3IUErwEpYPRPf+kL"
    "pdlqmIpx05cAAAAASUVORK5CYII="
)


"""Toolbar icon for insert button in database table grids."""
ToolbarInsert = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEbFAgw5n8+0gAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAAAvSURBVHjaY2AY3oCP78R/"
    "EManholSSwbeAEZ0PxOj6dMnC7g+il2AF4yQWBgGAADm3wucN+5mGAAAAABJRU5ErkJggg=="
)


"""Toolbar icon for refresh button."""
ToolbarRefresh = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAABnUlEQVQ4y9XUPWtUQRTG8d/c"
    "rGuljeJLIwmYtTeKinZ2YuHdBUmnYCUWhuRjKDZaxiaVKO4mEPIBFFGxymKxIQiCaJqAik0I"
    "ZsciN5u7d2/WlHq6M+fMf+Y88zD86xGGVp+pqJrAOEbwWdV7122AlpOia+qeDgfOq+qawZTg"
    "WKH6SzSLWUELidT43sCXjgqWBOf3OeUnqdM7SdJXWnJAYrEHi9q4hZpoDHW8HUav9GUbZgQX"
    "MticTXdM+p2Tois6MQyY5JpHBFMZbHkAtr2+gLECI5bfsOuc4Him7KMB2HbcxJEC7mc5MKjl"
    "mt6UzpNaxSpoOpTpS0uU6hQ1/CC6mwHX9uHgU3icZZMUgamOlqrosOCsZm/j+s7phVEv90wX"
    "rZS/MguC0cLGd7jUt/bCQcF0Vv9qzXK5D2PB6FFHUB+AVczhTLbywL3dl678RakfuKKpLahk"
    "Y07nYK8lnuxt7H5vBcFFPO/dO/R1vBLd0LBVbuzdxo+imuhh0WNZfMF9m65q+D78+2q6LVrU"
    "sJ77dSYwii3Bim/aec3+v/gDVpZ0g1sFQpUAAAAASUVORK5CYII="
)


"""Toolbar icon for rollback button in database table grids."""
ToolbarRollback = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAB3RJTUUH3AEaFDUVfy/FTgAA"
    "AAlwSFlzAAALEgAACxIB0t1+/AAAAARnQU1BAACxjwv8YQUAAABHSURBVHjaY2CgEDDCWcL1"
    "/0nS+bYRrJeJUhfQGIC8RcBrjHg1Y/EzcQbgshWLIYxEa8ZhCBNRCnE4nzAgIhApTgejBlAB"
    "AACTkRU1bx46WQAAAABJRU5ErkJggg=="
)


"""Toolbar icon for stop button on search page."""
ToolbarStop = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMTo1ODowNSArMDIwML0/WYwAAAAHdElNRQfdAxUTOiUy3m87"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAAAZ0Uk5TANQA0ADICuWh"
    "ugAAANVJREFUeNpjvHLhBAMpgAWZ83vmwgfTp6OpUMjMZE2Px6IBoto/ORlNw8bp0xUYGOB6"
    "mPCrBgKgIFAKqAChAY9qTD2MQE/fNrDAoxrhtrlzVS+cgPrhz+/fEAbrQpAxv+Pj0djonv75"
    "4weUER7Os3IlRCkQfAkPR7OHCa4Bjt76+0MEgQxkcVQbvn+HmyG1axeEIbxx4zM3NwI2QFTf"
    "t7MDIohmNBtAoQQJVm0LCzxBdPXECUiUg2wAUkAOUIigaoST8OhBVs2AnJZAeoDShBIfI6nJ"
    "GwC7TZxZQGalGAAAAABJRU5ErkJggg=="
)


"""Toolbar icon for inactive stop button on search page."""
ToolbarStopped = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMTo1ODowNSArMDIwML0/WYwAAAAHdElNRQfdAxYXCxC3jKuY"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAAIZJREFUeNpjYCAAGGGM"
    "9v9rkYSDGSoZURSApGORFCyGK2HEJo2shBG7NEIJUIHJf2zSECVnGFlAjN9gbjEQ9yLREABW"
    "8BPMbGOoAkuCWAjABCJ+QGEdWKgOzsdQ0AQWasKloAvIygNCBiALoQDqTRMsfjgD8yZ2JWcQ"
    "AYVNyRnUoMYXWQQBALXDQEUeuvmAAAAAAElFTkSuQmCC"
)


"""Toolbar icon for tabs toggle button on search page."""
ToolbarTabs = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAARnQU1B"
    "AACxjwv8YQUAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAadEVYdFNvZnR3YXJlAFBhaW50Lk5F"
    "VCB2My41LjEwMPRyoQAAASNJREFUOE+d0b1qg1AYxvF3Chkyd+gUehfF1dHF0VJwMm3sh0IK"
    "RRA0d+TuBXgBvYIgKH4hRiIxGk99pEuhkJwe+OPrCz+OIDmOc+e6rjI+Vwjzdru9v2YHS7Zt"
    "PyRJ8sV+DmbTNFfX7GDJsqynYRjY+Xyewuz7/vS8tIOlzWbz3Pc967puCrPneSwIgl/9tYMl"
    "wzDWp9OJHY/HqbZtGd4vhctgSdf1NeDhcOAKBpY0TdObpmH7/Z4rGFhSVfWlrmtWliVXMLCk"
    "KMprVVUsz3OuYGBJluU33D7+d65gYEmSpPeiKFgURVzBwJIoikaapiwMQ65gYEkQBBOfv9vt"
    "uIKBpeVy+ZFlGYvjmCsYWJrP54+LxeLzP8HSeGZjN2O3nMHMvgFTmvUJKTInOAAAAABJRU5E"
    "rkJggg=="
)


"""Toolbar icon for title toggle button on search page."""
ToolbarTitle = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAALHRFWHRDcmVhdGlvbiBUaW1l"
    "AE4gMjEgbeRydHMgMjAxMyAyMjowNjo0MSArMDIwMB9ug1oAAAAHdElNRQfdAxUVAhfpG/7y"
    "AAAACXBIWXMAAAsSAAALEgHS3X78AAAABGdBTUEAALGPC/xhBQAAAEJJREFUeNpjYBhowAhj"
    "JCUl/SdF47x588B6WXBJIBuKTQwGmHBpJmQzUQBkGyGvMRFr2KgBw9oArKkKV+IhKRUSCwAF"
    "qxgZvjJU7QAAAABJRU5ErkJggg=="
)


"""Transparent 1x1 GIF."""
TransparentPixel = PyEmbeddedImage(
    "R0lGODlhAQABAIAAAP///wAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw=="
)


"""TreeListCtrl icon for triggers."""
TreeTrigger = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAchJ"
    "REFUOI21k81OE1EYhp9z5k/bhIQiDaHItFQyYIyCRhM3utFELwAvwAWuDCZs3BkuwEQWLmDB"
    "BcjCtdGVceVCqgk6o8hMY9MWaPnL9A9RXJg2g2Vm55uc3fc8+ZL3OxCSqZnFiWt3Hh9NzSxO"
    "hM0AyDA476yvPH1yn7yzvhIl6RIEYbuwwfhlK1Iiw+C1UgVNVbg4miIxNBAqkSfB3uY2mirR"
    "FAWO4LSuk7YyJ0rEv3ChuotAIAQIIfhkFzB0lcPDX3xxy3iOi2mNTC7PT+cAZBAu7+yjKQqa"
    "+vc1mz/hNyR64pzPDpLq6+1scu/Rwi0AtQ1X9mtoqoIQAoGg1mhR2fa5NH6WU4bKu/drSARm"
    "fx8Anu2+BoRMj2Vuz84tcaYnTqNxgF9r8t3bJP+jSrG0S73WoljaQ5WSmKGT36riOS6pbOoK"
    "gHzx7MEb0xqZnJ1bYijZy6pdZKvi4/stzplJhgcTNOoHxAwdp1juwC+fP/zQaWF5fjrXlty9"
    "eYG4oRM3dPZ26kghUIXko1fogo/VGJTcuD5KzNDJmv0Ymsrb1W94jsvAcPJqEO7UGHZMX+0N"
    "XuU+d1UXKQhK0lYmEo5M+ze2+/5v+QMVsPBAoH4SJAAAAABJRU5ErkJggg=="
)
